// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RDLOW_OPERAND_IMM8_IN_IT_BLOCK_CMP_T32_H_
#define VIXL_ASSEMBLER_COND_RDLOW_OPERAND_IMM8_IN_IT_BLOCK_CMP_T32_H_

const byte kInstruction_cmp_vc_r1_111[] = {
  0x78, 0xbf, 0x6f, 0x29 // It vc; cmp vc r1 111
};
const byte kInstruction_cmp_ne_r1_134[] = {
  0x18, 0xbf, 0x86, 0x29 // It ne; cmp ne r1 134
};
const byte kInstruction_cmp_ne_r5_21[] = {
  0x18, 0xbf, 0x15, 0x2d // It ne; cmp ne r5 21
};
const byte kInstruction_cmp_cs_r6_221[] = {
  0x28, 0xbf, 0xdd, 0x2e // It cs; cmp cs r6 221
};
const byte kInstruction_cmp_cs_r3_100[] = {
  0x28, 0xbf, 0x64, 0x2b // It cs; cmp cs r3 100
};
const byte kInstruction_cmp_le_r2_209[] = {
  0xd8, 0xbf, 0xd1, 0x2a // It le; cmp le r2 209
};
const byte kInstruction_cmp_ls_r7_8[] = {
  0x98, 0xbf, 0x08, 0x2f // It ls; cmp ls r7 8
};
const byte kInstruction_cmp_cs_r7_201[] = {
  0x28, 0xbf, 0xc9, 0x2f // It cs; cmp cs r7 201
};
const byte kInstruction_cmp_ne_r3_112[] = {
  0x18, 0xbf, 0x70, 0x2b // It ne; cmp ne r3 112
};
const byte kInstruction_cmp_lt_r4_152[] = {
  0xb8, 0xbf, 0x98, 0x2c // It lt; cmp lt r4 152
};
const byte kInstruction_cmp_mi_r4_165[] = {
  0x48, 0xbf, 0xa5, 0x2c // It mi; cmp mi r4 165
};
const byte kInstruction_cmp_eq_r6_175[] = {
  0x08, 0xbf, 0xaf, 0x2e // It eq; cmp eq r6 175
};
const byte kInstruction_cmp_hi_r3_187[] = {
  0x88, 0xbf, 0xbb, 0x2b // It hi; cmp hi r3 187
};
const byte kInstruction_cmp_ne_r0_192[] = {
  0x18, 0xbf, 0xc0, 0x28 // It ne; cmp ne r0 192
};
const byte kInstruction_cmp_vc_r7_207[] = {
  0x78, 0xbf, 0xcf, 0x2f // It vc; cmp vc r7 207
};
const byte kInstruction_cmp_vs_r3_135[] = {
  0x68, 0xbf, 0x87, 0x2b // It vs; cmp vs r3 135
};
const byte kInstruction_cmp_cs_r4_204[] = {
  0x28, 0xbf, 0xcc, 0x2c // It cs; cmp cs r4 204
};
const byte kInstruction_cmp_gt_r0_122[] = {
  0xc8, 0xbf, 0x7a, 0x28 // It gt; cmp gt r0 122
};
const byte kInstruction_cmp_lt_r4_185[] = {
  0xb8, 0xbf, 0xb9, 0x2c // It lt; cmp lt r4 185
};
const byte kInstruction_cmp_eq_r2_187[] = {
  0x08, 0xbf, 0xbb, 0x2a // It eq; cmp eq r2 187
};
const byte kInstruction_cmp_ne_r5_226[] = {
  0x18, 0xbf, 0xe2, 0x2d // It ne; cmp ne r5 226
};
const byte kInstruction_cmp_ge_r1_250[] = {
  0xa8, 0xbf, 0xfa, 0x29 // It ge; cmp ge r1 250
};
const byte kInstruction_cmp_lt_r7_97[] = {
  0xb8, 0xbf, 0x61, 0x2f // It lt; cmp lt r7 97
};
const byte kInstruction_cmp_cs_r4_21[] = {
  0x28, 0xbf, 0x15, 0x2c // It cs; cmp cs r4 21
};
const byte kInstruction_cmp_vc_r0_217[] = {
  0x78, 0xbf, 0xd9, 0x28 // It vc; cmp vc r0 217
};
const byte kInstruction_cmp_mi_r1_81[] = {
  0x48, 0xbf, 0x51, 0x29 // It mi; cmp mi r1 81
};
const byte kInstruction_cmp_cc_r5_156[] = {
  0x38, 0xbf, 0x9c, 0x2d // It cc; cmp cc r5 156
};
const byte kInstruction_cmp_ne_r7_171[] = {
  0x18, 0xbf, 0xab, 0x2f // It ne; cmp ne r7 171
};
const byte kInstruction_cmp_vs_r2_252[] = {
  0x68, 0xbf, 0xfc, 0x2a // It vs; cmp vs r2 252
};
const byte kInstruction_cmp_lt_r4_103[] = {
  0xb8, 0xbf, 0x67, 0x2c // It lt; cmp lt r4 103
};
const byte kInstruction_cmp_ge_r6_203[] = {
  0xa8, 0xbf, 0xcb, 0x2e // It ge; cmp ge r6 203
};
const byte kInstruction_cmp_ne_r4_234[] = {
  0x18, 0xbf, 0xea, 0x2c // It ne; cmp ne r4 234
};
const byte kInstruction_cmp_mi_r2_27[] = {
  0x48, 0xbf, 0x1b, 0x2a // It mi; cmp mi r2 27
};
const byte kInstruction_cmp_ne_r4_224[] = {
  0x18, 0xbf, 0xe0, 0x2c // It ne; cmp ne r4 224
};
const byte kInstruction_cmp_gt_r3_124[] = {
  0xc8, 0xbf, 0x7c, 0x2b // It gt; cmp gt r3 124
};
const byte kInstruction_cmp_lt_r4_49[] = {
  0xb8, 0xbf, 0x31, 0x2c // It lt; cmp lt r4 49
};
const byte kInstruction_cmp_gt_r1_201[] = {
  0xc8, 0xbf, 0xc9, 0x29 // It gt; cmp gt r1 201
};
const byte kInstruction_cmp_ge_r4_133[] = {
  0xa8, 0xbf, 0x85, 0x2c // It ge; cmp ge r4 133
};
const byte kInstruction_cmp_hi_r4_176[] = {
  0x88, 0xbf, 0xb0, 0x2c // It hi; cmp hi r4 176
};
const byte kInstruction_cmp_pl_r3_94[] = {
  0x58, 0xbf, 0x5e, 0x2b // It pl; cmp pl r3 94
};
const byte kInstruction_cmp_le_r2_69[] = {
  0xd8, 0xbf, 0x45, 0x2a // It le; cmp le r2 69
};
const byte kInstruction_cmp_hi_r0_145[] = {
  0x88, 0xbf, 0x91, 0x28 // It hi; cmp hi r0 145
};
const byte kInstruction_cmp_ne_r1_119[] = {
  0x18, 0xbf, 0x77, 0x29 // It ne; cmp ne r1 119
};
const byte kInstruction_cmp_hi_r0_124[] = {
  0x88, 0xbf, 0x7c, 0x28 // It hi; cmp hi r0 124
};
const byte kInstruction_cmp_vc_r6_221[] = {
  0x78, 0xbf, 0xdd, 0x2e // It vc; cmp vc r6 221
};
const byte kInstruction_cmp_cs_r2_71[] = {
  0x28, 0xbf, 0x47, 0x2a // It cs; cmp cs r2 71
};
const byte kInstruction_cmp_eq_r0_87[] = {
  0x08, 0xbf, 0x57, 0x28 // It eq; cmp eq r0 87
};
const byte kInstruction_cmp_cc_r3_42[] = {
  0x38, 0xbf, 0x2a, 0x2b // It cc; cmp cc r3 42
};
const byte kInstruction_cmp_cs_r7_98[] = {
  0x28, 0xbf, 0x62, 0x2f // It cs; cmp cs r7 98
};
const byte kInstruction_cmp_vc_r3_28[] = {
  0x78, 0xbf, 0x1c, 0x2b // It vc; cmp vc r3 28
};
const byte kInstruction_cmp_eq_r4_94[] = {
  0x08, 0xbf, 0x5e, 0x2c // It eq; cmp eq r4 94
};
const byte kInstruction_cmp_gt_r7_84[] = {
  0xc8, 0xbf, 0x54, 0x2f // It gt; cmp gt r7 84
};
const byte kInstruction_cmp_hi_r3_101[] = {
  0x88, 0xbf, 0x65, 0x2b // It hi; cmp hi r3 101
};
const byte kInstruction_cmp_pl_r5_197[] = {
  0x58, 0xbf, 0xc5, 0x2d // It pl; cmp pl r5 197
};
const byte kInstruction_cmp_pl_r6_214[] = {
  0x58, 0xbf, 0xd6, 0x2e // It pl; cmp pl r6 214
};
const byte kInstruction_cmp_hi_r7_32[] = {
  0x88, 0xbf, 0x20, 0x2f // It hi; cmp hi r7 32
};
const byte kInstruction_cmp_ge_r7_217[] = {
  0xa8, 0xbf, 0xd9, 0x2f // It ge; cmp ge r7 217
};
const byte kInstruction_cmp_cc_r3_21[] = {
  0x38, 0xbf, 0x15, 0x2b // It cc; cmp cc r3 21
};
const byte kInstruction_cmp_le_r2_216[] = {
  0xd8, 0xbf, 0xd8, 0x2a // It le; cmp le r2 216
};
const byte kInstruction_cmp_le_r5_199[] = {
  0xd8, 0xbf, 0xc7, 0x2d // It le; cmp le r5 199
};
const byte kInstruction_cmp_cc_r3_162[] = {
  0x38, 0xbf, 0xa2, 0x2b // It cc; cmp cc r3 162
};
const byte kInstruction_cmp_cs_r5_39[] = {
  0x28, 0xbf, 0x27, 0x2d // It cs; cmp cs r5 39
};
const byte kInstruction_cmp_cc_r5_204[] = {
  0x38, 0xbf, 0xcc, 0x2d // It cc; cmp cc r5 204
};
const byte kInstruction_cmp_ge_r1_182[] = {
  0xa8, 0xbf, 0xb6, 0x29 // It ge; cmp ge r1 182
};
const byte kInstruction_cmp_ne_r5_12[] = {
  0x18, 0xbf, 0x0c, 0x2d // It ne; cmp ne r5 12
};
const byte kInstruction_cmp_lt_r4_39[] = {
  0xb8, 0xbf, 0x27, 0x2c // It lt; cmp lt r4 39
};
const byte kInstruction_cmp_vc_r5_205[] = {
  0x78, 0xbf, 0xcd, 0x2d // It vc; cmp vc r5 205
};
const byte kInstruction_cmp_cc_r7_36[] = {
  0x38, 0xbf, 0x24, 0x2f // It cc; cmp cc r7 36
};
const byte kInstruction_cmp_pl_r1_121[] = {
  0x58, 0xbf, 0x79, 0x29 // It pl; cmp pl r1 121
};
const byte kInstruction_cmp_lt_r3_206[] = {
  0xb8, 0xbf, 0xce, 0x2b // It lt; cmp lt r3 206
};
const byte kInstruction_cmp_ne_r5_130[] = {
  0x18, 0xbf, 0x82, 0x2d // It ne; cmp ne r5 130
};
const byte kInstruction_cmp_pl_r2_84[] = {
  0x58, 0xbf, 0x54, 0x2a // It pl; cmp pl r2 84
};
const byte kInstruction_cmp_pl_r5_180[] = {
  0x58, 0xbf, 0xb4, 0x2d // It pl; cmp pl r5 180
};
const byte kInstruction_cmp_ne_r1_126[] = {
  0x18, 0xbf, 0x7e, 0x29 // It ne; cmp ne r1 126
};
const byte kInstruction_cmp_ge_r5_91[] = {
  0xa8, 0xbf, 0x5b, 0x2d // It ge; cmp ge r5 91
};
const byte kInstruction_cmp_pl_r6_48[] = {
  0x58, 0xbf, 0x30, 0x2e // It pl; cmp pl r6 48
};
const byte kInstruction_cmp_mi_r3_241[] = {
  0x48, 0xbf, 0xf1, 0x2b // It mi; cmp mi r3 241
};
const byte kInstruction_cmp_le_r3_197[] = {
  0xd8, 0xbf, 0xc5, 0x2b // It le; cmp le r3 197
};
const byte kInstruction_cmp_gt_r3_154[] = {
  0xc8, 0xbf, 0x9a, 0x2b // It gt; cmp gt r3 154
};
const byte kInstruction_cmp_vc_r1_31[] = {
  0x78, 0xbf, 0x1f, 0x29 // It vc; cmp vc r1 31
};
const byte kInstruction_cmp_ls_r4_218[] = {
  0x98, 0xbf, 0xda, 0x2c // It ls; cmp ls r4 218
};
const byte kInstruction_cmp_ne_r0_237[] = {
  0x18, 0xbf, 0xed, 0x28 // It ne; cmp ne r0 237
};
const byte kInstruction_cmp_ge_r0_171[] = {
  0xa8, 0xbf, 0xab, 0x28 // It ge; cmp ge r0 171
};
const byte kInstruction_cmp_cc_r7_102[] = {
  0x38, 0xbf, 0x66, 0x2f // It cc; cmp cc r7 102
};
const byte kInstruction_cmp_ge_r5_245[] = {
  0xa8, 0xbf, 0xf5, 0x2d // It ge; cmp ge r5 245
};
const byte kInstruction_cmp_ne_r4_28[] = {
  0x18, 0xbf, 0x1c, 0x2c // It ne; cmp ne r4 28
};
const byte kInstruction_cmp_cs_r7_186[] = {
  0x28, 0xbf, 0xba, 0x2f // It cs; cmp cs r7 186
};
const byte kInstruction_cmp_ls_r0_30[] = {
  0x98, 0xbf, 0x1e, 0x28 // It ls; cmp ls r0 30
};
const byte kInstruction_cmp_ge_r1_17[] = {
  0xa8, 0xbf, 0x11, 0x29 // It ge; cmp ge r1 17
};
const byte kInstruction_cmp_cc_r5_92[] = {
  0x38, 0xbf, 0x5c, 0x2d // It cc; cmp cc r5 92
};
const byte kInstruction_cmp_mi_r1_71[] = {
  0x48, 0xbf, 0x47, 0x29 // It mi; cmp mi r1 71
};
const byte kInstruction_cmp_vs_r4_250[] = {
  0x68, 0xbf, 0xfa, 0x2c // It vs; cmp vs r4 250
};
const byte kInstruction_cmp_le_r3_170[] = {
  0xd8, 0xbf, 0xaa, 0x2b // It le; cmp le r3 170
};
const byte kInstruction_cmp_mi_r3_64[] = {
  0x48, 0xbf, 0x40, 0x2b // It mi; cmp mi r3 64
};
const byte kInstruction_cmp_ls_r2_177[] = {
  0x98, 0xbf, 0xb1, 0x2a // It ls; cmp ls r2 177
};
const byte kInstruction_cmp_vs_r5_70[] = {
  0x68, 0xbf, 0x46, 0x2d // It vs; cmp vs r5 70
};
const byte kInstruction_cmp_vs_r4_51[] = {
  0x68, 0xbf, 0x33, 0x2c // It vs; cmp vs r4 51
};
const byte kInstruction_cmp_vs_r3_176[] = {
  0x68, 0xbf, 0xb0, 0x2b // It vs; cmp vs r3 176
};
const byte kInstruction_cmp_le_r1_101[] = {
  0xd8, 0xbf, 0x65, 0x29 // It le; cmp le r1 101
};
const byte kInstruction_cmp_ne_r3_74[] = {
  0x18, 0xbf, 0x4a, 0x2b // It ne; cmp ne r3 74
};
const byte kInstruction_cmp_ge_r0_210[] = {
  0xa8, 0xbf, 0xd2, 0x28 // It ge; cmp ge r0 210
};
const byte kInstruction_cmp_gt_r1_181[] = {
  0xc8, 0xbf, 0xb5, 0x29 // It gt; cmp gt r1 181
};
const byte kInstruction_cmp_eq_r7_223[] = {
  0x08, 0xbf, 0xdf, 0x2f // It eq; cmp eq r7 223
};
const byte kInstruction_cmp_ge_r3_175[] = {
  0xa8, 0xbf, 0xaf, 0x2b // It ge; cmp ge r3 175
};
const byte kInstruction_cmp_eq_r3_106[] = {
  0x08, 0xbf, 0x6a, 0x2b // It eq; cmp eq r3 106
};
const byte kInstruction_cmp_ge_r5_127[] = {
  0xa8, 0xbf, 0x7f, 0x2d // It ge; cmp ge r5 127
};
const byte kInstruction_cmp_cc_r5_59[] = {
  0x38, 0xbf, 0x3b, 0x2d // It cc; cmp cc r5 59
};
const byte kInstruction_cmp_cs_r4_0[] = {
  0x28, 0xbf, 0x00, 0x2c // It cs; cmp cs r4 0
};
const byte kInstruction_cmp_gt_r6_133[] = {
  0xc8, 0xbf, 0x85, 0x2e // It gt; cmp gt r6 133
};
const byte kInstruction_cmp_ls_r1_56[] = {
  0x98, 0xbf, 0x38, 0x29 // It ls; cmp ls r1 56
};
const byte kInstruction_cmp_le_r3_25[] = {
  0xd8, 0xbf, 0x19, 0x2b // It le; cmp le r3 25
};
const byte kInstruction_cmp_vc_r1_24[] = {
  0x78, 0xbf, 0x18, 0x29 // It vc; cmp vc r1 24
};
const byte kInstruction_cmp_eq_r2_59[] = {
  0x08, 0xbf, 0x3b, 0x2a // It eq; cmp eq r2 59
};
const byte kInstruction_cmp_eq_r3_35[] = {
  0x08, 0xbf, 0x23, 0x2b // It eq; cmp eq r3 35
};
const byte kInstruction_cmp_ls_r1_68[] = {
  0x98, 0xbf, 0x44, 0x29 // It ls; cmp ls r1 68
};
const byte kInstruction_cmp_hi_r5_240[] = {
  0x88, 0xbf, 0xf0, 0x2d // It hi; cmp hi r5 240
};
const byte kInstruction_cmp_ls_r1_58[] = {
  0x98, 0xbf, 0x3a, 0x29 // It ls; cmp ls r1 58
};
const byte kInstruction_cmp_cc_r7_207[] = {
  0x38, 0xbf, 0xcf, 0x2f // It cc; cmp cc r7 207
};
const byte kInstruction_cmp_ls_r6_138[] = {
  0x98, 0xbf, 0x8a, 0x2e // It ls; cmp ls r6 138
};
const byte kInstruction_cmp_lt_r5_192[] = {
  0xb8, 0xbf, 0xc0, 0x2d // It lt; cmp lt r5 192
};
const byte kInstruction_cmp_ne_r7_210[] = {
  0x18, 0xbf, 0xd2, 0x2f // It ne; cmp ne r7 210
};
const byte kInstruction_cmp_eq_r3_82[] = {
  0x08, 0xbf, 0x52, 0x2b // It eq; cmp eq r3 82
};
const byte kInstruction_cmp_gt_r3_174[] = {
  0xc8, 0xbf, 0xae, 0x2b // It gt; cmp gt r3 174
};
const byte kInstruction_cmp_ge_r6_10[] = {
  0xa8, 0xbf, 0x0a, 0x2e // It ge; cmp ge r6 10
};
const byte kInstruction_cmp_vs_r3_113[] = {
  0x68, 0xbf, 0x71, 0x2b // It vs; cmp vs r3 113
};
const byte kInstruction_cmp_hi_r2_102[] = {
  0x88, 0xbf, 0x66, 0x2a // It hi; cmp hi r2 102
};
const byte kInstruction_cmp_le_r1_81[] = {
  0xd8, 0xbf, 0x51, 0x29 // It le; cmp le r1 81
};
const byte kInstruction_cmp_vc_r3_8[] = {
  0x78, 0xbf, 0x08, 0x2b // It vc; cmp vc r3 8
};
const byte kInstruction_cmp_mi_r4_60[] = {
  0x48, 0xbf, 0x3c, 0x2c // It mi; cmp mi r4 60
};
const byte kInstruction_cmp_pl_r7_133[] = {
  0x58, 0xbf, 0x85, 0x2f // It pl; cmp pl r7 133
};
const byte kInstruction_cmp_le_r0_41[] = {
  0xd8, 0xbf, 0x29, 0x28 // It le; cmp le r0 41
};
const byte kInstruction_cmp_vc_r6_4[] = {
  0x78, 0xbf, 0x04, 0x2e // It vc; cmp vc r6 4
};
const byte kInstruction_cmp_ls_r7_243[] = {
  0x98, 0xbf, 0xf3, 0x2f // It ls; cmp ls r7 243
};
const byte kInstruction_cmp_mi_r3_129[] = {
  0x48, 0xbf, 0x81, 0x2b // It mi; cmp mi r3 129
};
const byte kInstruction_cmp_eq_r6_3[] = {
  0x08, 0xbf, 0x03, 0x2e // It eq; cmp eq r6 3
};
const byte kInstruction_cmp_ge_r0_28[] = {
  0xa8, 0xbf, 0x1c, 0x28 // It ge; cmp ge r0 28
};
const byte kInstruction_cmp_pl_r3_129[] = {
  0x58, 0xbf, 0x81, 0x2b // It pl; cmp pl r3 129
};
const byte kInstruction_cmp_ne_r6_202[] = {
  0x18, 0xbf, 0xca, 0x2e // It ne; cmp ne r6 202
};
const byte kInstruction_cmp_gt_r0_84[] = {
  0xc8, 0xbf, 0x54, 0x28 // It gt; cmp gt r0 84
};
const byte kInstruction_cmp_hi_r7_3[] = {
  0x88, 0xbf, 0x03, 0x2f // It hi; cmp hi r7 3
};
const byte kInstruction_cmp_vs_r1_14[] = {
  0x68, 0xbf, 0x0e, 0x29 // It vs; cmp vs r1 14
};
const byte kInstruction_cmp_eq_r3_107[] = {
  0x08, 0xbf, 0x6b, 0x2b // It eq; cmp eq r3 107
};
const byte kInstruction_cmp_pl_r1_57[] = {
  0x58, 0xbf, 0x39, 0x29 // It pl; cmp pl r1 57
};
const byte kInstruction_cmp_pl_r0_138[] = {
  0x58, 0xbf, 0x8a, 0x28 // It pl; cmp pl r0 138
};
const byte kInstruction_cmp_cs_r6_158[] = {
  0x28, 0xbf, 0x9e, 0x2e // It cs; cmp cs r6 158
};
const byte kInstruction_cmp_ne_r2_120[] = {
  0x18, 0xbf, 0x78, 0x2a // It ne; cmp ne r2 120
};
const byte kInstruction_cmp_ge_r1_132[] = {
  0xa8, 0xbf, 0x84, 0x29 // It ge; cmp ge r1 132
};
const byte kInstruction_cmp_hi_r6_204[] = {
  0x88, 0xbf, 0xcc, 0x2e // It hi; cmp hi r6 204
};
const byte kInstruction_cmp_ge_r5_228[] = {
  0xa8, 0xbf, 0xe4, 0x2d // It ge; cmp ge r5 228
};
const byte kInstruction_cmp_gt_r5_55[] = {
  0xc8, 0xbf, 0x37, 0x2d // It gt; cmp gt r5 55
};
const byte kInstruction_cmp_vc_r7_55[] = {
  0x78, 0xbf, 0x37, 0x2f // It vc; cmp vc r7 55
};
const byte kInstruction_cmp_ge_r3_90[] = {
  0xa8, 0xbf, 0x5a, 0x2b // It ge; cmp ge r3 90
};
const byte kInstruction_cmp_vs_r7_252[] = {
  0x68, 0xbf, 0xfc, 0x2f // It vs; cmp vs r7 252
};
const byte kInstruction_cmp_le_r5_168[] = {
  0xd8, 0xbf, 0xa8, 0x2d // It le; cmp le r5 168
};
const byte kInstruction_cmp_vc_r6_9[] = {
  0x78, 0xbf, 0x09, 0x2e // It vc; cmp vc r6 9
};
const byte kInstruction_cmp_eq_r7_153[] = {
  0x08, 0xbf, 0x99, 0x2f // It eq; cmp eq r7 153
};
const byte kInstruction_cmp_cs_r2_129[] = {
  0x28, 0xbf, 0x81, 0x2a // It cs; cmp cs r2 129
};
const byte kInstruction_cmp_eq_r4_232[] = {
  0x08, 0xbf, 0xe8, 0x2c // It eq; cmp eq r4 232
};
const byte kInstruction_cmp_le_r3_86[] = {
  0xd8, 0xbf, 0x56, 0x2b // It le; cmp le r3 86
};
const byte kInstruction_cmp_vs_r1_138[] = {
  0x68, 0xbf, 0x8a, 0x29 // It vs; cmp vs r1 138
};
const byte kInstruction_cmp_vs_r6_107[] = {
  0x68, 0xbf, 0x6b, 0x2e // It vs; cmp vs r6 107
};
const byte kInstruction_cmp_gt_r0_59[] = {
  0xc8, 0xbf, 0x3b, 0x28 // It gt; cmp gt r0 59
};
const byte kInstruction_cmp_mi_r3_81[] = {
  0x48, 0xbf, 0x51, 0x2b // It mi; cmp mi r3 81
};
const byte kInstruction_cmp_le_r5_74[] = {
  0xd8, 0xbf, 0x4a, 0x2d // It le; cmp le r5 74
};
const byte kInstruction_cmp_le_r6_207[] = {
  0xd8, 0xbf, 0xcf, 0x2e // It le; cmp le r6 207
};
const byte kInstruction_cmp_vs_r0_64[] = {
  0x68, 0xbf, 0x40, 0x28 // It vs; cmp vs r0 64
};
const byte kInstruction_cmp_le_r7_146[] = {
  0xd8, 0xbf, 0x92, 0x2f // It le; cmp le r7 146
};
const byte kInstruction_cmp_cc_r4_160[] = {
  0x38, 0xbf, 0xa0, 0x2c // It cc; cmp cc r4 160
};
const byte kInstruction_cmp_vs_r5_10[] = {
  0x68, 0xbf, 0x0a, 0x2d // It vs; cmp vs r5 10
};
const byte kInstruction_cmp_gt_r2_126[] = {
  0xc8, 0xbf, 0x7e, 0x2a // It gt; cmp gt r2 126
};
const byte kInstruction_cmp_le_r0_94[] = {
  0xd8, 0xbf, 0x5e, 0x28 // It le; cmp le r0 94
};
const byte kInstruction_cmp_ne_r6_168[] = {
  0x18, 0xbf, 0xa8, 0x2e // It ne; cmp ne r6 168
};
const byte kInstruction_cmp_cc_r4_34[] = {
  0x38, 0xbf, 0x22, 0x2c // It cc; cmp cc r4 34
};
const byte kInstruction_cmp_hi_r5_197[] = {
  0x88, 0xbf, 0xc5, 0x2d // It hi; cmp hi r5 197
};
const byte kInstruction_cmp_eq_r0_103[] = {
  0x08, 0xbf, 0x67, 0x28 // It eq; cmp eq r0 103
};
const byte kInstruction_cmp_cs_r4_32[] = {
  0x28, 0xbf, 0x20, 0x2c // It cs; cmp cs r4 32
};
const byte kInstruction_cmp_hi_r7_221[] = {
  0x88, 0xbf, 0xdd, 0x2f // It hi; cmp hi r7 221
};
const byte kInstruction_cmp_mi_r0_0[] = {
  0x48, 0xbf, 0x00, 0x28 // It mi; cmp mi r0 0
};
const byte kInstruction_cmp_pl_r0_163[] = {
  0x58, 0xbf, 0xa3, 0x28 // It pl; cmp pl r0 163
};
const byte kInstruction_cmp_cc_r2_167[] = {
  0x38, 0xbf, 0xa7, 0x2a // It cc; cmp cc r2 167
};
const byte kInstruction_cmp_gt_r4_37[] = {
  0xc8, 0xbf, 0x25, 0x2c // It gt; cmp gt r4 37
};
const byte kInstruction_cmp_mi_r5_35[] = {
  0x48, 0xbf, 0x23, 0x2d // It mi; cmp mi r5 35
};
const byte kInstruction_cmp_cc_r7_131[] = {
  0x38, 0xbf, 0x83, 0x2f // It cc; cmp cc r7 131
};
const byte kInstruction_cmp_pl_r4_187[] = {
  0x58, 0xbf, 0xbb, 0x2c // It pl; cmp pl r4 187
};
const byte kInstruction_cmp_ls_r2_26[] = {
  0x98, 0xbf, 0x1a, 0x2a // It ls; cmp ls r2 26
};
const byte kInstruction_cmp_mi_r7_10[] = {
  0x48, 0xbf, 0x0a, 0x2f // It mi; cmp mi r7 10
};
const byte kInstruction_cmp_le_r2_113[] = {
  0xd8, 0xbf, 0x71, 0x2a // It le; cmp le r2 113
};
const byte kInstruction_cmp_vc_r2_26[] = {
  0x78, 0xbf, 0x1a, 0x2a // It vc; cmp vc r2 26
};
const byte kInstruction_cmp_vs_r1_255[] = {
  0x68, 0xbf, 0xff, 0x29 // It vs; cmp vs r1 255
};
const byte kInstruction_cmp_ls_r5_238[] = {
  0x98, 0xbf, 0xee, 0x2d // It ls; cmp ls r5 238
};
const byte kInstruction_cmp_ge_r0_86[] = {
  0xa8, 0xbf, 0x56, 0x28 // It ge; cmp ge r0 86
};
const byte kInstruction_cmp_gt_r0_104[] = {
  0xc8, 0xbf, 0x68, 0x28 // It gt; cmp gt r0 104
};
const byte kInstruction_cmp_eq_r2_78[] = {
  0x08, 0xbf, 0x4e, 0x2a // It eq; cmp eq r2 78
};
const byte kInstruction_cmp_cc_r1_102[] = {
  0x38, 0xbf, 0x66, 0x29 // It cc; cmp cc r1 102
};
const byte kInstruction_cmp_cc_r0_16[] = {
  0x38, 0xbf, 0x10, 0x28 // It cc; cmp cc r0 16
};
const byte kInstruction_cmp_mi_r4_48[] = {
  0x48, 0xbf, 0x30, 0x2c // It mi; cmp mi r4 48
};
const byte kInstruction_cmp_cc_r2_210[] = {
  0x38, 0xbf, 0xd2, 0x2a // It cc; cmp cc r2 210
};
const byte kInstruction_cmp_hi_r5_184[] = {
  0x88, 0xbf, 0xb8, 0x2d // It hi; cmp hi r5 184
};
const byte kInstruction_cmp_vs_r5_156[] = {
  0x68, 0xbf, 0x9c, 0x2d // It vs; cmp vs r5 156
};
const byte kInstruction_cmp_cc_r2_241[] = {
  0x38, 0xbf, 0xf1, 0x2a // It cc; cmp cc r2 241
};
const byte kInstruction_cmp_le_r5_169[] = {
  0xd8, 0xbf, 0xa9, 0x2d // It le; cmp le r5 169
};
const byte kInstruction_cmp_pl_r5_114[] = {
  0x58, 0xbf, 0x72, 0x2d // It pl; cmp pl r5 114
};
const byte kInstruction_cmp_eq_r6_200[] = {
  0x08, 0xbf, 0xc8, 0x2e // It eq; cmp eq r6 200
};
const byte kInstruction_cmp_vs_r4_174[] = {
  0x68, 0xbf, 0xae, 0x2c // It vs; cmp vs r4 174
};
const byte kInstruction_cmp_vc_r5_233[] = {
  0x78, 0xbf, 0xe9, 0x2d // It vc; cmp vc r5 233
};
const byte kInstruction_cmp_hi_r2_233[] = {
  0x88, 0xbf, 0xe9, 0x2a // It hi; cmp hi r2 233
};
const byte kInstruction_cmp_ne_r5_210[] = {
  0x18, 0xbf, 0xd2, 0x2d // It ne; cmp ne r5 210
};
const byte kInstruction_cmp_le_r1_109[] = {
  0xd8, 0xbf, 0x6d, 0x29 // It le; cmp le r1 109
};
const byte kInstruction_cmp_eq_r7_188[] = {
  0x08, 0xbf, 0xbc, 0x2f // It eq; cmp eq r7 188
};
const byte kInstruction_cmp_hi_r2_66[] = {
  0x88, 0xbf, 0x42, 0x2a // It hi; cmp hi r2 66
};
const byte kInstruction_cmp_le_r7_109[] = {
  0xd8, 0xbf, 0x6d, 0x2f // It le; cmp le r7 109
};
const byte kInstruction_cmp_ge_r6_175[] = {
  0xa8, 0xbf, 0xaf, 0x2e // It ge; cmp ge r6 175
};
const byte kInstruction_cmp_mi_r2_25[] = {
  0x48, 0xbf, 0x19, 0x2a // It mi; cmp mi r2 25
};
const byte kInstruction_cmp_pl_r2_137[] = {
  0x58, 0xbf, 0x89, 0x2a // It pl; cmp pl r2 137
};
const byte kInstruction_cmp_pl_r0_249[] = {
  0x58, 0xbf, 0xf9, 0x28 // It pl; cmp pl r0 249
};
const byte kInstruction_cmp_lt_r1_139[] = {
  0xb8, 0xbf, 0x8b, 0x29 // It lt; cmp lt r1 139
};
const byte kInstruction_cmp_cs_r2_165[] = {
  0x28, 0xbf, 0xa5, 0x2a // It cs; cmp cs r2 165
};
const byte kInstruction_cmp_ne_r6_174[] = {
  0x18, 0xbf, 0xae, 0x2e // It ne; cmp ne r6 174
};
const byte kInstruction_cmp_le_r7_90[] = {
  0xd8, 0xbf, 0x5a, 0x2f // It le; cmp le r7 90
};
const byte kInstruction_cmp_gt_r5_67[] = {
  0xc8, 0xbf, 0x43, 0x2d // It gt; cmp gt r5 67
};
const byte kInstruction_cmp_gt_r0_175[] = {
  0xc8, 0xbf, 0xaf, 0x28 // It gt; cmp gt r0 175
};
const byte kInstruction_cmp_hi_r3_81[] = {
  0x88, 0xbf, 0x51, 0x2b // It hi; cmp hi r3 81
};
const byte kInstruction_cmp_le_r4_144[] = {
  0xd8, 0xbf, 0x90, 0x2c // It le; cmp le r4 144
};
const byte kInstruction_cmp_vs_r4_23[] = {
  0x68, 0xbf, 0x17, 0x2c // It vs; cmp vs r4 23
};
const byte kInstruction_cmp_eq_r7_85[] = {
  0x08, 0xbf, 0x55, 0x2f // It eq; cmp eq r7 85
};
const byte kInstruction_cmp_eq_r7_202[] = {
  0x08, 0xbf, 0xca, 0x2f // It eq; cmp eq r7 202
};
const byte kInstruction_cmp_cs_r1_201[] = {
  0x28, 0xbf, 0xc9, 0x29 // It cs; cmp cs r1 201
};
const byte kInstruction_cmp_lt_r4_67[] = {
  0xb8, 0xbf, 0x43, 0x2c // It lt; cmp lt r4 67
};
const byte kInstruction_cmp_pl_r2_206[] = {
  0x58, 0xbf, 0xce, 0x2a // It pl; cmp pl r2 206
};
const byte kInstruction_cmp_vc_r0_87[] = {
  0x78, 0xbf, 0x57, 0x28 // It vc; cmp vc r0 87
};
const byte kInstruction_cmp_lt_r1_35[] = {
  0xb8, 0xbf, 0x23, 0x29 // It lt; cmp lt r1 35
};
const byte kInstruction_cmp_pl_r7_192[] = {
  0x58, 0xbf, 0xc0, 0x2f // It pl; cmp pl r7 192
};
const byte kInstruction_cmp_cc_r5_213[] = {
  0x38, 0xbf, 0xd5, 0x2d // It cc; cmp cc r5 213
};
const byte kInstruction_cmp_vs_r5_86[] = {
  0x68, 0xbf, 0x56, 0x2d // It vs; cmp vs r5 86
};
const byte kInstruction_cmp_ls_r1_182[] = {
  0x98, 0xbf, 0xb6, 0x29 // It ls; cmp ls r1 182
};
const byte kInstruction_cmp_vc_r0_227[] = {
  0x78, 0xbf, 0xe3, 0x28 // It vc; cmp vc r0 227
};
const byte kInstruction_cmp_cs_r1_206[] = {
  0x28, 0xbf, 0xce, 0x29 // It cs; cmp cs r1 206
};
const byte kInstruction_cmp_vs_r7_194[] = {
  0x68, 0xbf, 0xc2, 0x2f // It vs; cmp vs r7 194
};
const byte kInstruction_cmp_gt_r1_242[] = {
  0xc8, 0xbf, 0xf2, 0x29 // It gt; cmp gt r1 242
};
const byte kInstruction_cmp_le_r3_222[] = {
  0xd8, 0xbf, 0xde, 0x2b // It le; cmp le r3 222
};
const byte kInstruction_cmp_mi_r2_194[] = {
  0x48, 0xbf, 0xc2, 0x2a // It mi; cmp mi r2 194
};
const byte kInstruction_cmp_vs_r2_19[] = {
  0x68, 0xbf, 0x13, 0x2a // It vs; cmp vs r2 19
};
const byte kInstruction_cmp_cs_r6_230[] = {
  0x28, 0xbf, 0xe6, 0x2e // It cs; cmp cs r6 230
};
const byte kInstruction_cmp_ls_r1_141[] = {
  0x98, 0xbf, 0x8d, 0x29 // It ls; cmp ls r1 141
};
const byte kInstruction_cmp_le_r1_144[] = {
  0xd8, 0xbf, 0x90, 0x29 // It le; cmp le r1 144
};
const byte kInstruction_cmp_ls_r1_184[] = {
  0x98, 0xbf, 0xb8, 0x29 // It ls; cmp ls r1 184
};
const byte kInstruction_cmp_pl_r0_175[] = {
  0x58, 0xbf, 0xaf, 0x28 // It pl; cmp pl r0 175
};
const byte kInstruction_cmp_cs_r3_0[] = {
  0x28, 0xbf, 0x00, 0x2b // It cs; cmp cs r3 0
};
const byte kInstruction_cmp_cs_r0_142[] = {
  0x28, 0xbf, 0x8e, 0x28 // It cs; cmp cs r0 142
};
const byte kInstruction_cmp_le_r4_5[] = {
  0xd8, 0xbf, 0x05, 0x2c // It le; cmp le r4 5
};
const byte kInstruction_cmp_pl_r4_123[] = {
  0x58, 0xbf, 0x7b, 0x2c // It pl; cmp pl r4 123
};
const byte kInstruction_cmp_cs_r3_128[] = {
  0x28, 0xbf, 0x80, 0x2b // It cs; cmp cs r3 128
};
const byte kInstruction_cmp_pl_r7_112[] = {
  0x58, 0xbf, 0x70, 0x2f // It pl; cmp pl r7 112
};
const byte kInstruction_cmp_vs_r2_186[] = {
  0x68, 0xbf, 0xba, 0x2a // It vs; cmp vs r2 186
};
const byte kInstruction_cmp_pl_r6_200[] = {
  0x58, 0xbf, 0xc8, 0x2e // It pl; cmp pl r6 200
};
const byte kInstruction_cmp_ne_r7_200[] = {
  0x18, 0xbf, 0xc8, 0x2f // It ne; cmp ne r7 200
};
const byte kInstruction_cmp_le_r6_223[] = {
  0xd8, 0xbf, 0xdf, 0x2e // It le; cmp le r6 223
};
const byte kInstruction_cmp_vs_r4_117[] = {
  0x68, 0xbf, 0x75, 0x2c // It vs; cmp vs r4 117
};
const byte kInstruction_cmp_cs_r4_6[] = {
  0x28, 0xbf, 0x06, 0x2c // It cs; cmp cs r4 6
};
const byte kInstruction_cmp_ls_r6_86[] = {
  0x98, 0xbf, 0x56, 0x2e // It ls; cmp ls r6 86
};
const byte kInstruction_cmp_cc_r2_37[] = {
  0x38, 0xbf, 0x25, 0x2a // It cc; cmp cc r2 37
};
const byte kInstruction_cmp_ge_r6_28[] = {
  0xa8, 0xbf, 0x1c, 0x2e // It ge; cmp ge r6 28
};
const byte kInstruction_cmp_ls_r3_247[] = {
  0x98, 0xbf, 0xf7, 0x2b // It ls; cmp ls r3 247
};
const byte kInstruction_cmp_ge_r4_193[] = {
  0xa8, 0xbf, 0xc1, 0x2c // It ge; cmp ge r4 193
};
const byte kInstruction_cmp_le_r4_108[] = {
  0xd8, 0xbf, 0x6c, 0x2c // It le; cmp le r4 108
};
const byte kInstruction_cmp_vc_r0_106[] = {
  0x78, 0xbf, 0x6a, 0x28 // It vc; cmp vc r0 106
};
const byte kInstruction_cmp_gt_r0_64[] = {
  0xc8, 0xbf, 0x40, 0x28 // It gt; cmp gt r0 64
};
const byte kInstruction_cmp_pl_r0_247[] = {
  0x58, 0xbf, 0xf7, 0x28 // It pl; cmp pl r0 247
};
const byte kInstruction_cmp_eq_r0_88[] = {
  0x08, 0xbf, 0x58, 0x28 // It eq; cmp eq r0 88
};
const byte kInstruction_cmp_mi_r4_88[] = {
  0x48, 0xbf, 0x58, 0x2c // It mi; cmp mi r4 88
};
const byte kInstruction_cmp_ne_r6_118[] = {
  0x18, 0xbf, 0x76, 0x2e // It ne; cmp ne r6 118
};
const byte kInstruction_cmp_vc_r2_79[] = {
  0x78, 0xbf, 0x4f, 0x2a // It vc; cmp vc r2 79
};
const byte kInstruction_cmp_vc_r0_104[] = {
  0x78, 0xbf, 0x68, 0x28 // It vc; cmp vc r0 104
};
const byte kInstruction_cmp_vs_r3_128[] = {
  0x68, 0xbf, 0x80, 0x2b // It vs; cmp vs r3 128
};
const byte kInstruction_cmp_pl_r1_129[] = {
  0x58, 0xbf, 0x81, 0x29 // It pl; cmp pl r1 129
};
const byte kInstruction_cmp_mi_r6_149[] = {
  0x48, 0xbf, 0x95, 0x2e // It mi; cmp mi r6 149
};
const byte kInstruction_cmp_mi_r4_226[] = {
  0x48, 0xbf, 0xe2, 0x2c // It mi; cmp mi r4 226
};
const byte kInstruction_cmp_pl_r5_232[] = {
  0x58, 0xbf, 0xe8, 0x2d // It pl; cmp pl r5 232
};
const byte kInstruction_cmp_hi_r1_88[] = {
  0x88, 0xbf, 0x58, 0x29 // It hi; cmp hi r1 88
};
const byte kInstruction_cmp_mi_r3_13[] = {
  0x48, 0xbf, 0x0d, 0x2b // It mi; cmp mi r3 13
};
const byte kInstruction_cmp_vs_r1_44[] = {
  0x68, 0xbf, 0x2c, 0x29 // It vs; cmp vs r1 44
};
const byte kInstruction_cmp_le_r3_88[] = {
  0xd8, 0xbf, 0x58, 0x2b // It le; cmp le r3 88
};
const byte kInstruction_cmp_pl_r7_224[] = {
  0x58, 0xbf, 0xe0, 0x2f // It pl; cmp pl r7 224
};
const byte kInstruction_cmp_eq_r2_117[] = {
  0x08, 0xbf, 0x75, 0x2a // It eq; cmp eq r2 117
};
const byte kInstruction_cmp_cc_r5_94[] = {
  0x38, 0xbf, 0x5e, 0x2d // It cc; cmp cc r5 94
};
const byte kInstruction_cmp_gt_r3_43[] = {
  0xc8, 0xbf, 0x2b, 0x2b // It gt; cmp gt r3 43
};
const byte kInstruction_cmp_vs_r4_159[] = {
  0x68, 0xbf, 0x9f, 0x2c // It vs; cmp vs r4 159
};
const byte kInstruction_cmp_mi_r7_205[] = {
  0x48, 0xbf, 0xcd, 0x2f // It mi; cmp mi r7 205
};
const byte kInstruction_cmp_eq_r6_161[] = {
  0x08, 0xbf, 0xa1, 0x2e // It eq; cmp eq r6 161
};
const byte kInstruction_cmp_le_r6_150[] = {
  0xd8, 0xbf, 0x96, 0x2e // It le; cmp le r6 150
};
const byte kInstruction_cmp_ls_r2_144[] = {
  0x98, 0xbf, 0x90, 0x2a // It ls; cmp ls r2 144
};
const byte kInstruction_cmp_le_r2_240[] = {
  0xd8, 0xbf, 0xf0, 0x2a // It le; cmp le r2 240
};
const byte kInstruction_cmp_pl_r1_11[] = {
  0x58, 0xbf, 0x0b, 0x29 // It pl; cmp pl r1 11
};
const byte kInstruction_cmp_pl_r2_116[] = {
  0x58, 0xbf, 0x74, 0x2a // It pl; cmp pl r2 116
};
const byte kInstruction_cmp_ne_r3_122[] = {
  0x18, 0xbf, 0x7a, 0x2b // It ne; cmp ne r3 122
};
const byte kInstruction_cmp_cs_r7_146[] = {
  0x28, 0xbf, 0x92, 0x2f // It cs; cmp cs r7 146
};
const byte kInstruction_cmp_eq_r5_21[] = {
  0x08, 0xbf, 0x15, 0x2d // It eq; cmp eq r5 21
};
const byte kInstruction_cmp_ge_r0_49[] = {
  0xa8, 0xbf, 0x31, 0x28 // It ge; cmp ge r0 49
};
const byte kInstruction_cmp_gt_r2_170[] = {
  0xc8, 0xbf, 0xaa, 0x2a // It gt; cmp gt r2 170
};
const byte kInstruction_cmp_mi_r3_208[] = {
  0x48, 0xbf, 0xd0, 0x2b // It mi; cmp mi r3 208
};
const byte kInstruction_cmp_le_r4_47[] = {
  0xd8, 0xbf, 0x2f, 0x2c // It le; cmp le r4 47
};
const byte kInstruction_cmp_ne_r4_176[] = {
  0x18, 0xbf, 0xb0, 0x2c // It ne; cmp ne r4 176
};
const byte kInstruction_cmp_le_r1_153[] = {
  0xd8, 0xbf, 0x99, 0x29 // It le; cmp le r1 153
};
const byte kInstruction_cmp_cs_r3_136[] = {
  0x28, 0xbf, 0x88, 0x2b // It cs; cmp cs r3 136
};
const byte kInstruction_cmp_le_r7_166[] = {
  0xd8, 0xbf, 0xa6, 0x2f // It le; cmp le r7 166
};
const byte kInstruction_cmp_vc_r2_148[] = {
  0x78, 0xbf, 0x94, 0x2a // It vc; cmp vc r2 148
};
const byte kInstruction_cmp_ge_r6_226[] = {
  0xa8, 0xbf, 0xe2, 0x2e // It ge; cmp ge r6 226
};
const byte kInstruction_cmp_mi_r7_224[] = {
  0x48, 0xbf, 0xe0, 0x2f // It mi; cmp mi r7 224
};
const byte kInstruction_cmp_le_r0_88[] = {
  0xd8, 0xbf, 0x58, 0x28 // It le; cmp le r0 88
};
const byte kInstruction_cmp_lt_r3_131[] = {
  0xb8, 0xbf, 0x83, 0x2b // It lt; cmp lt r3 131
};
const byte kInstruction_cmp_gt_r6_70[] = {
  0xc8, 0xbf, 0x46, 0x2e // It gt; cmp gt r6 70
};
const byte kInstruction_cmp_cc_r5_212[] = {
  0x38, 0xbf, 0xd4, 0x2d // It cc; cmp cc r5 212
};
const byte kInstruction_cmp_pl_r7_184[] = {
  0x58, 0xbf, 0xb8, 0x2f // It pl; cmp pl r7 184
};
const byte kInstruction_cmp_gt_r0_170[] = {
  0xc8, 0xbf, 0xaa, 0x28 // It gt; cmp gt r0 170
};
const byte kInstruction_cmp_ne_r7_227[] = {
  0x18, 0xbf, 0xe3, 0x2f // It ne; cmp ne r7 227
};
const byte kInstruction_cmp_cs_r7_129[] = {
  0x28, 0xbf, 0x81, 0x2f // It cs; cmp cs r7 129
};
const byte kInstruction_cmp_lt_r2_214[] = {
  0xb8, 0xbf, 0xd6, 0x2a // It lt; cmp lt r2 214
};
const byte kInstruction_cmp_le_r3_68[] = {
  0xd8, 0xbf, 0x44, 0x2b // It le; cmp le r3 68
};
const byte kInstruction_cmp_cs_r1_174[] = {
  0x28, 0xbf, 0xae, 0x29 // It cs; cmp cs r1 174
};
const byte kInstruction_cmp_mi_r6_224[] = {
  0x48, 0xbf, 0xe0, 0x2e // It mi; cmp mi r6 224
};
const byte kInstruction_cmp_gt_r3_107[] = {
  0xc8, 0xbf, 0x6b, 0x2b // It gt; cmp gt r3 107
};
const byte kInstruction_cmp_pl_r6_62[] = {
  0x58, 0xbf, 0x3e, 0x2e // It pl; cmp pl r6 62
};
const byte kInstruction_cmp_mi_r2_173[] = {
  0x48, 0xbf, 0xad, 0x2a // It mi; cmp mi r2 173
};
const byte kInstruction_cmp_cs_r3_208[] = {
  0x28, 0xbf, 0xd0, 0x2b // It cs; cmp cs r3 208
};
const byte kInstruction_cmp_cc_r3_214[] = {
  0x38, 0xbf, 0xd6, 0x2b // It cc; cmp cc r3 214
};
const byte kInstruction_cmp_lt_r5_20[] = {
  0xb8, 0xbf, 0x14, 0x2d // It lt; cmp lt r5 20
};
const byte kInstruction_cmp_vs_r2_9[] = {
  0x68, 0xbf, 0x09, 0x2a // It vs; cmp vs r2 9
};
const byte kInstruction_cmp_le_r1_55[] = {
  0xd8, 0xbf, 0x37, 0x29 // It le; cmp le r1 55
};
const byte kInstruction_cmp_vc_r3_14[] = {
  0x78, 0xbf, 0x0e, 0x2b // It vc; cmp vc r3 14
};
const byte kInstruction_cmp_eq_r5_74[] = {
  0x08, 0xbf, 0x4a, 0x2d // It eq; cmp eq r5 74
};
const byte kInstruction_cmp_cs_r0_40[] = {
  0x28, 0xbf, 0x28, 0x28 // It cs; cmp cs r0 40
};
const byte kInstruction_cmp_ge_r6_98[] = {
  0xa8, 0xbf, 0x62, 0x2e // It ge; cmp ge r6 98
};
const byte kInstruction_cmp_cs_r3_79[] = {
  0x28, 0xbf, 0x4f, 0x2b // It cs; cmp cs r3 79
};
const byte kInstruction_cmp_ne_r0_199[] = {
  0x18, 0xbf, 0xc7, 0x28 // It ne; cmp ne r0 199
};
const byte kInstruction_cmp_lt_r0_163[] = {
  0xb8, 0xbf, 0xa3, 0x28 // It lt; cmp lt r0 163
};
const byte kInstruction_cmp_cs_r6_42[] = {
  0x28, 0xbf, 0x2a, 0x2e // It cs; cmp cs r6 42
};
const byte kInstruction_cmp_eq_r6_32[] = {
  0x08, 0xbf, 0x20, 0x2e // It eq; cmp eq r6 32
};
const byte kInstruction_cmp_vs_r1_64[] = {
  0x68, 0xbf, 0x40, 0x29 // It vs; cmp vs r1 64
};
const byte kInstruction_cmp_hi_r4_91[] = {
  0x88, 0xbf, 0x5b, 0x2c // It hi; cmp hi r4 91
};
const byte kInstruction_cmp_ls_r3_79[] = {
  0x98, 0xbf, 0x4f, 0x2b // It ls; cmp ls r3 79
};
const byte kInstruction_cmp_gt_r3_68[] = {
  0xc8, 0xbf, 0x44, 0x2b // It gt; cmp gt r3 68
};
const byte kInstruction_cmp_eq_r0_133[] = {
  0x08, 0xbf, 0x85, 0x28 // It eq; cmp eq r0 133
};
const byte kInstruction_cmp_vs_r4_8[] = {
  0x68, 0xbf, 0x08, 0x2c // It vs; cmp vs r4 8
};
const byte kInstruction_cmp_cs_r2_248[] = {
  0x28, 0xbf, 0xf8, 0x2a // It cs; cmp cs r2 248
};
const byte kInstruction_cmp_cs_r2_153[] = {
  0x28, 0xbf, 0x99, 0x2a // It cs; cmp cs r2 153
};
const byte kInstruction_cmp_cc_r1_21[] = {
  0x38, 0xbf, 0x15, 0x29 // It cc; cmp cc r1 21
};
const byte kInstruction_cmp_mi_r3_171[] = {
  0x48, 0xbf, 0xab, 0x2b // It mi; cmp mi r3 171
};
const byte kInstruction_cmp_gt_r6_126[] = {
  0xc8, 0xbf, 0x7e, 0x2e // It gt; cmp gt r6 126
};
const byte kInstruction_cmp_hi_r0_155[] = {
  0x88, 0xbf, 0x9b, 0x28 // It hi; cmp hi r0 155
};
const byte kInstruction_cmp_cs_r0_224[] = {
  0x28, 0xbf, 0xe0, 0x28 // It cs; cmp cs r0 224
};
const byte kInstruction_cmp_cc_r2_38[] = {
  0x38, 0xbf, 0x26, 0x2a // It cc; cmp cc r2 38
};
const byte kInstruction_cmp_lt_r3_127[] = {
  0xb8, 0xbf, 0x7f, 0x2b // It lt; cmp lt r3 127
};
const byte kInstruction_cmp_gt_r6_21[] = {
  0xc8, 0xbf, 0x15, 0x2e // It gt; cmp gt r6 21
};
const byte kInstruction_cmp_gt_r4_39[] = {
  0xc8, 0xbf, 0x27, 0x2c // It gt; cmp gt r4 39
};
const byte kInstruction_cmp_ge_r4_40[] = {
  0xa8, 0xbf, 0x28, 0x2c // It ge; cmp ge r4 40
};
const byte kInstruction_cmp_hi_r4_228[] = {
  0x88, 0xbf, 0xe4, 0x2c // It hi; cmp hi r4 228
};
const byte kInstruction_cmp_le_r6_51[] = {
  0xd8, 0xbf, 0x33, 0x2e // It le; cmp le r6 51
};
const byte kInstruction_cmp_ge_r3_3[] = {
  0xa8, 0xbf, 0x03, 0x2b // It ge; cmp ge r3 3
};
const byte kInstruction_cmp_ge_r5_24[] = {
  0xa8, 0xbf, 0x18, 0x2d // It ge; cmp ge r5 24
};
const byte kInstruction_cmp_ge_r0_52[] = {
  0xa8, 0xbf, 0x34, 0x28 // It ge; cmp ge r0 52
};
const byte kInstruction_cmp_vs_r6_84[] = {
  0x68, 0xbf, 0x54, 0x2e // It vs; cmp vs r6 84
};
const byte kInstruction_cmp_gt_r7_238[] = {
  0xc8, 0xbf, 0xee, 0x2f // It gt; cmp gt r7 238
};
const byte kInstruction_cmp_pl_r2_118[] = {
  0x58, 0xbf, 0x76, 0x2a // It pl; cmp pl r2 118
};
const byte kInstruction_cmp_cc_r0_96[] = {
  0x38, 0xbf, 0x60, 0x28 // It cc; cmp cc r0 96
};
const byte kInstruction_cmp_gt_r1_241[] = {
  0xc8, 0xbf, 0xf1, 0x29 // It gt; cmp gt r1 241
};
const byte kInstruction_cmp_lt_r5_231[] = {
  0xb8, 0xbf, 0xe7, 0x2d // It lt; cmp lt r5 231
};
const byte kInstruction_cmp_vs_r0_223[] = {
  0x68, 0xbf, 0xdf, 0x28 // It vs; cmp vs r0 223
};
const byte kInstruction_cmp_vc_r6_85[] = {
  0x78, 0xbf, 0x55, 0x2e // It vc; cmp vc r6 85
};
const byte kInstruction_cmp_vs_r4_171[] = {
  0x68, 0xbf, 0xab, 0x2c // It vs; cmp vs r4 171
};
const byte kInstruction_cmp_hi_r7_34[] = {
  0x88, 0xbf, 0x22, 0x2f // It hi; cmp hi r7 34
};
const byte kInstruction_cmp_hi_r4_243[] = {
  0x88, 0xbf, 0xf3, 0x2c // It hi; cmp hi r4 243
};
const byte kInstruction_cmp_cc_r6_16[] = {
  0x38, 0xbf, 0x10, 0x2e // It cc; cmp cc r6 16
};
const byte kInstruction_cmp_cs_r2_179[] = {
  0x28, 0xbf, 0xb3, 0x2a // It cs; cmp cs r2 179
};
const byte kInstruction_cmp_cs_r5_128[] = {
  0x28, 0xbf, 0x80, 0x2d // It cs; cmp cs r5 128
};
const byte kInstruction_cmp_lt_r6_43[] = {
  0xb8, 0xbf, 0x2b, 0x2e // It lt; cmp lt r6 43
};
const byte kInstruction_cmp_lt_r1_116[] = {
  0xb8, 0xbf, 0x74, 0x29 // It lt; cmp lt r1 116
};
const byte kInstruction_cmp_mi_r4_176[] = {
  0x48, 0xbf, 0xb0, 0x2c // It mi; cmp mi r4 176
};
const byte kInstruction_cmp_hi_r3_158[] = {
  0x88, 0xbf, 0x9e, 0x2b // It hi; cmp hi r3 158
};
const byte kInstruction_cmp_cs_r6_21[] = {
  0x28, 0xbf, 0x15, 0x2e // It cs; cmp cs r6 21
};
const byte kInstruction_cmp_ge_r5_114[] = {
  0xa8, 0xbf, 0x72, 0x2d // It ge; cmp ge r5 114
};
const byte kInstruction_cmp_vs_r3_109[] = {
  0x68, 0xbf, 0x6d, 0x2b // It vs; cmp vs r3 109
};
const byte kInstruction_cmp_ne_r4_249[] = {
  0x18, 0xbf, 0xf9, 0x2c // It ne; cmp ne r4 249
};
const byte kInstruction_cmp_ls_r5_96[] = {
  0x98, 0xbf, 0x60, 0x2d // It ls; cmp ls r5 96
};
const byte kInstruction_cmp_hi_r0_135[] = {
  0x88, 0xbf, 0x87, 0x28 // It hi; cmp hi r0 135
};
const byte kInstruction_cmp_vc_r2_63[] = {
  0x78, 0xbf, 0x3f, 0x2a // It vc; cmp vc r2 63
};
const byte kInstruction_cmp_le_r0_169[] = {
  0xd8, 0xbf, 0xa9, 0x28 // It le; cmp le r0 169
};
const byte kInstruction_cmp_vc_r4_230[] = {
  0x78, 0xbf, 0xe6, 0x2c // It vc; cmp vc r4 230
};
const byte kInstruction_cmp_gt_r3_181[] = {
  0xc8, 0xbf, 0xb5, 0x2b // It gt; cmp gt r3 181
};
const byte kInstruction_cmp_eq_r6_202[] = {
  0x08, 0xbf, 0xca, 0x2e // It eq; cmp eq r6 202
};
const byte kInstruction_cmp_mi_r4_57[] = {
  0x48, 0xbf, 0x39, 0x2c // It mi; cmp mi r4 57
};
const byte kInstruction_cmp_lt_r7_220[] = {
  0xb8, 0xbf, 0xdc, 0x2f // It lt; cmp lt r7 220
};
const byte kInstruction_cmp_lt_r3_43[] = {
  0xb8, 0xbf, 0x2b, 0x2b // It lt; cmp lt r3 43
};
const byte kInstruction_cmp_pl_r3_210[] = {
  0x58, 0xbf, 0xd2, 0x2b // It pl; cmp pl r3 210
};
const byte kInstruction_cmp_cc_r4_182[] = {
  0x38, 0xbf, 0xb6, 0x2c // It cc; cmp cc r4 182
};
const byte kInstruction_cmp_vc_r5_105[] = {
  0x78, 0xbf, 0x69, 0x2d // It vc; cmp vc r5 105
};
const byte kInstruction_cmp_ls_r4_150[] = {
  0x98, 0xbf, 0x96, 0x2c // It ls; cmp ls r4 150
};
const byte kInstruction_cmp_ls_r0_2[] = {
  0x98, 0xbf, 0x02, 0x28 // It ls; cmp ls r0 2
};
const byte kInstruction_cmp_eq_r0_0[] = {
  0x08, 0xbf, 0x00, 0x28 // It eq; cmp eq r0 0
};
const byte kInstruction_cmp_cc_r6_204[] = {
  0x38, 0xbf, 0xcc, 0x2e // It cc; cmp cc r6 204
};
const byte kInstruction_cmp_lt_r4_226[] = {
  0xb8, 0xbf, 0xe2, 0x2c // It lt; cmp lt r4 226
};
const byte kInstruction_cmp_pl_r2_37[] = {
  0x58, 0xbf, 0x25, 0x2a // It pl; cmp pl r2 37
};
const byte kInstruction_cmp_ge_r3_208[] = {
  0xa8, 0xbf, 0xd0, 0x2b // It ge; cmp ge r3 208
};
const byte kInstruction_cmp_mi_r1_75[] = {
  0x48, 0xbf, 0x4b, 0x29 // It mi; cmp mi r1 75
};
const byte kInstruction_cmp_hi_r7_249[] = {
  0x88, 0xbf, 0xf9, 0x2f // It hi; cmp hi r7 249
};
const byte kInstruction_cmp_vc_r6_61[] = {
  0x78, 0xbf, 0x3d, 0x2e // It vc; cmp vc r6 61
};
const byte kInstruction_cmp_eq_r1_185[] = {
  0x08, 0xbf, 0xb9, 0x29 // It eq; cmp eq r1 185
};
const byte kInstruction_cmp_vs_r5_55[] = {
  0x68, 0xbf, 0x37, 0x2d // It vs; cmp vs r5 55
};
const byte kInstruction_cmp_pl_r2_243[] = {
  0x58, 0xbf, 0xf3, 0x2a // It pl; cmp pl r2 243
};
const byte kInstruction_cmp_eq_r0_111[] = {
  0x08, 0xbf, 0x6f, 0x28 // It eq; cmp eq r0 111
};
const byte kInstruction_cmp_cc_r5_75[] = {
  0x38, 0xbf, 0x4b, 0x2d // It cc; cmp cc r5 75
};
const byte kInstruction_cmp_mi_r1_103[] = {
  0x48, 0xbf, 0x67, 0x29 // It mi; cmp mi r1 103
};
const byte kInstruction_cmp_mi_r5_201[] = {
  0x48, 0xbf, 0xc9, 0x2d // It mi; cmp mi r5 201
};
const byte kInstruction_cmp_eq_r6_13[] = {
  0x08, 0xbf, 0x0d, 0x2e // It eq; cmp eq r6 13
};
const byte kInstruction_cmp_le_r1_117[] = {
  0xd8, 0xbf, 0x75, 0x29 // It le; cmp le r1 117
};
const byte kInstruction_cmp_le_r4_245[] = {
  0xd8, 0xbf, 0xf5, 0x2c // It le; cmp le r4 245
};
const byte kInstruction_cmp_vc_r5_253[] = {
  0x78, 0xbf, 0xfd, 0x2d // It vc; cmp vc r5 253
};
const byte kInstruction_cmp_vc_r1_245[] = {
  0x78, 0xbf, 0xf5, 0x29 // It vc; cmp vc r1 245
};
const byte kInstruction_cmp_hi_r0_160[] = {
  0x88, 0xbf, 0xa0, 0x28 // It hi; cmp hi r0 160
};
const byte kInstruction_cmp_ne_r6_139[] = {
  0x18, 0xbf, 0x8b, 0x2e // It ne; cmp ne r6 139
};
const byte kInstruction_cmp_cc_r3_71[] = {
  0x38, 0xbf, 0x47, 0x2b // It cc; cmp cc r3 71
};
const byte kInstruction_cmp_lt_r0_155[] = {
  0xb8, 0xbf, 0x9b, 0x28 // It lt; cmp lt r0 155
};
const byte kInstruction_cmp_ls_r4_100[] = {
  0x98, 0xbf, 0x64, 0x2c // It ls; cmp ls r4 100
};
const byte kInstruction_cmp_vs_r5_117[] = {
  0x68, 0xbf, 0x75, 0x2d // It vs; cmp vs r5 117
};
const byte kInstruction_cmp_gt_r7_9[] = {
  0xc8, 0xbf, 0x09, 0x2f // It gt; cmp gt r7 9
};
const byte kInstruction_cmp_lt_r5_30[] = {
  0xb8, 0xbf, 0x1e, 0x2d // It lt; cmp lt r5 30
};
const byte kInstruction_cmp_pl_r6_32[] = {
  0x58, 0xbf, 0x20, 0x2e // It pl; cmp pl r6 32
};
const byte kInstruction_cmp_mi_r1_105[] = {
  0x48, 0xbf, 0x69, 0x29 // It mi; cmp mi r1 105
};
const byte kInstruction_cmp_hi_r1_34[] = {
  0x88, 0xbf, 0x22, 0x29 // It hi; cmp hi r1 34
};
const byte kInstruction_cmp_cs_r7_213[] = {
  0x28, 0xbf, 0xd5, 0x2f // It cs; cmp cs r7 213
};
const byte kInstruction_cmp_le_r7_218[] = {
  0xd8, 0xbf, 0xda, 0x2f // It le; cmp le r7 218
};
const byte kInstruction_cmp_pl_r3_131[] = {
  0x58, 0xbf, 0x83, 0x2b // It pl; cmp pl r3 131
};
const byte kInstruction_cmp_cs_r6_117[] = {
  0x28, 0xbf, 0x75, 0x2e // It cs; cmp cs r6 117
};
const byte kInstruction_cmp_cc_r1_177[] = {
  0x38, 0xbf, 0xb1, 0x29 // It cc; cmp cc r1 177
};
const byte kInstruction_cmp_cs_r1_74[] = {
  0x28, 0xbf, 0x4a, 0x29 // It cs; cmp cs r1 74
};
const byte kInstruction_cmp_ls_r7_176[] = {
  0x98, 0xbf, 0xb0, 0x2f // It ls; cmp ls r7 176
};
const byte kInstruction_cmp_lt_r7_208[] = {
  0xb8, 0xbf, 0xd0, 0x2f // It lt; cmp lt r7 208
};
const byte kInstruction_cmp_ge_r2_252[] = {
  0xa8, 0xbf, 0xfc, 0x2a // It ge; cmp ge r2 252
};
const byte kInstruction_cmp_gt_r7_135[] = {
  0xc8, 0xbf, 0x87, 0x2f // It gt; cmp gt r7 135
};
const byte kInstruction_cmp_cs_r4_128[] = {
  0x28, 0xbf, 0x80, 0x2c // It cs; cmp cs r4 128
};
const byte kInstruction_cmp_le_r6_44[] = {
  0xd8, 0xbf, 0x2c, 0x2e // It le; cmp le r6 44
};
const byte kInstruction_cmp_cs_r5_184[] = {
  0x28, 0xbf, 0xb8, 0x2d // It cs; cmp cs r5 184
};
const byte kInstruction_cmp_cc_r5_17[] = {
  0x38, 0xbf, 0x11, 0x2d // It cc; cmp cc r5 17
};
const byte kInstruction_cmp_le_r1_48[] = {
  0xd8, 0xbf, 0x30, 0x29 // It le; cmp le r1 48
};
const byte kInstruction_cmp_vs_r7_152[] = {
  0x68, 0xbf, 0x98, 0x2f // It vs; cmp vs r7 152
};
const byte kInstruction_cmp_cs_r3_236[] = {
  0x28, 0xbf, 0xec, 0x2b // It cs; cmp cs r3 236
};
const byte kInstruction_cmp_cc_r1_68[] = {
  0x38, 0xbf, 0x44, 0x29 // It cc; cmp cc r1 68
};
const byte kInstruction_cmp_cs_r6_179[] = {
  0x28, 0xbf, 0xb3, 0x2e // It cs; cmp cs r6 179
};
const byte kInstruction_cmp_eq_r5_35[] = {
  0x08, 0xbf, 0x23, 0x2d // It eq; cmp eq r5 35
};
const byte kInstruction_cmp_le_r5_220[] = {
  0xd8, 0xbf, 0xdc, 0x2d // It le; cmp le r5 220
};
const byte kInstruction_cmp_pl_r1_63[] = {
  0x58, 0xbf, 0x3f, 0x29 // It pl; cmp pl r1 63
};
const byte kInstruction_cmp_vs_r5_255[] = {
  0x68, 0xbf, 0xff, 0x2d // It vs; cmp vs r5 255
};
const byte kInstruction_cmp_pl_r5_193[] = {
  0x58, 0xbf, 0xc1, 0x2d // It pl; cmp pl r5 193
};
const byte kInstruction_cmp_gt_r3_165[] = {
  0xc8, 0xbf, 0xa5, 0x2b // It gt; cmp gt r3 165
};
const byte kInstruction_cmp_le_r0_120[] = {
  0xd8, 0xbf, 0x78, 0x28 // It le; cmp le r0 120
};
const byte kInstruction_cmp_cc_r0_21[] = {
  0x38, 0xbf, 0x15, 0x28 // It cc; cmp cc r0 21
};
const byte kInstruction_cmp_ge_r3_203[] = {
  0xa8, 0xbf, 0xcb, 0x2b // It ge; cmp ge r3 203
};
const byte kInstruction_cmp_ne_r0_25[] = {
  0x18, 0xbf, 0x19, 0x28 // It ne; cmp ne r0 25
};
const byte kInstruction_cmp_mi_r6_6[] = {
  0x48, 0xbf, 0x06, 0x2e // It mi; cmp mi r6 6
};
const byte kInstruction_cmp_ne_r7_194[] = {
  0x18, 0xbf, 0xc2, 0x2f // It ne; cmp ne r7 194
};
const byte kInstruction_cmp_lt_r6_20[] = {
  0xb8, 0xbf, 0x14, 0x2e // It lt; cmp lt r6 20
};
const byte kInstruction_cmp_ls_r3_94[] = {
  0x98, 0xbf, 0x5e, 0x2b // It ls; cmp ls r3 94
};
const byte kInstruction_cmp_gt_r6_222[] = {
  0xc8, 0xbf, 0xde, 0x2e // It gt; cmp gt r6 222
};
const byte kInstruction_cmp_cc_r1_247[] = {
  0x38, 0xbf, 0xf7, 0x29 // It cc; cmp cc r1 247
};
const byte kInstruction_cmp_cc_r0_127[] = {
  0x38, 0xbf, 0x7f, 0x28 // It cc; cmp cc r0 127
};
const byte kInstruction_cmp_mi_r2_252[] = {
  0x48, 0xbf, 0xfc, 0x2a // It mi; cmp mi r2 252
};
const byte kInstruction_cmp_ge_r0_150[] = {
  0xa8, 0xbf, 0x96, 0x28 // It ge; cmp ge r0 150
};
const byte kInstruction_cmp_mi_r4_18[] = {
  0x48, 0xbf, 0x12, 0x2c // It mi; cmp mi r4 18
};
const byte kInstruction_cmp_vs_r5_182[] = {
  0x68, 0xbf, 0xb6, 0x2d // It vs; cmp vs r5 182
};
const byte kInstruction_cmp_pl_r1_125[] = {
  0x58, 0xbf, 0x7d, 0x29 // It pl; cmp pl r1 125
};
const byte kInstruction_cmp_pl_r6_159[] = {
  0x58, 0xbf, 0x9f, 0x2e // It pl; cmp pl r6 159
};
const byte kInstruction_cmp_le_r3_218[] = {
  0xd8, 0xbf, 0xda, 0x2b // It le; cmp le r3 218
};
const byte kInstruction_cmp_hi_r2_163[] = {
  0x88, 0xbf, 0xa3, 0x2a // It hi; cmp hi r2 163
};
const byte kInstruction_cmp_mi_r7_246[] = {
  0x48, 0xbf, 0xf6, 0x2f // It mi; cmp mi r7 246
};
const byte kInstruction_cmp_lt_r7_1[] = {
  0xb8, 0xbf, 0x01, 0x2f // It lt; cmp lt r7 1
};
const byte kInstruction_cmp_pl_r4_82[] = {
  0x58, 0xbf, 0x52, 0x2c // It pl; cmp pl r4 82
};
const byte kInstruction_cmp_le_r2_115[] = {
  0xd8, 0xbf, 0x73, 0x2a // It le; cmp le r2 115
};
const byte kInstruction_cmp_vc_r0_74[] = {
  0x78, 0xbf, 0x4a, 0x28 // It vc; cmp vc r0 74
};
const byte kInstruction_cmp_gt_r3_11[] = {
  0xc8, 0xbf, 0x0b, 0x2b // It gt; cmp gt r3 11
};
const byte kInstruction_cmp_cs_r7_225[] = {
  0x28, 0xbf, 0xe1, 0x2f // It cs; cmp cs r7 225
};
const byte kInstruction_cmp_gt_r2_245[] = {
  0xc8, 0xbf, 0xf5, 0x2a // It gt; cmp gt r2 245
};
const byte kInstruction_cmp_lt_r4_13[] = {
  0xb8, 0xbf, 0x0d, 0x2c // It lt; cmp lt r4 13
};
const byte kInstruction_cmp_le_r3_83[] = {
  0xd8, 0xbf, 0x53, 0x2b // It le; cmp le r3 83
};
const byte kInstruction_cmp_eq_r7_83[] = {
  0x08, 0xbf, 0x53, 0x2f // It eq; cmp eq r7 83
};
const byte kInstruction_cmp_vc_r6_86[] = {
  0x78, 0xbf, 0x56, 0x2e // It vc; cmp vc r6 86
};
const byte kInstruction_cmp_le_r2_99[] = {
  0xd8, 0xbf, 0x63, 0x2a // It le; cmp le r2 99
};
const byte kInstruction_cmp_hi_r0_139[] = {
  0x88, 0xbf, 0x8b, 0x28 // It hi; cmp hi r0 139
};
const byte kInstruction_cmp_gt_r6_122[] = {
  0xc8, 0xbf, 0x7a, 0x2e // It gt; cmp gt r6 122
};
const byte kInstruction_cmp_cs_r2_190[] = {
  0x28, 0xbf, 0xbe, 0x2a // It cs; cmp cs r2 190
};
const byte kInstruction_cmp_pl_r0_97[] = {
  0x58, 0xbf, 0x61, 0x28 // It pl; cmp pl r0 97
};
const byte kInstruction_cmp_ls_r7_41[] = {
  0x98, 0xbf, 0x29, 0x2f // It ls; cmp ls r7 41
};
const byte kInstruction_cmp_pl_r2_111[] = {
  0x58, 0xbf, 0x6f, 0x2a // It pl; cmp pl r2 111
};
const byte kInstruction_cmp_ls_r5_239[] = {
  0x98, 0xbf, 0xef, 0x2d // It ls; cmp ls r5 239
};
const byte kInstruction_cmp_le_r3_104[] = {
  0xd8, 0xbf, 0x68, 0x2b // It le; cmp le r3 104
};
const byte kInstruction_cmp_gt_r3_29[] = {
  0xc8, 0xbf, 0x1d, 0x2b // It gt; cmp gt r3 29
};
const byte kInstruction_cmp_ge_r7_247[] = {
  0xa8, 0xbf, 0xf7, 0x2f // It ge; cmp ge r7 247
};
const byte kInstruction_cmp_le_r6_1[] = {
  0xd8, 0xbf, 0x01, 0x2e // It le; cmp le r6 1
};
const byte kInstruction_cmp_hi_r0_161[] = {
  0x88, 0xbf, 0xa1, 0x28 // It hi; cmp hi r0 161
};
const byte kInstruction_cmp_vs_r1_143[] = {
  0x68, 0xbf, 0x8f, 0x29 // It vs; cmp vs r1 143
};
const byte kInstruction_cmp_cs_r7_14[] = {
  0x28, 0xbf, 0x0e, 0x2f // It cs; cmp cs r7 14
};
const byte kInstruction_cmp_gt_r3_80[] = {
  0xc8, 0xbf, 0x50, 0x2b // It gt; cmp gt r3 80
};
const byte kInstruction_cmp_ls_r6_207[] = {
  0x98, 0xbf, 0xcf, 0x2e // It ls; cmp ls r6 207
};
const byte kInstruction_cmp_vs_r1_187[] = {
  0x68, 0xbf, 0xbb, 0x29 // It vs; cmp vs r1 187
};
const byte kInstruction_cmp_ne_r6_193[] = {
  0x18, 0xbf, 0xc1, 0x2e // It ne; cmp ne r6 193
};
const byte kInstruction_cmp_le_r5_202[] = {
  0xd8, 0xbf, 0xca, 0x2d // It le; cmp le r5 202
};
const byte kInstruction_cmp_vs_r3_23[] = {
  0x68, 0xbf, 0x17, 0x2b // It vs; cmp vs r3 23
};
const byte kInstruction_cmp_mi_r2_141[] = {
  0x48, 0xbf, 0x8d, 0x2a // It mi; cmp mi r2 141
};
const byte kInstruction_cmp_mi_r1_145[] = {
  0x48, 0xbf, 0x91, 0x29 // It mi; cmp mi r1 145
};
const byte kInstruction_cmp_lt_r0_176[] = {
  0xb8, 0xbf, 0xb0, 0x28 // It lt; cmp lt r0 176
};
const byte kInstruction_cmp_hi_r2_18[] = {
  0x88, 0xbf, 0x12, 0x2a // It hi; cmp hi r2 18
};
const byte kInstruction_cmp_gt_r4_247[] = {
  0xc8, 0xbf, 0xf7, 0x2c // It gt; cmp gt r4 247
};
const byte kInstruction_cmp_lt_r1_144[] = {
  0xb8, 0xbf, 0x90, 0x29 // It lt; cmp lt r1 144
};
const byte kInstruction_cmp_cc_r5_174[] = {
  0x38, 0xbf, 0xae, 0x2d // It cc; cmp cc r5 174
};
const byte kInstruction_cmp_ge_r6_66[] = {
  0xa8, 0xbf, 0x42, 0x2e // It ge; cmp ge r6 66
};
const byte kInstruction_cmp_vc_r0_223[] = {
  0x78, 0xbf, 0xdf, 0x28 // It vc; cmp vc r0 223
};
const byte kInstruction_cmp_cc_r7_211[] = {
  0x38, 0xbf, 0xd3, 0x2f // It cc; cmp cc r7 211
};
const byte kInstruction_cmp_le_r1_186[] = {
  0xd8, 0xbf, 0xba, 0x29 // It le; cmp le r1 186
};
const byte kInstruction_cmp_ne_r4_73[] = {
  0x18, 0xbf, 0x49, 0x2c // It ne; cmp ne r4 73
};
const byte kInstruction_cmp_ls_r4_64[] = {
  0x98, 0xbf, 0x40, 0x2c // It ls; cmp ls r4 64
};
const byte kInstruction_cmp_cc_r3_100[] = {
  0x38, 0xbf, 0x64, 0x2b // It cc; cmp cc r3 100
};
const byte kInstruction_cmp_ls_r7_83[] = {
  0x98, 0xbf, 0x53, 0x2f // It ls; cmp ls r7 83
};
const byte kInstruction_cmp_ge_r7_253[] = {
  0xa8, 0xbf, 0xfd, 0x2f // It ge; cmp ge r7 253
};
const byte kInstruction_cmp_lt_r1_190[] = {
  0xb8, 0xbf, 0xbe, 0x29 // It lt; cmp lt r1 190
};
const byte kInstruction_cmp_hi_r0_132[] = {
  0x88, 0xbf, 0x84, 0x28 // It hi; cmp hi r0 132
};
const byte kInstruction_cmp_cc_r1_172[] = {
  0x38, 0xbf, 0xac, 0x29 // It cc; cmp cc r1 172
};
const byte kInstruction_cmp_cs_r4_24[] = {
  0x28, 0xbf, 0x18, 0x2c // It cs; cmp cs r4 24
};
const byte kInstruction_cmp_vs_r0_183[] = {
  0x68, 0xbf, 0xb7, 0x28 // It vs; cmp vs r0 183
};
const byte kInstruction_cmp_eq_r3_231[] = {
  0x08, 0xbf, 0xe7, 0x2b // It eq; cmp eq r3 231
};
const byte kInstruction_cmp_cc_r4_6[] = {
  0x38, 0xbf, 0x06, 0x2c // It cc; cmp cc r4 6
};
const byte kInstruction_cmp_le_r6_151[] = {
  0xd8, 0xbf, 0x97, 0x2e // It le; cmp le r6 151
};
const byte kInstruction_cmp_eq_r4_123[] = {
  0x08, 0xbf, 0x7b, 0x2c // It eq; cmp eq r4 123
};
const byte kInstruction_cmp_lt_r2_110[] = {
  0xb8, 0xbf, 0x6e, 0x2a // It lt; cmp lt r2 110
};
const byte kInstruction_cmp_vc_r2_39[] = {
  0x78, 0xbf, 0x27, 0x2a // It vc; cmp vc r2 39
};
const byte kInstruction_cmp_gt_r5_45[] = {
  0xc8, 0xbf, 0x2d, 0x2d // It gt; cmp gt r5 45
};
const byte kInstruction_cmp_eq_r2_120[] = {
  0x08, 0xbf, 0x78, 0x2a // It eq; cmp eq r2 120
};
const byte kInstruction_cmp_ge_r0_6[] = {
  0xa8, 0xbf, 0x06, 0x28 // It ge; cmp ge r0 6
};
const byte kInstruction_cmp_vs_r3_54[] = {
  0x68, 0xbf, 0x36, 0x2b // It vs; cmp vs r3 54
};
const byte kInstruction_cmp_cc_r0_164[] = {
  0x38, 0xbf, 0xa4, 0x28 // It cc; cmp cc r0 164
};
const byte kInstruction_cmp_eq_r6_198[] = {
  0x08, 0xbf, 0xc6, 0x2e // It eq; cmp eq r6 198
};
const byte kInstruction_cmp_cc_r0_254[] = {
  0x38, 0xbf, 0xfe, 0x28 // It cc; cmp cc r0 254
};
const byte kInstruction_cmp_ne_r1_167[] = {
  0x18, 0xbf, 0xa7, 0x29 // It ne; cmp ne r1 167
};
const byte kInstruction_cmp_hi_r7_89[] = {
  0x88, 0xbf, 0x59, 0x2f // It hi; cmp hi r7 89
};
const byte kInstruction_cmp_mi_r6_220[] = {
  0x48, 0xbf, 0xdc, 0x2e // It mi; cmp mi r6 220
};
const byte kInstruction_cmp_vs_r5_199[] = {
  0x68, 0xbf, 0xc7, 0x2d // It vs; cmp vs r5 199
};
const byte kInstruction_cmp_ls_r4_166[] = {
  0x98, 0xbf, 0xa6, 0x2c // It ls; cmp ls r4 166
};
const byte kInstruction_cmp_le_r2_139[] = {
  0xd8, 0xbf, 0x8b, 0x2a // It le; cmp le r2 139
};
const byte kInstruction_cmp_vs_r5_112[] = {
  0x68, 0xbf, 0x70, 0x2d // It vs; cmp vs r5 112
};
const byte kInstruction_cmp_cs_r3_13[] = {
  0x28, 0xbf, 0x0d, 0x2b // It cs; cmp cs r3 13
};
const byte kInstruction_cmp_gt_r3_95[] = {
  0xc8, 0xbf, 0x5f, 0x2b // It gt; cmp gt r3 95
};
const byte kInstruction_cmp_pl_r2_94[] = {
  0x58, 0xbf, 0x5e, 0x2a // It pl; cmp pl r2 94
};
const byte kInstruction_cmp_ne_r2_227[] = {
  0x18, 0xbf, 0xe3, 0x2a // It ne; cmp ne r2 227
};
const byte kInstruction_cmp_ne_r7_251[] = {
  0x18, 0xbf, 0xfb, 0x2f // It ne; cmp ne r7 251
};
const byte kInstruction_cmp_ge_r5_97[] = {
  0xa8, 0xbf, 0x61, 0x2d // It ge; cmp ge r5 97
};
const byte kInstruction_cmp_gt_r5_253[] = {
  0xc8, 0xbf, 0xfd, 0x2d // It gt; cmp gt r5 253
};
const byte kInstruction_cmp_hi_r7_95[] = {
  0x88, 0xbf, 0x5f, 0x2f // It hi; cmp hi r7 95
};
const byte kInstruction_cmp_gt_r3_253[] = {
  0xc8, 0xbf, 0xfd, 0x2b // It gt; cmp gt r3 253
};
const byte kInstruction_cmp_le_r7_162[] = {
  0xd8, 0xbf, 0xa2, 0x2f // It le; cmp le r7 162
};
const byte kInstruction_cmp_gt_r4_36[] = {
  0xc8, 0xbf, 0x24, 0x2c // It gt; cmp gt r4 36
};
const byte kInstruction_cmp_ne_r3_58[] = {
  0x18, 0xbf, 0x3a, 0x2b // It ne; cmp ne r3 58
};
const byte kInstruction_cmp_vs_r0_25[] = {
  0x68, 0xbf, 0x19, 0x28 // It vs; cmp vs r0 25
};
const byte kInstruction_cmp_ne_r7_116[] = {
  0x18, 0xbf, 0x74, 0x2f // It ne; cmp ne r7 116
};
const byte kInstruction_cmp_cs_r1_198[] = {
  0x28, 0xbf, 0xc6, 0x29 // It cs; cmp cs r1 198
};
const byte kInstruction_cmp_cc_r0_122[] = {
  0x38, 0xbf, 0x7a, 0x28 // It cc; cmp cc r0 122
};
const byte kInstruction_cmp_le_r4_57[] = {
  0xd8, 0xbf, 0x39, 0x2c // It le; cmp le r4 57
};
const byte kInstruction_cmp_vc_r3_150[] = {
  0x78, 0xbf, 0x96, 0x2b // It vc; cmp vc r3 150
};
const byte kInstruction_cmp_eq_r1_54[] = {
  0x08, 0xbf, 0x36, 0x29 // It eq; cmp eq r1 54
};
const byte kInstruction_cmp_ge_r1_146[] = {
  0xa8, 0xbf, 0x92, 0x29 // It ge; cmp ge r1 146
};
const byte kInstruction_cmp_vc_r1_124[] = {
  0x78, 0xbf, 0x7c, 0x29 // It vc; cmp vc r1 124
};
const byte kInstruction_cmp_ne_r6_165[] = {
  0x18, 0xbf, 0xa5, 0x2e // It ne; cmp ne r6 165
};
const byte kInstruction_cmp_vc_r6_54[] = {
  0x78, 0xbf, 0x36, 0x2e // It vc; cmp vc r6 54
};
const byte kInstruction_cmp_hi_r3_226[] = {
  0x88, 0xbf, 0xe2, 0x2b // It hi; cmp hi r3 226
};
const byte kInstruction_cmp_eq_r1_167[] = {
  0x08, 0xbf, 0xa7, 0x29 // It eq; cmp eq r1 167
};
const byte kInstruction_cmp_mi_r3_162[] = {
  0x48, 0xbf, 0xa2, 0x2b // It mi; cmp mi r3 162
};
const byte kInstruction_cmp_mi_r5_8[] = {
  0x48, 0xbf, 0x08, 0x2d // It mi; cmp mi r5 8
};
const byte kInstruction_cmp_mi_r3_67[] = {
  0x48, 0xbf, 0x43, 0x2b // It mi; cmp mi r3 67
};
const byte kInstruction_cmp_ge_r6_113[] = {
  0xa8, 0xbf, 0x71, 0x2e // It ge; cmp ge r6 113
};
const byte kInstruction_cmp_lt_r2_51[] = {
  0xb8, 0xbf, 0x33, 0x2a // It lt; cmp lt r2 51
};
const byte kInstruction_cmp_vc_r2_131[] = {
  0x78, 0xbf, 0x83, 0x2a // It vc; cmp vc r2 131
};
const byte kInstruction_cmp_ne_r4_196[] = {
  0x18, 0xbf, 0xc4, 0x2c // It ne; cmp ne r4 196
};
const byte kInstruction_cmp_mi_r5_189[] = {
  0x48, 0xbf, 0xbd, 0x2d // It mi; cmp mi r5 189
};
const byte kInstruction_cmp_cs_r1_62[] = {
  0x28, 0xbf, 0x3e, 0x29 // It cs; cmp cs r1 62
};
const byte kInstruction_cmp_hi_r4_142[] = {
  0x88, 0xbf, 0x8e, 0x2c // It hi; cmp hi r4 142
};
const byte kInstruction_cmp_ne_r5_91[] = {
  0x18, 0xbf, 0x5b, 0x2d // It ne; cmp ne r5 91
};
const byte kInstruction_cmp_eq_r3_38[] = {
  0x08, 0xbf, 0x26, 0x2b // It eq; cmp eq r3 38
};
const byte kInstruction_cmp_ls_r3_155[] = {
  0x98, 0xbf, 0x9b, 0x2b // It ls; cmp ls r3 155
};
const byte kInstruction_cmp_le_r5_0[] = {
  0xd8, 0xbf, 0x00, 0x2d // It le; cmp le r5 0
};
const byte kInstruction_cmp_vc_r1_106[] = {
  0x78, 0xbf, 0x6a, 0x29 // It vc; cmp vc r1 106
};
const byte kInstruction_cmp_lt_r0_212[] = {
  0xb8, 0xbf, 0xd4, 0x28 // It lt; cmp lt r0 212
};
const byte kInstruction_cmp_lt_r1_87[] = {
  0xb8, 0xbf, 0x57, 0x29 // It lt; cmp lt r1 87
};
const byte kInstruction_cmp_mi_r2_62[] = {
  0x48, 0xbf, 0x3e, 0x2a // It mi; cmp mi r2 62
};
const byte kInstruction_cmp_vc_r0_2[] = {
  0x78, 0xbf, 0x02, 0x28 // It vc; cmp vc r0 2
};
const byte kInstruction_cmp_ls_r7_24[] = {
  0x98, 0xbf, 0x18, 0x2f // It ls; cmp ls r7 24
};
const byte kInstruction_cmp_ls_r3_12[] = {
  0x98, 0xbf, 0x0c, 0x2b // It ls; cmp ls r3 12
};
const byte kInstruction_cmp_pl_r0_181[] = {
  0x58, 0xbf, 0xb5, 0x28 // It pl; cmp pl r0 181
};
const byte kInstruction_cmp_gt_r2_43[] = {
  0xc8, 0xbf, 0x2b, 0x2a // It gt; cmp gt r2 43
};
const byte kInstruction_cmp_cc_r5_130[] = {
  0x38, 0xbf, 0x82, 0x2d // It cc; cmp cc r5 130
};
const byte kInstruction_cmp_eq_r6_170[] = {
  0x08, 0xbf, 0xaa, 0x2e // It eq; cmp eq r6 170
};
const byte kInstruction_cmp_hi_r4_208[] = {
  0x88, 0xbf, 0xd0, 0x2c // It hi; cmp hi r4 208
};
const byte kInstruction_cmp_cc_r2_196[] = {
  0x38, 0xbf, 0xc4, 0x2a // It cc; cmp cc r2 196
};
const byte kInstruction_cmp_lt_r4_131[] = {
  0xb8, 0xbf, 0x83, 0x2c // It lt; cmp lt r4 131
};
const byte kInstruction_cmp_vs_r7_122[] = {
  0x68, 0xbf, 0x7a, 0x2f // It vs; cmp vs r7 122
};
const byte kInstruction_cmp_cs_r0_212[] = {
  0x28, 0xbf, 0xd4, 0x28 // It cs; cmp cs r0 212
};
const byte kInstruction_cmp_eq_r2_50[] = {
  0x08, 0xbf, 0x32, 0x2a // It eq; cmp eq r2 50
};
const byte kInstruction_cmp_gt_r3_202[] = {
  0xc8, 0xbf, 0xca, 0x2b // It gt; cmp gt r3 202
};
const byte kInstruction_cmp_eq_r4_197[] = {
  0x08, 0xbf, 0xc5, 0x2c // It eq; cmp eq r4 197
};
const byte kInstruction_cmp_cc_r3_7[] = {
  0x38, 0xbf, 0x07, 0x2b // It cc; cmp cc r3 7
};
const byte kInstruction_cmp_vs_r5_206[] = {
  0x68, 0xbf, 0xce, 0x2d // It vs; cmp vs r5 206
};
const byte kInstruction_cmp_lt_r6_137[] = {
  0xb8, 0xbf, 0x89, 0x2e // It lt; cmp lt r6 137
};
const byte kInstruction_cmp_cs_r4_154[] = {
  0x28, 0xbf, 0x9a, 0x2c // It cs; cmp cs r4 154
};
const byte kInstruction_cmp_hi_r0_16[] = {
  0x88, 0xbf, 0x10, 0x28 // It hi; cmp hi r0 16
};
const byte kInstruction_cmp_le_r1_110[] = {
  0xd8, 0xbf, 0x6e, 0x29 // It le; cmp le r1 110
};
const byte kInstruction_cmp_ge_r5_67[] = {
  0xa8, 0xbf, 0x43, 0x2d // It ge; cmp ge r5 67
};
const byte kInstruction_cmp_lt_r2_58[] = {
  0xb8, 0xbf, 0x3a, 0x2a // It lt; cmp lt r2 58
};
const byte kInstruction_cmp_gt_r4_45[] = {
  0xc8, 0xbf, 0x2d, 0x2c // It gt; cmp gt r4 45
};
const byte kInstruction_cmp_gt_r7_227[] = {
  0xc8, 0xbf, 0xe3, 0x2f // It gt; cmp gt r7 227
};
const byte kInstruction_cmp_lt_r6_143[] = {
  0xb8, 0xbf, 0x8f, 0x2e // It lt; cmp lt r6 143
};
const byte kInstruction_cmp_cs_r5_168[] = {
  0x28, 0xbf, 0xa8, 0x2d // It cs; cmp cs r5 168
};
const byte kInstruction_cmp_hi_r5_74[] = {
  0x88, 0xbf, 0x4a, 0x2d // It hi; cmp hi r5 74
};
const byte kInstruction_cmp_gt_r6_165[] = {
  0xc8, 0xbf, 0xa5, 0x2e // It gt; cmp gt r6 165
};
const byte kInstruction_cmp_le_r2_191[] = {
  0xd8, 0xbf, 0xbf, 0x2a // It le; cmp le r2 191
};
const byte kInstruction_cmp_pl_r3_212[] = {
  0x58, 0xbf, 0xd4, 0x2b // It pl; cmp pl r3 212
};
const byte kInstruction_cmp_lt_r2_108[] = {
  0xb8, 0xbf, 0x6c, 0x2a // It lt; cmp lt r2 108
};
const byte kInstruction_cmp_gt_r4_225[] = {
  0xc8, 0xbf, 0xe1, 0x2c // It gt; cmp gt r4 225
};
const byte kInstruction_cmp_cc_r3_181[] = {
  0x38, 0xbf, 0xb5, 0x2b // It cc; cmp cc r3 181
};
const byte kInstruction_cmp_ge_r7_39[] = {
  0xa8, 0xbf, 0x27, 0x2f // It ge; cmp ge r7 39
};
const byte kInstruction_cmp_gt_r2_212[] = {
  0xc8, 0xbf, 0xd4, 0x2a // It gt; cmp gt r2 212
};
const byte kInstruction_cmp_cc_r2_32[] = {
  0x38, 0xbf, 0x20, 0x2a // It cc; cmp cc r2 32
};
const byte kInstruction_cmp_vs_r1_92[] = {
  0x68, 0xbf, 0x5c, 0x29 // It vs; cmp vs r1 92
};
const byte kInstruction_cmp_cs_r0_64[] = {
  0x28, 0xbf, 0x40, 0x28 // It cs; cmp cs r0 64
};
const byte kInstruction_cmp_mi_r3_195[] = {
  0x48, 0xbf, 0xc3, 0x2b // It mi; cmp mi r3 195
};
const byte kInstruction_cmp_ne_r7_168[] = {
  0x18, 0xbf, 0xa8, 0x2f // It ne; cmp ne r7 168
};
const byte kInstruction_cmp_vc_r2_84[] = {
  0x78, 0xbf, 0x54, 0x2a // It vc; cmp vc r2 84
};
const byte kInstruction_cmp_hi_r1_105[] = {
  0x88, 0xbf, 0x69, 0x29 // It hi; cmp hi r1 105
};
const byte kInstruction_cmp_vc_r4_91[] = {
  0x78, 0xbf, 0x5b, 0x2c // It vc; cmp vc r4 91
};
const byte kInstruction_cmp_pl_r0_103[] = {
  0x58, 0xbf, 0x67, 0x28 // It pl; cmp pl r0 103
};
const byte kInstruction_cmp_cc_r7_122[] = {
  0x38, 0xbf, 0x7a, 0x2f // It cc; cmp cc r7 122
};
const byte kInstruction_cmp_vs_r7_228[] = {
  0x68, 0xbf, 0xe4, 0x2f // It vs; cmp vs r7 228
};
const byte kInstruction_cmp_ls_r4_154[] = {
  0x98, 0xbf, 0x9a, 0x2c // It ls; cmp ls r4 154
};
const byte kInstruction_cmp_mi_r5_159[] = {
  0x48, 0xbf, 0x9f, 0x2d // It mi; cmp mi r5 159
};
const byte kInstruction_cmp_gt_r6_207[] = {
  0xc8, 0xbf, 0xcf, 0x2e // It gt; cmp gt r6 207
};
const byte kInstruction_cmp_lt_r0_75[] = {
  0xb8, 0xbf, 0x4b, 0x28 // It lt; cmp lt r0 75
};
const byte kInstruction_cmp_gt_r4_106[] = {
  0xc8, 0xbf, 0x6a, 0x2c // It gt; cmp gt r4 106
};
const byte kInstruction_cmp_gt_r0_236[] = {
  0xc8, 0xbf, 0xec, 0x28 // It gt; cmp gt r0 236
};
const byte kInstruction_cmp_le_r7_127[] = {
  0xd8, 0xbf, 0x7f, 0x2f // It le; cmp le r7 127
};
const byte kInstruction_cmp_vs_r0_138[] = {
  0x68, 0xbf, 0x8a, 0x28 // It vs; cmp vs r0 138
};
const byte kInstruction_cmp_vs_r3_145[] = {
  0x68, 0xbf, 0x91, 0x2b // It vs; cmp vs r3 145
};
const byte kInstruction_cmp_cs_r1_70[] = {
  0x28, 0xbf, 0x46, 0x29 // It cs; cmp cs r1 70
};
const byte kInstruction_cmp_cs_r3_69[] = {
  0x28, 0xbf, 0x45, 0x2b // It cs; cmp cs r3 69
};
const byte kInstruction_cmp_hi_r3_28[] = {
  0x88, 0xbf, 0x1c, 0x2b // It hi; cmp hi r3 28
};
const byte kInstruction_cmp_le_r5_122[] = {
  0xd8, 0xbf, 0x7a, 0x2d // It le; cmp le r5 122
};
const byte kInstruction_cmp_cc_r7_212[] = {
  0x38, 0xbf, 0xd4, 0x2f // It cc; cmp cc r7 212
};
const byte kInstruction_cmp_mi_r4_186[] = {
  0x48, 0xbf, 0xba, 0x2c // It mi; cmp mi r4 186
};
const byte kInstruction_cmp_ne_r1_171[] = {
  0x18, 0xbf, 0xab, 0x29 // It ne; cmp ne r1 171
};
const byte kInstruction_cmp_vs_r4_205[] = {
  0x68, 0xbf, 0xcd, 0x2c // It vs; cmp vs r4 205
};
const byte kInstruction_cmp_ls_r1_26[] = {
  0x98, 0xbf, 0x1a, 0x29 // It ls; cmp ls r1 26
};
const byte kInstruction_cmp_le_r5_58[] = {
  0xd8, 0xbf, 0x3a, 0x2d // It le; cmp le r5 58
};
const byte kInstruction_cmp_gt_r2_140[] = {
  0xc8, 0xbf, 0x8c, 0x2a // It gt; cmp gt r2 140
};
const byte kInstruction_cmp_pl_r5_121[] = {
  0x58, 0xbf, 0x79, 0x2d // It pl; cmp pl r5 121
};
const byte kInstruction_cmp_vc_r3_183[] = {
  0x78, 0xbf, 0xb7, 0x2b // It vc; cmp vc r3 183
};
const byte kInstruction_cmp_vs_r5_110[] = {
  0x68, 0xbf, 0x6e, 0x2d // It vs; cmp vs r5 110
};
const byte kInstruction_cmp_ls_r2_89[] = {
  0x98, 0xbf, 0x59, 0x2a // It ls; cmp ls r2 89
};
const byte kInstruction_cmp_vc_r3_173[] = {
  0x78, 0xbf, 0xad, 0x2b // It vc; cmp vc r3 173
};
const byte kInstruction_cmp_le_r7_57[] = {
  0xd8, 0xbf, 0x39, 0x2f // It le; cmp le r7 57
};
const byte kInstruction_cmp_eq_r5_111[] = {
  0x08, 0xbf, 0x6f, 0x2d // It eq; cmp eq r5 111
};
const byte kInstruction_cmp_mi_r4_180[] = {
  0x48, 0xbf, 0xb4, 0x2c // It mi; cmp mi r4 180
};
const byte kInstruction_cmp_vs_r1_252[] = {
  0x68, 0xbf, 0xfc, 0x29 // It vs; cmp vs r1 252
};
const byte kInstruction_cmp_le_r2_168[] = {
  0xd8, 0xbf, 0xa8, 0x2a // It le; cmp le r2 168
};
const byte kInstruction_cmp_ne_r7_240[] = {
  0x18, 0xbf, 0xf0, 0x2f // It ne; cmp ne r7 240
};
const byte kInstruction_cmp_hi_r5_177[] = {
  0x88, 0xbf, 0xb1, 0x2d // It hi; cmp hi r5 177
};
const byte kInstruction_cmp_cc_r7_156[] = {
  0x38, 0xbf, 0x9c, 0x2f // It cc; cmp cc r7 156
};
const byte kInstruction_cmp_ls_r0_140[] = {
  0x98, 0xbf, 0x8c, 0x28 // It ls; cmp ls r0 140
};
const byte kInstruction_cmp_vc_r2_206[] = {
  0x78, 0xbf, 0xce, 0x2a // It vc; cmp vc r2 206
};
const byte kInstruction_cmp_ge_r3_198[] = {
  0xa8, 0xbf, 0xc6, 0x2b // It ge; cmp ge r3 198
};
const byte kInstruction_cmp_pl_r1_154[] = {
  0x58, 0xbf, 0x9a, 0x29 // It pl; cmp pl r1 154
};
const byte kInstruction_cmp_eq_r5_118[] = {
  0x08, 0xbf, 0x76, 0x2d // It eq; cmp eq r5 118
};
const byte kInstruction_cmp_le_r7_173[] = {
  0xd8, 0xbf, 0xad, 0x2f // It le; cmp le r7 173
};
const byte kInstruction_cmp_mi_r6_174[] = {
  0x48, 0xbf, 0xae, 0x2e // It mi; cmp mi r6 174
};
const byte kInstruction_cmp_pl_r2_159[] = {
  0x58, 0xbf, 0x9f, 0x2a // It pl; cmp pl r2 159
};
const byte kInstruction_cmp_lt_r0_97[] = {
  0xb8, 0xbf, 0x61, 0x28 // It lt; cmp lt r0 97
};
const byte kInstruction_cmp_ge_r2_145[] = {
  0xa8, 0xbf, 0x91, 0x2a // It ge; cmp ge r2 145
};
const byte kInstruction_cmp_cc_r5_196[] = {
  0x38, 0xbf, 0xc4, 0x2d // It cc; cmp cc r5 196
};
const byte kInstruction_cmp_vs_r3_152[] = {
  0x68, 0xbf, 0x98, 0x2b // It vs; cmp vs r3 152
};
const byte kInstruction_cmp_le_r3_85[] = {
  0xd8, 0xbf, 0x55, 0x2b // It le; cmp le r3 85
};
const byte kInstruction_cmp_le_r7_155[] = {
  0xd8, 0xbf, 0x9b, 0x2f // It le; cmp le r7 155
};
const byte kInstruction_cmp_cc_r1_160[] = {
  0x38, 0xbf, 0xa0, 0x29 // It cc; cmp cc r1 160
};
const byte kInstruction_cmp_gt_r2_195[] = {
  0xc8, 0xbf, 0xc3, 0x2a // It gt; cmp gt r2 195
};
const byte kInstruction_cmp_vc_r3_67[] = {
  0x78, 0xbf, 0x43, 0x2b // It vc; cmp vc r3 67
};
const byte kInstruction_cmp_lt_r0_119[] = {
  0xb8, 0xbf, 0x77, 0x28 // It lt; cmp lt r0 119
};
const byte kInstruction_cmp_ne_r3_123[] = {
  0x18, 0xbf, 0x7b, 0x2b // It ne; cmp ne r3 123
};
const byte kInstruction_cmp_le_r5_23[] = {
  0xd8, 0xbf, 0x17, 0x2d // It le; cmp le r5 23
};
const byte kInstruction_cmp_lt_r6_208[] = {
  0xb8, 0xbf, 0xd0, 0x2e // It lt; cmp lt r6 208
};
const byte kInstruction_cmp_cc_r5_245[] = {
  0x38, 0xbf, 0xf5, 0x2d // It cc; cmp cc r5 245
};
const byte kInstruction_cmp_vs_r4_111[] = {
  0x68, 0xbf, 0x6f, 0x2c // It vs; cmp vs r4 111
};
const byte kInstruction_cmp_pl_r4_75[] = {
  0x58, 0xbf, 0x4b, 0x2c // It pl; cmp pl r4 75
};
const byte kInstruction_cmp_le_r6_59[] = {
  0xd8, 0xbf, 0x3b, 0x2e // It le; cmp le r6 59
};
const byte kInstruction_cmp_pl_r6_70[] = {
  0x58, 0xbf, 0x46, 0x2e // It pl; cmp pl r6 70
};
const byte kInstruction_cmp_vc_r1_191[] = {
  0x78, 0xbf, 0xbf, 0x29 // It vc; cmp vc r1 191
};
const byte kInstruction_cmp_le_r2_125[] = {
  0xd8, 0xbf, 0x7d, 0x2a // It le; cmp le r2 125
};
const byte kInstruction_cmp_ls_r4_249[] = {
  0x98, 0xbf, 0xf9, 0x2c // It ls; cmp ls r4 249
};
const byte kInstruction_cmp_vs_r2_41[] = {
  0x68, 0xbf, 0x29, 0x2a // It vs; cmp vs r2 41
};
const byte kInstruction_cmp_pl_r4_199[] = {
  0x58, 0xbf, 0xc7, 0x2c // It pl; cmp pl r4 199
};
const byte kInstruction_cmp_cc_r3_180[] = {
  0x38, 0xbf, 0xb4, 0x2b // It cc; cmp cc r3 180
};
const byte kInstruction_cmp_ls_r0_225[] = {
  0x98, 0xbf, 0xe1, 0x28 // It ls; cmp ls r0 225
};
const byte kInstruction_cmp_ne_r2_93[] = {
  0x18, 0xbf, 0x5d, 0x2a // It ne; cmp ne r2 93
};
const byte kInstruction_cmp_cc_r3_16[] = {
  0x38, 0xbf, 0x10, 0x2b // It cc; cmp cc r3 16
};
const byte kInstruction_cmp_pl_r1_223[] = {
  0x58, 0xbf, 0xdf, 0x29 // It pl; cmp pl r1 223
};
const byte kInstruction_cmp_ge_r0_129[] = {
  0xa8, 0xbf, 0x81, 0x28 // It ge; cmp ge r0 129
};
const byte kInstruction_cmp_lt_r5_34[] = {
  0xb8, 0xbf, 0x22, 0x2d // It lt; cmp lt r5 34
};
const byte kInstruction_cmp_vc_r5_156[] = {
  0x78, 0xbf, 0x9c, 0x2d // It vc; cmp vc r5 156
};
const byte kInstruction_cmp_hi_r0_29[] = {
  0x88, 0xbf, 0x1d, 0x28 // It hi; cmp hi r0 29
};
const byte kInstruction_cmp_eq_r5_228[] = {
  0x08, 0xbf, 0xe4, 0x2d // It eq; cmp eq r5 228
};
const byte kInstruction_cmp_ls_r5_86[] = {
  0x98, 0xbf, 0x56, 0x2d // It ls; cmp ls r5 86
};
const byte kInstruction_cmp_cs_r5_99[] = {
  0x28, 0xbf, 0x63, 0x2d // It cs; cmp cs r5 99
};
const byte kInstruction_cmp_eq_r4_217[] = {
  0x08, 0xbf, 0xd9, 0x2c // It eq; cmp eq r4 217
};
const byte kInstruction_cmp_ne_r0_15[] = {
  0x18, 0xbf, 0x0f, 0x28 // It ne; cmp ne r0 15
};
const byte kInstruction_cmp_ls_r2_17[] = {
  0x98, 0xbf, 0x11, 0x2a // It ls; cmp ls r2 17
};
const byte kInstruction_cmp_cs_r3_70[] = {
  0x28, 0xbf, 0x46, 0x2b // It cs; cmp cs r3 70
};
const byte kInstruction_cmp_ge_r0_60[] = {
  0xa8, 0xbf, 0x3c, 0x28 // It ge; cmp ge r0 60
};
const byte kInstruction_cmp_cc_r0_107[] = {
  0x38, 0xbf, 0x6b, 0x28 // It cc; cmp cc r0 107
};
const byte kInstruction_cmp_gt_r3_192[] = {
  0xc8, 0xbf, 0xc0, 0x2b // It gt; cmp gt r3 192
};
const byte kInstruction_cmp_ne_r1_175[] = {
  0x18, 0xbf, 0xaf, 0x29 // It ne; cmp ne r1 175
};
const byte kInstruction_cmp_le_r1_88[] = {
  0xd8, 0xbf, 0x58, 0x29 // It le; cmp le r1 88
};
const byte kInstruction_cmp_mi_r5_216[] = {
  0x48, 0xbf, 0xd8, 0x2d // It mi; cmp mi r5 216
};
const byte kInstruction_cmp_pl_r4_149[] = {
  0x58, 0xbf, 0x95, 0x2c // It pl; cmp pl r4 149
};
const byte kInstruction_cmp_cs_r6_28[] = {
  0x28, 0xbf, 0x1c, 0x2e // It cs; cmp cs r6 28
};
const byte kInstruction_cmp_vs_r1_65[] = {
  0x68, 0xbf, 0x41, 0x29 // It vs; cmp vs r1 65
};
const byte kInstruction_cmp_vs_r2_169[] = {
  0x68, 0xbf, 0xa9, 0x2a // It vs; cmp vs r2 169
};
const byte kInstruction_cmp_eq_r3_108[] = {
  0x08, 0xbf, 0x6c, 0x2b // It eq; cmp eq r3 108
};
const byte kInstruction_cmp_eq_r5_127[] = {
  0x08, 0xbf, 0x7f, 0x2d // It eq; cmp eq r5 127
};
const byte kInstruction_cmp_vc_r1_23[] = {
  0x78, 0xbf, 0x17, 0x29 // It vc; cmp vc r1 23
};
const byte kInstruction_cmp_pl_r7_132[] = {
  0x58, 0xbf, 0x84, 0x2f // It pl; cmp pl r7 132
};
const byte kInstruction_cmp_vc_r3_90[] = {
  0x78, 0xbf, 0x5a, 0x2b // It vc; cmp vc r3 90
};
const byte kInstruction_cmp_pl_r3_195[] = {
  0x58, 0xbf, 0xc3, 0x2b // It pl; cmp pl r3 195
};
const byte kInstruction_cmp_ne_r7_28[] = {
  0x18, 0xbf, 0x1c, 0x2f // It ne; cmp ne r7 28
};
const byte kInstruction_cmp_vs_r2_233[] = {
  0x68, 0xbf, 0xe9, 0x2a // It vs; cmp vs r2 233
};
const byte kInstruction_cmp_ge_r5_3[] = {
  0xa8, 0xbf, 0x03, 0x2d // It ge; cmp ge r5 3
};
const byte kInstruction_cmp_ge_r3_231[] = {
  0xa8, 0xbf, 0xe7, 0x2b // It ge; cmp ge r3 231
};
const byte kInstruction_cmp_pl_r2_10[] = {
  0x58, 0xbf, 0x0a, 0x2a // It pl; cmp pl r2 10
};
const byte kInstruction_cmp_le_r1_56[] = {
  0xd8, 0xbf, 0x38, 0x29 // It le; cmp le r1 56
};
const byte kInstruction_cmp_eq_r5_232[] = {
  0x08, 0xbf, 0xe8, 0x2d // It eq; cmp eq r5 232
};
const byte kInstruction_cmp_mi_r5_124[] = {
  0x48, 0xbf, 0x7c, 0x2d // It mi; cmp mi r5 124
};
const byte kInstruction_cmp_vc_r2_198[] = {
  0x78, 0xbf, 0xc6, 0x2a // It vc; cmp vc r2 198
};
const byte kInstruction_cmp_lt_r5_86[] = {
  0xb8, 0xbf, 0x56, 0x2d // It lt; cmp lt r5 86
};
const byte kInstruction_cmp_eq_r1_199[] = {
  0x08, 0xbf, 0xc7, 0x29 // It eq; cmp eq r1 199
};
const byte kInstruction_cmp_eq_r2_21[] = {
  0x08, 0xbf, 0x15, 0x2a // It eq; cmp eq r2 21
};
const byte kInstruction_cmp_mi_r4_194[] = {
  0x48, 0xbf, 0xc2, 0x2c // It mi; cmp mi r4 194
};
const byte kInstruction_cmp_ge_r1_235[] = {
  0xa8, 0xbf, 0xeb, 0x29 // It ge; cmp ge r1 235
};
const byte kInstruction_cmp_gt_r6_164[] = {
  0xc8, 0xbf, 0xa4, 0x2e // It gt; cmp gt r6 164
};
const byte kInstruction_cmp_ne_r0_132[] = {
  0x18, 0xbf, 0x84, 0x28 // It ne; cmp ne r0 132
};
const byte kInstruction_cmp_mi_r2_188[] = {
  0x48, 0xbf, 0xbc, 0x2a // It mi; cmp mi r2 188
};
const byte kInstruction_cmp_ls_r7_136[] = {
  0x98, 0xbf, 0x88, 0x2f // It ls; cmp ls r7 136
};
const byte kInstruction_cmp_mi_r3_248[] = {
  0x48, 0xbf, 0xf8, 0x2b // It mi; cmp mi r3 248
};
const byte kInstruction_cmp_pl_r1_248[] = {
  0x58, 0xbf, 0xf8, 0x29 // It pl; cmp pl r1 248
};
const byte kInstruction_cmp_gt_r1_4[] = {
  0xc8, 0xbf, 0x04, 0x29 // It gt; cmp gt r1 4
};
const byte kInstruction_cmp_eq_r3_171[] = {
  0x08, 0xbf, 0xab, 0x2b // It eq; cmp eq r3 171
};
const byte kInstruction_cmp_ge_r5_75[] = {
  0xa8, 0xbf, 0x4b, 0x2d // It ge; cmp ge r5 75
};
const byte kInstruction_cmp_ne_r6_115[] = {
  0x18, 0xbf, 0x73, 0x2e // It ne; cmp ne r6 115
};
const byte kInstruction_cmp_mi_r1_218[] = {
  0x48, 0xbf, 0xda, 0x29 // It mi; cmp mi r1 218
};
const byte kInstruction_cmp_pl_r6_160[] = {
  0x58, 0xbf, 0xa0, 0x2e // It pl; cmp pl r6 160
};
const byte kInstruction_cmp_ls_r3_69[] = {
  0x98, 0xbf, 0x45, 0x2b // It ls; cmp ls r3 69
};
const byte kInstruction_cmp_hi_r3_73[] = {
  0x88, 0xbf, 0x49, 0x2b // It hi; cmp hi r3 73
};
const byte kInstruction_cmp_cc_r2_248[] = {
  0x38, 0xbf, 0xf8, 0x2a // It cc; cmp cc r2 248
};
const byte kInstruction_cmp_le_r0_1[] = {
  0xd8, 0xbf, 0x01, 0x28 // It le; cmp le r0 1
};
const byte kInstruction_cmp_gt_r0_43[] = {
  0xc8, 0xbf, 0x2b, 0x28 // It gt; cmp gt r0 43
};
const byte kInstruction_cmp_pl_r7_202[] = {
  0x58, 0xbf, 0xca, 0x2f // It pl; cmp pl r7 202
};
const byte kInstruction_cmp_le_r3_8[] = {
  0xd8, 0xbf, 0x08, 0x2b // It le; cmp le r3 8
};
const byte kInstruction_cmp_ls_r1_235[] = {
  0x98, 0xbf, 0xeb, 0x29 // It ls; cmp ls r1 235
};
const byte kInstruction_cmp_cs_r5_223[] = {
  0x28, 0xbf, 0xdf, 0x2d // It cs; cmp cs r5 223
};
const byte kInstruction_cmp_le_r7_89[] = {
  0xd8, 0xbf, 0x59, 0x2f // It le; cmp le r7 89
};
const byte kInstruction_cmp_ls_r5_45[] = {
  0x98, 0xbf, 0x2d, 0x2d // It ls; cmp ls r5 45
};
const byte kInstruction_cmp_pl_r6_206[] = {
  0x58, 0xbf, 0xce, 0x2e // It pl; cmp pl r6 206
};
const byte kInstruction_cmp_ne_r3_12[] = {
  0x18, 0xbf, 0x0c, 0x2b // It ne; cmp ne r3 12
};
const byte kInstruction_cmp_vc_r3_37[] = {
  0x78, 0xbf, 0x25, 0x2b // It vc; cmp vc r3 37
};
const byte kInstruction_cmp_cs_r3_112[] = {
  0x28, 0xbf, 0x70, 0x2b // It cs; cmp cs r3 112
};
const byte kInstruction_cmp_cs_r3_10[] = {
  0x28, 0xbf, 0x0a, 0x2b // It cs; cmp cs r3 10
};
const byte kInstruction_cmp_cs_r0_206[] = {
  0x28, 0xbf, 0xce, 0x28 // It cs; cmp cs r0 206
};
const byte kInstruction_cmp_vs_r2_215[] = {
  0x68, 0xbf, 0xd7, 0x2a // It vs; cmp vs r2 215
};
const byte kInstruction_cmp_hi_r2_171[] = {
  0x88, 0xbf, 0xab, 0x2a // It hi; cmp hi r2 171
};
const byte kInstruction_cmp_ge_r3_117[] = {
  0xa8, 0xbf, 0x75, 0x2b // It ge; cmp ge r3 117
};
const byte kInstruction_cmp_vc_r7_211[] = {
  0x78, 0xbf, 0xd3, 0x2f // It vc; cmp vc r7 211
};
const byte kInstruction_cmp_hi_r6_147[] = {
  0x88, 0xbf, 0x93, 0x2e // It hi; cmp hi r6 147
};
const byte kInstruction_cmp_gt_r4_64[] = {
  0xc8, 0xbf, 0x40, 0x2c // It gt; cmp gt r4 64
};
const byte kInstruction_cmp_ge_r2_17[] = {
  0xa8, 0xbf, 0x11, 0x2a // It ge; cmp ge r2 17
};
const byte kInstruction_cmp_lt_r0_242[] = {
  0xb8, 0xbf, 0xf2, 0x28 // It lt; cmp lt r0 242
};
const byte kInstruction_cmp_ls_r5_144[] = {
  0x98, 0xbf, 0x90, 0x2d // It ls; cmp ls r5 144
};
const byte kInstruction_cmp_cc_r7_44[] = {
  0x38, 0xbf, 0x2c, 0x2f // It cc; cmp cc r7 44
};
const byte kInstruction_cmp_vs_r7_214[] = {
  0x68, 0xbf, 0xd6, 0x2f // It vs; cmp vs r7 214
};
const byte kInstruction_cmp_ge_r3_132[] = {
  0xa8, 0xbf, 0x84, 0x2b // It ge; cmp ge r3 132
};
const byte kInstruction_cmp_hi_r4_36[] = {
  0x88, 0xbf, 0x24, 0x2c // It hi; cmp hi r4 36
};
const byte kInstruction_cmp_cs_r1_5[] = {
  0x28, 0xbf, 0x05, 0x29 // It cs; cmp cs r1 5
};
const byte kInstruction_cmp_mi_r6_194[] = {
  0x48, 0xbf, 0xc2, 0x2e // It mi; cmp mi r6 194
};
const byte kInstruction_cmp_ge_r1_134[] = {
  0xa8, 0xbf, 0x86, 0x29 // It ge; cmp ge r1 134
};
const byte kInstruction_cmp_ls_r2_90[] = {
  0x98, 0xbf, 0x5a, 0x2a // It ls; cmp ls r2 90
};
const byte kInstruction_cmp_vc_r1_207[] = {
  0x78, 0xbf, 0xcf, 0x29 // It vc; cmp vc r1 207
};
const byte kInstruction_cmp_cc_r7_13[] = {
  0x38, 0xbf, 0x0d, 0x2f // It cc; cmp cc r7 13
};
const byte kInstruction_cmp_cc_r6_117[] = {
  0x38, 0xbf, 0x75, 0x2e // It cc; cmp cc r6 117
};
const byte kInstruction_cmp_mi_r2_113[] = {
  0x48, 0xbf, 0x71, 0x2a // It mi; cmp mi r2 113
};
const byte kInstruction_cmp_vc_r0_107[] = {
  0x78, 0xbf, 0x6b, 0x28 // It vc; cmp vc r0 107
};
const byte kInstruction_cmp_mi_r6_156[] = {
  0x48, 0xbf, 0x9c, 0x2e // It mi; cmp mi r6 156
};
const byte kInstruction_cmp_hi_r0_193[] = {
  0x88, 0xbf, 0xc1, 0x28 // It hi; cmp hi r0 193
};
const byte kInstruction_cmp_gt_r5_5[] = {
  0xc8, 0xbf, 0x05, 0x2d // It gt; cmp gt r5 5
};
const byte kInstruction_cmp_cc_r5_137[] = {
  0x38, 0xbf, 0x89, 0x2d // It cc; cmp cc r5 137
};
const byte kInstruction_cmp_vs_r1_60[] = {
  0x68, 0xbf, 0x3c, 0x29 // It vs; cmp vs r1 60
};
const byte kInstruction_cmp_ge_r5_156[] = {
  0xa8, 0xbf, 0x9c, 0x2d // It ge; cmp ge r5 156
};
const byte kInstruction_cmp_hi_r5_246[] = {
  0x88, 0xbf, 0xf6, 0x2d // It hi; cmp hi r5 246
};
const byte kInstruction_cmp_pl_r1_228[] = {
  0x58, 0xbf, 0xe4, 0x29 // It pl; cmp pl r1 228
};
const byte kInstruction_cmp_mi_r6_214[] = {
  0x48, 0xbf, 0xd6, 0x2e // It mi; cmp mi r6 214
};
const byte kInstruction_cmp_ls_r1_39[] = {
  0x98, 0xbf, 0x27, 0x29 // It ls; cmp ls r1 39
};
const byte kInstruction_cmp_ge_r2_201[] = {
  0xa8, 0xbf, 0xc9, 0x2a // It ge; cmp ge r2 201
};
const byte kInstruction_cmp_ls_r5_250[] = {
  0x98, 0xbf, 0xfa, 0x2d // It ls; cmp ls r5 250
};
const byte kInstruction_cmp_mi_r2_40[] = {
  0x48, 0xbf, 0x28, 0x2a // It mi; cmp mi r2 40
};
const byte kInstruction_cmp_cc_r4_225[] = {
  0x38, 0xbf, 0xe1, 0x2c // It cc; cmp cc r4 225
};
const byte kInstruction_cmp_ne_r1_96[] = {
  0x18, 0xbf, 0x60, 0x29 // It ne; cmp ne r1 96
};
const byte kInstruction_cmp_ge_r5_162[] = {
  0xa8, 0xbf, 0xa2, 0x2d // It ge; cmp ge r5 162
};
const byte kInstruction_cmp_eq_r5_176[] = {
  0x08, 0xbf, 0xb0, 0x2d // It eq; cmp eq r5 176
};
const byte kInstruction_cmp_lt_r1_246[] = {
  0xb8, 0xbf, 0xf6, 0x29 // It lt; cmp lt r1 246
};
const byte kInstruction_cmp_ls_r4_44[] = {
  0x98, 0xbf, 0x2c, 0x2c // It ls; cmp ls r4 44
};
const byte kInstruction_cmp_lt_r2_96[] = {
  0xb8, 0xbf, 0x60, 0x2a // It lt; cmp lt r2 96
};
const byte kInstruction_cmp_ge_r5_54[] = {
  0xa8, 0xbf, 0x36, 0x2d // It ge; cmp ge r5 54
};
const byte kInstruction_cmp_lt_r6_13[] = {
  0xb8, 0xbf, 0x0d, 0x2e // It lt; cmp lt r6 13
};
const byte kInstruction_cmp_mi_r5_106[] = {
  0x48, 0xbf, 0x6a, 0x2d // It mi; cmp mi r5 106
};
const byte kInstruction_cmp_vs_r5_62[] = {
  0x68, 0xbf, 0x3e, 0x2d // It vs; cmp vs r5 62
};
const byte kInstruction_cmp_vs_r5_235[] = {
  0x68, 0xbf, 0xeb, 0x2d // It vs; cmp vs r5 235
};
const byte kInstruction_cmp_hi_r1_49[] = {
  0x88, 0xbf, 0x31, 0x29 // It hi; cmp hi r1 49
};
const byte kInstruction_cmp_cs_r5_32[] = {
  0x28, 0xbf, 0x20, 0x2d // It cs; cmp cs r5 32
};
const byte kInstruction_cmp_cc_r7_43[] = {
  0x38, 0xbf, 0x2b, 0x2f // It cc; cmp cc r7 43
};
const byte kInstruction_cmp_pl_r6_122[] = {
  0x58, 0xbf, 0x7a, 0x2e // It pl; cmp pl r6 122
};
const byte kInstruction_cmp_eq_r7_87[] = {
  0x08, 0xbf, 0x57, 0x2f // It eq; cmp eq r7 87
};
const byte kInstruction_cmp_cc_r1_250[] = {
  0x38, 0xbf, 0xfa, 0x29 // It cc; cmp cc r1 250
};
const byte kInstruction_cmp_vc_r1_236[] = {
  0x78, 0xbf, 0xec, 0x29 // It vc; cmp vc r1 236
};
const byte kInstruction_cmp_pl_r1_83[] = {
  0x58, 0xbf, 0x53, 0x29 // It pl; cmp pl r1 83
};
const byte kInstruction_cmp_gt_r2_228[] = {
  0xc8, 0xbf, 0xe4, 0x2a // It gt; cmp gt r2 228
};
const byte kInstruction_cmp_mi_r1_41[] = {
  0x48, 0xbf, 0x29, 0x29 // It mi; cmp mi r1 41
};
const byte kInstruction_cmp_hi_r1_42[] = {
  0x88, 0xbf, 0x2a, 0x29 // It hi; cmp hi r1 42
};
const byte kInstruction_cmp_hi_r0_242[] = {
  0x88, 0xbf, 0xf2, 0x28 // It hi; cmp hi r0 242
};
const byte kInstruction_cmp_ne_r7_9[] = {
  0x18, 0xbf, 0x09, 0x2f // It ne; cmp ne r7 9
};
const byte kInstruction_cmp_lt_r3_0[] = {
  0xb8, 0xbf, 0x00, 0x2b // It lt; cmp lt r3 0
};
const byte kInstruction_cmp_pl_r0_183[] = {
  0x58, 0xbf, 0xb7, 0x28 // It pl; cmp pl r0 183
};
const byte kInstruction_cmp_hi_r2_117[] = {
  0x88, 0xbf, 0x75, 0x2a // It hi; cmp hi r2 117
};
const byte kInstruction_cmp_hi_r0_77[] = {
  0x88, 0xbf, 0x4d, 0x28 // It hi; cmp hi r0 77
};
const byte kInstruction_cmp_ls_r3_159[] = {
  0x98, 0xbf, 0x9f, 0x2b // It ls; cmp ls r3 159
};
const byte kInstruction_cmp_cc_r4_5[] = {
  0x38, 0xbf, 0x05, 0x2c // It cc; cmp cc r4 5
};
const byte kInstruction_cmp_vc_r4_244[] = {
  0x78, 0xbf, 0xf4, 0x2c // It vc; cmp vc r4 244
};
const byte kInstruction_cmp_hi_r2_121[] = {
  0x88, 0xbf, 0x79, 0x2a // It hi; cmp hi r2 121
};
const byte kInstruction_cmp_le_r3_90[] = {
  0xd8, 0xbf, 0x5a, 0x2b // It le; cmp le r3 90
};
const byte kInstruction_cmp_vc_r6_10[] = {
  0x78, 0xbf, 0x0a, 0x2e // It vc; cmp vc r6 10
};
const byte kInstruction_cmp_cs_r5_150[] = {
  0x28, 0xbf, 0x96, 0x2d // It cs; cmp cs r5 150
};
const byte kInstruction_cmp_vc_r7_117[] = {
  0x78, 0xbf, 0x75, 0x2f // It vc; cmp vc r7 117
};
const byte kInstruction_cmp_cs_r7_211[] = {
  0x28, 0xbf, 0xd3, 0x2f // It cs; cmp cs r7 211
};
const byte kInstruction_cmp_cs_r0_18[] = {
  0x28, 0xbf, 0x12, 0x28 // It cs; cmp cs r0 18
};
const byte kInstruction_cmp_ne_r2_60[] = {
  0x18, 0xbf, 0x3c, 0x2a // It ne; cmp ne r2 60
};
const byte kInstruction_cmp_ge_r0_223[] = {
  0xa8, 0xbf, 0xdf, 0x28 // It ge; cmp ge r0 223
};
const byte kInstruction_cmp_lt_r1_176[] = {
  0xb8, 0xbf, 0xb0, 0x29 // It lt; cmp lt r1 176
};
const byte kInstruction_cmp_eq_r6_15[] = {
  0x08, 0xbf, 0x0f, 0x2e // It eq; cmp eq r6 15
};
const byte kInstruction_cmp_vs_r7_74[] = {
  0x68, 0xbf, 0x4a, 0x2f // It vs; cmp vs r7 74
};
const byte kInstruction_cmp_ne_r5_68[] = {
  0x18, 0xbf, 0x44, 0x2d // It ne; cmp ne r5 68
};
const byte kInstruction_cmp_ne_r7_49[] = {
  0x18, 0xbf, 0x31, 0x2f // It ne; cmp ne r7 49
};
const byte kInstruction_cmp_le_r0_139[] = {
  0xd8, 0xbf, 0x8b, 0x28 // It le; cmp le r0 139
};
const byte kInstruction_cmp_ge_r3_218[] = {
  0xa8, 0xbf, 0xda, 0x2b // It ge; cmp ge r3 218
};
const byte kInstruction_cmp_ge_r2_25[] = {
  0xa8, 0xbf, 0x19, 0x2a // It ge; cmp ge r2 25
};
const byte kInstruction_cmp_mi_r5_117[] = {
  0x48, 0xbf, 0x75, 0x2d // It mi; cmp mi r5 117
};
const byte kInstruction_cmp_pl_r7_57[] = {
  0x58, 0xbf, 0x39, 0x2f // It pl; cmp pl r7 57
};
const byte kInstruction_cmp_gt_r7_7[] = {
  0xc8, 0xbf, 0x07, 0x2f // It gt; cmp gt r7 7
};
const byte kInstruction_cmp_ne_r4_55[] = {
  0x18, 0xbf, 0x37, 0x2c // It ne; cmp ne r4 55
};
const byte kInstruction_cmp_ne_r7_56[] = {
  0x18, 0xbf, 0x38, 0x2f // It ne; cmp ne r7 56
};
const byte kInstruction_cmp_cc_r5_55[] = {
  0x38, 0xbf, 0x37, 0x2d // It cc; cmp cc r5 55
};
const byte kInstruction_cmp_cc_r7_84[] = {
  0x38, 0xbf, 0x54, 0x2f // It cc; cmp cc r7 84
};
const byte kInstruction_cmp_cs_r5_229[] = {
  0x28, 0xbf, 0xe5, 0x2d // It cs; cmp cs r5 229
};
const byte kInstruction_cmp_ne_r1_205[] = {
  0x18, 0xbf, 0xcd, 0x29 // It ne; cmp ne r1 205
};
const byte kInstruction_cmp_ge_r1_133[] = {
  0xa8, 0xbf, 0x85, 0x29 // It ge; cmp ge r1 133
};
const byte kInstruction_cmp_vc_r0_25[] = {
  0x78, 0xbf, 0x19, 0x28 // It vc; cmp vc r0 25
};
const byte kInstruction_cmp_ge_r0_114[] = {
  0xa8, 0xbf, 0x72, 0x28 // It ge; cmp ge r0 114
};
const byte kInstruction_cmp_le_r5_135[] = {
  0xd8, 0xbf, 0x87, 0x2d // It le; cmp le r5 135
};
const byte kInstruction_cmp_pl_r3_145[] = {
  0x58, 0xbf, 0x91, 0x2b // It pl; cmp pl r3 145
};
const byte kInstruction_cmp_le_r5_197[] = {
  0xd8, 0xbf, 0xc5, 0x2d // It le; cmp le r5 197
};
const byte kInstruction_cmp_vc_r0_14[] = {
  0x78, 0xbf, 0x0e, 0x28 // It vc; cmp vc r0 14
};
const byte kInstruction_cmp_vc_r3_113[] = {
  0x78, 0xbf, 0x71, 0x2b // It vc; cmp vc r3 113
};
const byte kInstruction_cmp_le_r3_224[] = {
  0xd8, 0xbf, 0xe0, 0x2b // It le; cmp le r3 224
};
const byte kInstruction_cmp_le_r1_99[] = {
  0xd8, 0xbf, 0x63, 0x29 // It le; cmp le r1 99
};
const byte kInstruction_cmp_le_r6_222[] = {
  0xd8, 0xbf, 0xde, 0x2e // It le; cmp le r6 222
};
const byte kInstruction_cmp_vc_r6_15[] = {
  0x78, 0xbf, 0x0f, 0x2e // It vc; cmp vc r6 15
};
const byte kInstruction_cmp_ge_r5_59[] = {
  0xa8, 0xbf, 0x3b, 0x2d // It ge; cmp ge r5 59
};
const byte kInstruction_cmp_mi_r2_187[] = {
  0x48, 0xbf, 0xbb, 0x2a // It mi; cmp mi r2 187
};
const byte kInstruction_cmp_ls_r0_107[] = {
  0x98, 0xbf, 0x6b, 0x28 // It ls; cmp ls r0 107
};
const byte kInstruction_cmp_le_r6_111[] = {
  0xd8, 0xbf, 0x6f, 0x2e // It le; cmp le r6 111
};
const byte kInstruction_cmp_hi_r7_58[] = {
  0x88, 0xbf, 0x3a, 0x2f // It hi; cmp hi r7 58
};
const byte kInstruction_cmp_le_r1_143[] = {
  0xd8, 0xbf, 0x8f, 0x29 // It le; cmp le r1 143
};
const byte kInstruction_cmp_cs_r7_181[] = {
  0x28, 0xbf, 0xb5, 0x2f // It cs; cmp cs r7 181
};
const byte kInstruction_cmp_hi_r4_235[] = {
  0x88, 0xbf, 0xeb, 0x2c // It hi; cmp hi r4 235
};
const byte kInstruction_cmp_vs_r3_69[] = {
  0x68, 0xbf, 0x45, 0x2b // It vs; cmp vs r3 69
};
const byte kInstruction_cmp_ls_r1_100[] = {
  0x98, 0xbf, 0x64, 0x29 // It ls; cmp ls r1 100
};
const byte kInstruction_cmp_ne_r7_93[] = {
  0x18, 0xbf, 0x5d, 0x2f // It ne; cmp ne r7 93
};
const byte kInstruction_cmp_pl_r5_10[] = {
  0x58, 0xbf, 0x0a, 0x2d // It pl; cmp pl r5 10
};
const byte kInstruction_cmp_eq_r0_158[] = {
  0x08, 0xbf, 0x9e, 0x28 // It eq; cmp eq r0 158
};
const byte kInstruction_cmp_pl_r5_8[] = {
  0x58, 0xbf, 0x08, 0x2d // It pl; cmp pl r5 8
};
const byte kInstruction_cmp_vc_r5_172[] = {
  0x78, 0xbf, 0xac, 0x2d // It vc; cmp vc r5 172
};
const byte kInstruction_cmp_ne_r6_0[] = {
  0x18, 0xbf, 0x00, 0x2e // It ne; cmp ne r6 0
};
const byte kInstruction_cmp_mi_r0_106[] = {
  0x48, 0xbf, 0x6a, 0x28 // It mi; cmp mi r0 106
};
const byte kInstruction_cmp_vs_r7_229[] = {
  0x68, 0xbf, 0xe5, 0x2f // It vs; cmp vs r7 229
};
const byte kInstruction_cmp_ne_r6_75[] = {
  0x18, 0xbf, 0x4b, 0x2e // It ne; cmp ne r6 75
};
const byte kInstruction_cmp_cc_r7_247[] = {
  0x38, 0xbf, 0xf7, 0x2f // It cc; cmp cc r7 247
};
const byte kInstruction_cmp_ne_r0_171[] = {
  0x18, 0xbf, 0xab, 0x28 // It ne; cmp ne r0 171
};
const byte kInstruction_cmp_lt_r6_76[] = {
  0xb8, 0xbf, 0x4c, 0x2e // It lt; cmp lt r6 76
};
const byte kInstruction_cmp_ls_r6_20[] = {
  0x98, 0xbf, 0x14, 0x2e // It ls; cmp ls r6 20
};
const byte kInstruction_cmp_ne_r3_79[] = {
  0x18, 0xbf, 0x4f, 0x2b // It ne; cmp ne r3 79
};
const byte kInstruction_cmp_lt_r4_214[] = {
  0xb8, 0xbf, 0xd6, 0x2c // It lt; cmp lt r4 214
};
const byte kInstruction_cmp_gt_r1_108[] = {
  0xc8, 0xbf, 0x6c, 0x29 // It gt; cmp gt r1 108
};
const byte kInstruction_cmp_ls_r0_149[] = {
  0x98, 0xbf, 0x95, 0x28 // It ls; cmp ls r0 149
};
const byte kInstruction_cmp_vc_r5_218[] = {
  0x78, 0xbf, 0xda, 0x2d // It vc; cmp vc r5 218
};
const byte kInstruction_cmp_hi_r3_65[] = {
  0x88, 0xbf, 0x41, 0x2b // It hi; cmp hi r3 65
};
const byte kInstruction_cmp_ge_r4_9[] = {
  0xa8, 0xbf, 0x09, 0x2c // It ge; cmp ge r4 9
};
const byte kInstruction_cmp_ls_r2_252[] = {
  0x98, 0xbf, 0xfc, 0x2a // It ls; cmp ls r2 252
};
const byte kInstruction_cmp_vs_r1_107[] = {
  0x68, 0xbf, 0x6b, 0x29 // It vs; cmp vs r1 107
};
const byte kInstruction_cmp_le_r7_32[] = {
  0xd8, 0xbf, 0x20, 0x2f // It le; cmp le r7 32
};
const byte kInstruction_cmp_cs_r7_22[] = {
  0x28, 0xbf, 0x16, 0x2f // It cs; cmp cs r7 22
};
const byte kInstruction_cmp_le_r1_145[] = {
  0xd8, 0xbf, 0x91, 0x29 // It le; cmp le r1 145
};
const byte kInstruction_cmp_ne_r2_144[] = {
  0x18, 0xbf, 0x90, 0x2a // It ne; cmp ne r2 144
};
const byte kInstruction_cmp_mi_r4_79[] = {
  0x48, 0xbf, 0x4f, 0x2c // It mi; cmp mi r4 79
};
const byte kInstruction_cmp_ne_r5_240[] = {
  0x18, 0xbf, 0xf0, 0x2d // It ne; cmp ne r5 240
};
const byte kInstruction_cmp_lt_r7_251[] = {
  0xb8, 0xbf, 0xfb, 0x2f // It lt; cmp lt r7 251
};
const byte kInstruction_cmp_le_r0_118[] = {
  0xd8, 0xbf, 0x76, 0x28 // It le; cmp le r0 118
};
const byte kInstruction_cmp_eq_r0_199[] = {
  0x08, 0xbf, 0xc7, 0x28 // It eq; cmp eq r0 199
};
const byte kInstruction_cmp_hi_r3_105[] = {
  0x88, 0xbf, 0x69, 0x2b // It hi; cmp hi r3 105
};
const byte kInstruction_cmp_cs_r3_215[] = {
  0x28, 0xbf, 0xd7, 0x2b // It cs; cmp cs r3 215
};
const byte kInstruction_cmp_ge_r7_19[] = {
  0xa8, 0xbf, 0x13, 0x2f // It ge; cmp ge r7 19
};
const byte kInstruction_cmp_le_r4_94[] = {
  0xd8, 0xbf, 0x5e, 0x2c // It le; cmp le r4 94
};
const byte kInstruction_cmp_hi_r4_100[] = {
  0x88, 0xbf, 0x64, 0x2c // It hi; cmp hi r4 100
};
const byte kInstruction_cmp_cc_r7_116[] = {
  0x38, 0xbf, 0x74, 0x2f // It cc; cmp cc r7 116
};
const byte kInstruction_cmp_ls_r4_168[] = {
  0x98, 0xbf, 0xa8, 0x2c // It ls; cmp ls r4 168
};
const byte kInstruction_cmp_lt_r5_5[] = {
  0xb8, 0xbf, 0x05, 0x2d // It lt; cmp lt r5 5
};
const byte kInstruction_cmp_vc_r4_121[] = {
  0x78, 0xbf, 0x79, 0x2c // It vc; cmp vc r4 121
};
const byte kInstruction_cmp_ls_r2_235[] = {
  0x98, 0xbf, 0xeb, 0x2a // It ls; cmp ls r2 235
};
const byte kInstruction_cmp_gt_r2_65[] = {
  0xc8, 0xbf, 0x41, 0x2a // It gt; cmp gt r2 65
};
const byte kInstruction_cmp_le_r0_153[] = {
  0xd8, 0xbf, 0x99, 0x28 // It le; cmp le r0 153
};
const byte kInstruction_cmp_ge_r2_92[] = {
  0xa8, 0xbf, 0x5c, 0x2a // It ge; cmp ge r2 92
};
const byte kInstruction_cmp_cs_r7_183[] = {
  0x28, 0xbf, 0xb7, 0x2f // It cs; cmp cs r7 183
};
const byte kInstruction_cmp_vs_r7_90[] = {
  0x68, 0xbf, 0x5a, 0x2f // It vs; cmp vs r7 90
};
const byte kInstruction_cmp_ge_r7_83[] = {
  0xa8, 0xbf, 0x53, 0x2f // It ge; cmp ge r7 83
};
const byte kInstruction_cmp_vc_r6_170[] = {
  0x78, 0xbf, 0xaa, 0x2e // It vc; cmp vc r6 170
};
const byte kInstruction_cmp_vs_r7_13[] = {
  0x68, 0xbf, 0x0d, 0x2f // It vs; cmp vs r7 13
};
const byte kInstruction_cmp_cc_r2_26[] = {
  0x38, 0xbf, 0x1a, 0x2a // It cc; cmp cc r2 26
};
const byte kInstruction_cmp_ls_r3_118[] = {
  0x98, 0xbf, 0x76, 0x2b // It ls; cmp ls r3 118
};
const byte kInstruction_cmp_vc_r4_78[] = {
  0x78, 0xbf, 0x4e, 0x2c // It vc; cmp vc r4 78
};
const byte kInstruction_cmp_vc_r1_222[] = {
  0x78, 0xbf, 0xde, 0x29 // It vc; cmp vc r1 222
};
const byte kInstruction_cmp_ls_r7_16[] = {
  0x98, 0xbf, 0x10, 0x2f // It ls; cmp ls r7 16
};
const byte kInstruction_cmp_vs_r4_41[] = {
  0x68, 0xbf, 0x29, 0x2c // It vs; cmp vs r4 41
};
const byte kInstruction_cmp_lt_r3_21[] = {
  0xb8, 0xbf, 0x15, 0x2b // It lt; cmp lt r3 21
};
const byte kInstruction_cmp_gt_r5_73[] = {
  0xc8, 0xbf, 0x49, 0x2d // It gt; cmp gt r5 73
};
const byte kInstruction_cmp_vs_r2_21[] = {
  0x68, 0xbf, 0x15, 0x2a // It vs; cmp vs r2 21
};
const byte kInstruction_cmp_gt_r6_212[] = {
  0xc8, 0xbf, 0xd4, 0x2e // It gt; cmp gt r6 212
};
const byte kInstruction_cmp_ge_r0_217[] = {
  0xa8, 0xbf, 0xd9, 0x28 // It ge; cmp ge r0 217
};
const byte kInstruction_cmp_ge_r3_163[] = {
  0xa8, 0xbf, 0xa3, 0x2b // It ge; cmp ge r3 163
};
const byte kInstruction_cmp_hi_r4_180[] = {
  0x88, 0xbf, 0xb4, 0x2c // It hi; cmp hi r4 180
};
const byte kInstruction_cmp_cs_r3_163[] = {
  0x28, 0xbf, 0xa3, 0x2b // It cs; cmp cs r3 163
};
const byte kInstruction_cmp_hi_r3_3[] = {
  0x88, 0xbf, 0x03, 0x2b // It hi; cmp hi r3 3
};
const byte kInstruction_cmp_gt_r3_121[] = {
  0xc8, 0xbf, 0x79, 0x2b // It gt; cmp gt r3 121
};
const byte kInstruction_cmp_cs_r0_82[] = {
  0x28, 0xbf, 0x52, 0x28 // It cs; cmp cs r0 82
};
const byte kInstruction_cmp_cc_r1_204[] = {
  0x38, 0xbf, 0xcc, 0x29 // It cc; cmp cc r1 204
};
const byte kInstruction_cmp_cc_r2_16[] = {
  0x38, 0xbf, 0x10, 0x2a // It cc; cmp cc r2 16
};
const byte kInstruction_cmp_le_r4_152[] = {
  0xd8, 0xbf, 0x98, 0x2c // It le; cmp le r4 152
};
const byte kInstruction_cmp_ls_r6_168[] = {
  0x98, 0xbf, 0xa8, 0x2e // It ls; cmp ls r6 168
};
const byte kInstruction_cmp_cs_r4_85[] = {
  0x28, 0xbf, 0x55, 0x2c // It cs; cmp cs r4 85
};
const byte kInstruction_cmp_lt_r7_175[] = {
  0xb8, 0xbf, 0xaf, 0x2f // It lt; cmp lt r7 175
};
const byte kInstruction_cmp_cs_r7_165[] = {
  0x28, 0xbf, 0xa5, 0x2f // It cs; cmp cs r7 165
};
const byte kInstruction_cmp_ge_r1_6[] = {
  0xa8, 0xbf, 0x06, 0x29 // It ge; cmp ge r1 6
};
const byte kInstruction_cmp_cs_r3_59[] = {
  0x28, 0xbf, 0x3b, 0x2b // It cs; cmp cs r3 59
};
const byte kInstruction_cmp_ne_r1_223[] = {
  0x18, 0xbf, 0xdf, 0x29 // It ne; cmp ne r1 223
};
const byte kInstruction_cmp_vs_r1_222[] = {
  0x68, 0xbf, 0xde, 0x29 // It vs; cmp vs r1 222
};
const byte kInstruction_cmp_cs_r0_102[] = {
  0x28, 0xbf, 0x66, 0x28 // It cs; cmp cs r0 102
};
const byte kInstruction_cmp_ls_r0_62[] = {
  0x98, 0xbf, 0x3e, 0x28 // It ls; cmp ls r0 62
};
const byte kInstruction_cmp_vs_r6_97[] = {
  0x68, 0xbf, 0x61, 0x2e // It vs; cmp vs r6 97
};
const byte kInstruction_cmp_gt_r6_60[] = {
  0xc8, 0xbf, 0x3c, 0x2e // It gt; cmp gt r6 60
};
const byte kInstruction_cmp_mi_r7_144[] = {
  0x48, 0xbf, 0x90, 0x2f // It mi; cmp mi r7 144
};
const byte kInstruction_cmp_vs_r4_0[] = {
  0x68, 0xbf, 0x00, 0x2c // It vs; cmp vs r4 0
};
const byte kInstruction_cmp_hi_r5_62[] = {
  0x88, 0xbf, 0x3e, 0x2d // It hi; cmp hi r5 62
};
const byte kInstruction_cmp_le_r1_49[] = {
  0xd8, 0xbf, 0x31, 0x29 // It le; cmp le r1 49
};
const byte kInstruction_cmp_le_r4_178[] = {
  0xd8, 0xbf, 0xb2, 0x2c // It le; cmp le r4 178
};
const byte kInstruction_cmp_lt_r3_149[] = {
  0xb8, 0xbf, 0x95, 0x2b // It lt; cmp lt r3 149
};
const byte kInstruction_cmp_vs_r7_64[] = {
  0x68, 0xbf, 0x40, 0x2f // It vs; cmp vs r7 64
};
const byte kInstruction_cmp_ne_r3_202[] = {
  0x18, 0xbf, 0xca, 0x2b // It ne; cmp ne r3 202
};
const byte kInstruction_cmp_ne_r2_164[] = {
  0x18, 0xbf, 0xa4, 0x2a // It ne; cmp ne r2 164
};
const byte kInstruction_cmp_gt_r3_193[] = {
  0xc8, 0xbf, 0xc1, 0x2b // It gt; cmp gt r3 193
};
const byte kInstruction_cmp_le_r7_164[] = {
  0xd8, 0xbf, 0xa4, 0x2f // It le; cmp le r7 164
};
const byte kInstruction_cmp_eq_r6_151[] = {
  0x08, 0xbf, 0x97, 0x2e // It eq; cmp eq r6 151
};
const byte kInstruction_cmp_hi_r3_38[] = {
  0x88, 0xbf, 0x26, 0x2b // It hi; cmp hi r3 38
};
const byte kInstruction_cmp_gt_r7_191[] = {
  0xc8, 0xbf, 0xbf, 0x2f // It gt; cmp gt r7 191
};
const byte kInstruction_cmp_ge_r6_42[] = {
  0xa8, 0xbf, 0x2a, 0x2e // It ge; cmp ge r6 42
};
const byte kInstruction_cmp_vc_r6_247[] = {
  0x78, 0xbf, 0xf7, 0x2e // It vc; cmp vc r6 247
};
const byte kInstruction_cmp_hi_r5_236[] = {
  0x88, 0xbf, 0xec, 0x2d // It hi; cmp hi r5 236
};
const byte kInstruction_cmp_hi_r5_234[] = {
  0x88, 0xbf, 0xea, 0x2d // It hi; cmp hi r5 234
};
const byte kInstruction_cmp_le_r4_126[] = {
  0xd8, 0xbf, 0x7e, 0x2c // It le; cmp le r4 126
};
const byte kInstruction_cmp_gt_r7_241[] = {
  0xc8, 0xbf, 0xf1, 0x2f // It gt; cmp gt r7 241
};
const byte kInstruction_cmp_hi_r7_116[] = {
  0x88, 0xbf, 0x74, 0x2f // It hi; cmp hi r7 116
};
const byte kInstruction_cmp_cs_r7_119[] = {
  0x28, 0xbf, 0x77, 0x2f // It cs; cmp cs r7 119
};
const byte kInstruction_cmp_ge_r3_148[] = {
  0xa8, 0xbf, 0x94, 0x2b // It ge; cmp ge r3 148
};
const byte kInstruction_cmp_gt_r7_88[] = {
  0xc8, 0xbf, 0x58, 0x2f // It gt; cmp gt r7 88
};
const byte kInstruction_cmp_vc_r6_58[] = {
  0x78, 0xbf, 0x3a, 0x2e // It vc; cmp vc r6 58
};
const byte kInstruction_cmp_mi_r6_157[] = {
  0x48, 0xbf, 0x9d, 0x2e // It mi; cmp mi r6 157
};
const byte kInstruction_cmp_cs_r0_129[] = {
  0x28, 0xbf, 0x81, 0x28 // It cs; cmp cs r0 129
};
const byte kInstruction_cmp_vc_r1_161[] = {
  0x78, 0xbf, 0xa1, 0x29 // It vc; cmp vc r1 161
};
const byte kInstruction_cmp_mi_r0_34[] = {
  0x48, 0xbf, 0x22, 0x28 // It mi; cmp mi r0 34
};
const TestResult kReferencecmp[] = {
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_111),
    kInstruction_cmp_vc_r1_111,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_134),
    kInstruction_cmp_ne_r1_134,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_21),
    kInstruction_cmp_ne_r5_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_221),
    kInstruction_cmp_cs_r6_221,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_100),
    kInstruction_cmp_cs_r3_100,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_209),
    kInstruction_cmp_le_r2_209,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_8),
    kInstruction_cmp_ls_r7_8,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_201),
    kInstruction_cmp_cs_r7_201,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_112),
    kInstruction_cmp_ne_r3_112,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_152),
    kInstruction_cmp_lt_r4_152,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_165),
    kInstruction_cmp_mi_r4_165,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_175),
    kInstruction_cmp_eq_r6_175,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_187),
    kInstruction_cmp_hi_r3_187,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_192),
    kInstruction_cmp_ne_r0_192,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r7_207),
    kInstruction_cmp_vc_r7_207,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_135),
    kInstruction_cmp_vs_r3_135,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_204),
    kInstruction_cmp_cs_r4_204,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_122),
    kInstruction_cmp_gt_r0_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_185),
    kInstruction_cmp_lt_r4_185,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_187),
    kInstruction_cmp_eq_r2_187,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_226),
    kInstruction_cmp_ne_r5_226,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_250),
    kInstruction_cmp_ge_r1_250,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_97),
    kInstruction_cmp_lt_r7_97,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_21),
    kInstruction_cmp_cs_r4_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_217),
    kInstruction_cmp_vc_r0_217,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_81),
    kInstruction_cmp_mi_r1_81,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_156),
    kInstruction_cmp_cc_r5_156,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_171),
    kInstruction_cmp_ne_r7_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_252),
    kInstruction_cmp_vs_r2_252,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_103),
    kInstruction_cmp_lt_r4_103,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_203),
    kInstruction_cmp_ge_r6_203,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_234),
    kInstruction_cmp_ne_r4_234,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_27),
    kInstruction_cmp_mi_r2_27,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_224),
    kInstruction_cmp_ne_r4_224,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_124),
    kInstruction_cmp_gt_r3_124,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_49),
    kInstruction_cmp_lt_r4_49,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_201),
    kInstruction_cmp_gt_r1_201,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r4_133),
    kInstruction_cmp_ge_r4_133,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_176),
    kInstruction_cmp_hi_r4_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_94),
    kInstruction_cmp_pl_r3_94,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_69),
    kInstruction_cmp_le_r2_69,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_145),
    kInstruction_cmp_hi_r0_145,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_119),
    kInstruction_cmp_ne_r1_119,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_124),
    kInstruction_cmp_hi_r0_124,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_221),
    kInstruction_cmp_vc_r6_221,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_71),
    kInstruction_cmp_cs_r2_71,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_87),
    kInstruction_cmp_eq_r0_87,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_42),
    kInstruction_cmp_cc_r3_42,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_98),
    kInstruction_cmp_cs_r7_98,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_28),
    kInstruction_cmp_vc_r3_28,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r4_94),
    kInstruction_cmp_eq_r4_94,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_84),
    kInstruction_cmp_gt_r7_84,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_101),
    kInstruction_cmp_hi_r3_101,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_197),
    kInstruction_cmp_pl_r5_197,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_214),
    kInstruction_cmp_pl_r6_214,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_32),
    kInstruction_cmp_hi_r7_32,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_217),
    kInstruction_cmp_ge_r7_217,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_21),
    kInstruction_cmp_cc_r3_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_216),
    kInstruction_cmp_le_r2_216,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_199),
    kInstruction_cmp_le_r5_199,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_162),
    kInstruction_cmp_cc_r3_162,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_39),
    kInstruction_cmp_cs_r5_39,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_204),
    kInstruction_cmp_cc_r5_204,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_182),
    kInstruction_cmp_ge_r1_182,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_12),
    kInstruction_cmp_ne_r5_12,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_39),
    kInstruction_cmp_lt_r4_39,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_205),
    kInstruction_cmp_vc_r5_205,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_36),
    kInstruction_cmp_cc_r7_36,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_121),
    kInstruction_cmp_pl_r1_121,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_206),
    kInstruction_cmp_lt_r3_206,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_130),
    kInstruction_cmp_ne_r5_130,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_84),
    kInstruction_cmp_pl_r2_84,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_180),
    kInstruction_cmp_pl_r5_180,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_126),
    kInstruction_cmp_ne_r1_126,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_91),
    kInstruction_cmp_ge_r5_91,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_48),
    kInstruction_cmp_pl_r6_48,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_241),
    kInstruction_cmp_mi_r3_241,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_197),
    kInstruction_cmp_le_r3_197,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_154),
    kInstruction_cmp_gt_r3_154,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_31),
    kInstruction_cmp_vc_r1_31,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_218),
    kInstruction_cmp_ls_r4_218,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_237),
    kInstruction_cmp_ne_r0_237,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_171),
    kInstruction_cmp_ge_r0_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_102),
    kInstruction_cmp_cc_r7_102,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_245),
    kInstruction_cmp_ge_r5_245,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_28),
    kInstruction_cmp_ne_r4_28,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_186),
    kInstruction_cmp_cs_r7_186,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_30),
    kInstruction_cmp_ls_r0_30,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_17),
    kInstruction_cmp_ge_r1_17,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_92),
    kInstruction_cmp_cc_r5_92,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_71),
    kInstruction_cmp_mi_r1_71,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_250),
    kInstruction_cmp_vs_r4_250,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_170),
    kInstruction_cmp_le_r3_170,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_64),
    kInstruction_cmp_mi_r3_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_177),
    kInstruction_cmp_ls_r2_177,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_70),
    kInstruction_cmp_vs_r5_70,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_51),
    kInstruction_cmp_vs_r4_51,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_176),
    kInstruction_cmp_vs_r3_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_101),
    kInstruction_cmp_le_r1_101,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_74),
    kInstruction_cmp_ne_r3_74,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_210),
    kInstruction_cmp_ge_r0_210,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_181),
    kInstruction_cmp_gt_r1_181,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r7_223),
    kInstruction_cmp_eq_r7_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_175),
    kInstruction_cmp_ge_r3_175,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_106),
    kInstruction_cmp_eq_r3_106,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_127),
    kInstruction_cmp_ge_r5_127,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_59),
    kInstruction_cmp_cc_r5_59,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_0),
    kInstruction_cmp_cs_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_133),
    kInstruction_cmp_gt_r6_133,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_56),
    kInstruction_cmp_ls_r1_56,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_25),
    kInstruction_cmp_le_r3_25,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_24),
    kInstruction_cmp_vc_r1_24,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_59),
    kInstruction_cmp_eq_r2_59,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_35),
    kInstruction_cmp_eq_r3_35,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_68),
    kInstruction_cmp_ls_r1_68,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_240),
    kInstruction_cmp_hi_r5_240,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_58),
    kInstruction_cmp_ls_r1_58,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_207),
    kInstruction_cmp_cc_r7_207,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r6_138),
    kInstruction_cmp_ls_r6_138,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_192),
    kInstruction_cmp_lt_r5_192,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_210),
    kInstruction_cmp_ne_r7_210,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_82),
    kInstruction_cmp_eq_r3_82,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_174),
    kInstruction_cmp_gt_r3_174,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_10),
    kInstruction_cmp_ge_r6_10,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_113),
    kInstruction_cmp_vs_r3_113,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_102),
    kInstruction_cmp_hi_r2_102,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_81),
    kInstruction_cmp_le_r1_81,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_8),
    kInstruction_cmp_vc_r3_8,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_60),
    kInstruction_cmp_mi_r4_60,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_133),
    kInstruction_cmp_pl_r7_133,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_41),
    kInstruction_cmp_le_r0_41,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_4),
    kInstruction_cmp_vc_r6_4,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_243),
    kInstruction_cmp_ls_r7_243,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_129),
    kInstruction_cmp_mi_r3_129,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_3),
    kInstruction_cmp_eq_r6_3,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_28),
    kInstruction_cmp_ge_r0_28,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_129),
    kInstruction_cmp_pl_r3_129,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_202),
    kInstruction_cmp_ne_r6_202,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_84),
    kInstruction_cmp_gt_r0_84,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_3),
    kInstruction_cmp_hi_r7_3,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_14),
    kInstruction_cmp_vs_r1_14,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_107),
    kInstruction_cmp_eq_r3_107,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_57),
    kInstruction_cmp_pl_r1_57,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_138),
    kInstruction_cmp_pl_r0_138,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_158),
    kInstruction_cmp_cs_r6_158,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r2_120),
    kInstruction_cmp_ne_r2_120,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_132),
    kInstruction_cmp_ge_r1_132,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r6_204),
    kInstruction_cmp_hi_r6_204,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_228),
    kInstruction_cmp_ge_r5_228,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_55),
    kInstruction_cmp_gt_r5_55,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r7_55),
    kInstruction_cmp_vc_r7_55,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_90),
    kInstruction_cmp_ge_r3_90,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_252),
    kInstruction_cmp_vs_r7_252,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_168),
    kInstruction_cmp_le_r5_168,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_9),
    kInstruction_cmp_vc_r6_9,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r7_153),
    kInstruction_cmp_eq_r7_153,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_129),
    kInstruction_cmp_cs_r2_129,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r4_232),
    kInstruction_cmp_eq_r4_232,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_86),
    kInstruction_cmp_le_r3_86,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_138),
    kInstruction_cmp_vs_r1_138,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r6_107),
    kInstruction_cmp_vs_r6_107,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_59),
    kInstruction_cmp_gt_r0_59,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_81),
    kInstruction_cmp_mi_r3_81,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_74),
    kInstruction_cmp_le_r5_74,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_207),
    kInstruction_cmp_le_r6_207,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_64),
    kInstruction_cmp_vs_r0_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_146),
    kInstruction_cmp_le_r7_146,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_160),
    kInstruction_cmp_cc_r4_160,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_10),
    kInstruction_cmp_vs_r5_10,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_126),
    kInstruction_cmp_gt_r2_126,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_94),
    kInstruction_cmp_le_r0_94,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_168),
    kInstruction_cmp_ne_r6_168,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_34),
    kInstruction_cmp_cc_r4_34,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_197),
    kInstruction_cmp_hi_r5_197,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_103),
    kInstruction_cmp_eq_r0_103,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_32),
    kInstruction_cmp_cs_r4_32,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_221),
    kInstruction_cmp_hi_r7_221,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r0_0),
    kInstruction_cmp_mi_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_163),
    kInstruction_cmp_pl_r0_163,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_167),
    kInstruction_cmp_cc_r2_167,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_37),
    kInstruction_cmp_gt_r4_37,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_35),
    kInstruction_cmp_mi_r5_35,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_131),
    kInstruction_cmp_cc_r7_131,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_187),
    kInstruction_cmp_pl_r4_187,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_26),
    kInstruction_cmp_ls_r2_26,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r7_10),
    kInstruction_cmp_mi_r7_10,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_113),
    kInstruction_cmp_le_r2_113,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_26),
    kInstruction_cmp_vc_r2_26,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_255),
    kInstruction_cmp_vs_r1_255,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_238),
    kInstruction_cmp_ls_r5_238,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_86),
    kInstruction_cmp_ge_r0_86,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_104),
    kInstruction_cmp_gt_r0_104,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_78),
    kInstruction_cmp_eq_r2_78,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_102),
    kInstruction_cmp_cc_r1_102,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_16),
    kInstruction_cmp_cc_r0_16,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_48),
    kInstruction_cmp_mi_r4_48,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_210),
    kInstruction_cmp_cc_r2_210,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_184),
    kInstruction_cmp_hi_r5_184,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_156),
    kInstruction_cmp_vs_r5_156,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_241),
    kInstruction_cmp_cc_r2_241,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_169),
    kInstruction_cmp_le_r5_169,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_114),
    kInstruction_cmp_pl_r5_114,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_200),
    kInstruction_cmp_eq_r6_200,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_174),
    kInstruction_cmp_vs_r4_174,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_233),
    kInstruction_cmp_vc_r5_233,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_233),
    kInstruction_cmp_hi_r2_233,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_210),
    kInstruction_cmp_ne_r5_210,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_109),
    kInstruction_cmp_le_r1_109,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r7_188),
    kInstruction_cmp_eq_r7_188,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_66),
    kInstruction_cmp_hi_r2_66,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_109),
    kInstruction_cmp_le_r7_109,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_175),
    kInstruction_cmp_ge_r6_175,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_25),
    kInstruction_cmp_mi_r2_25,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_137),
    kInstruction_cmp_pl_r2_137,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_249),
    kInstruction_cmp_pl_r0_249,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_139),
    kInstruction_cmp_lt_r1_139,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_165),
    kInstruction_cmp_cs_r2_165,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_174),
    kInstruction_cmp_ne_r6_174,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_90),
    kInstruction_cmp_le_r7_90,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_67),
    kInstruction_cmp_gt_r5_67,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_175),
    kInstruction_cmp_gt_r0_175,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_81),
    kInstruction_cmp_hi_r3_81,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_144),
    kInstruction_cmp_le_r4_144,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_23),
    kInstruction_cmp_vs_r4_23,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r7_85),
    kInstruction_cmp_eq_r7_85,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r7_202),
    kInstruction_cmp_eq_r7_202,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_201),
    kInstruction_cmp_cs_r1_201,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_67),
    kInstruction_cmp_lt_r4_67,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_206),
    kInstruction_cmp_pl_r2_206,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_87),
    kInstruction_cmp_vc_r0_87,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_35),
    kInstruction_cmp_lt_r1_35,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_192),
    kInstruction_cmp_pl_r7_192,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_213),
    kInstruction_cmp_cc_r5_213,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_86),
    kInstruction_cmp_vs_r5_86,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_182),
    kInstruction_cmp_ls_r1_182,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_227),
    kInstruction_cmp_vc_r0_227,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_206),
    kInstruction_cmp_cs_r1_206,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_194),
    kInstruction_cmp_vs_r7_194,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_242),
    kInstruction_cmp_gt_r1_242,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_222),
    kInstruction_cmp_le_r3_222,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_194),
    kInstruction_cmp_mi_r2_194,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_19),
    kInstruction_cmp_vs_r2_19,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_230),
    kInstruction_cmp_cs_r6_230,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_141),
    kInstruction_cmp_ls_r1_141,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_144),
    kInstruction_cmp_le_r1_144,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_184),
    kInstruction_cmp_ls_r1_184,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_175),
    kInstruction_cmp_pl_r0_175,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_0),
    kInstruction_cmp_cs_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_142),
    kInstruction_cmp_cs_r0_142,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_5),
    kInstruction_cmp_le_r4_5,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_123),
    kInstruction_cmp_pl_r4_123,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_128),
    kInstruction_cmp_cs_r3_128,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_112),
    kInstruction_cmp_pl_r7_112,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_186),
    kInstruction_cmp_vs_r2_186,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_200),
    kInstruction_cmp_pl_r6_200,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_200),
    kInstruction_cmp_ne_r7_200,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_223),
    kInstruction_cmp_le_r6_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_117),
    kInstruction_cmp_vs_r4_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_6),
    kInstruction_cmp_cs_r4_6,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r6_86),
    kInstruction_cmp_ls_r6_86,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_37),
    kInstruction_cmp_cc_r2_37,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_28),
    kInstruction_cmp_ge_r6_28,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_247),
    kInstruction_cmp_ls_r3_247,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r4_193),
    kInstruction_cmp_ge_r4_193,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_108),
    kInstruction_cmp_le_r4_108,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_106),
    kInstruction_cmp_vc_r0_106,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_64),
    kInstruction_cmp_gt_r0_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_247),
    kInstruction_cmp_pl_r0_247,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_88),
    kInstruction_cmp_eq_r0_88,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_88),
    kInstruction_cmp_mi_r4_88,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_118),
    kInstruction_cmp_ne_r6_118,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_79),
    kInstruction_cmp_vc_r2_79,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_104),
    kInstruction_cmp_vc_r0_104,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_128),
    kInstruction_cmp_vs_r3_128,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_129),
    kInstruction_cmp_pl_r1_129,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_149),
    kInstruction_cmp_mi_r6_149,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_226),
    kInstruction_cmp_mi_r4_226,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_232),
    kInstruction_cmp_pl_r5_232,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_88),
    kInstruction_cmp_hi_r1_88,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_13),
    kInstruction_cmp_mi_r3_13,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_44),
    kInstruction_cmp_vs_r1_44,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_88),
    kInstruction_cmp_le_r3_88,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_224),
    kInstruction_cmp_pl_r7_224,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_117),
    kInstruction_cmp_eq_r2_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_94),
    kInstruction_cmp_cc_r5_94,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_43),
    kInstruction_cmp_gt_r3_43,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_159),
    kInstruction_cmp_vs_r4_159,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r7_205),
    kInstruction_cmp_mi_r7_205,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_161),
    kInstruction_cmp_eq_r6_161,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_150),
    kInstruction_cmp_le_r6_150,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_144),
    kInstruction_cmp_ls_r2_144,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_240),
    kInstruction_cmp_le_r2_240,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_11),
    kInstruction_cmp_pl_r1_11,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_116),
    kInstruction_cmp_pl_r2_116,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_122),
    kInstruction_cmp_ne_r3_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_146),
    kInstruction_cmp_cs_r7_146,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_21),
    kInstruction_cmp_eq_r5_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_49),
    kInstruction_cmp_ge_r0_49,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_170),
    kInstruction_cmp_gt_r2_170,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_208),
    kInstruction_cmp_mi_r3_208,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_47),
    kInstruction_cmp_le_r4_47,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_176),
    kInstruction_cmp_ne_r4_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_153),
    kInstruction_cmp_le_r1_153,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_136),
    kInstruction_cmp_cs_r3_136,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_166),
    kInstruction_cmp_le_r7_166,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_148),
    kInstruction_cmp_vc_r2_148,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_226),
    kInstruction_cmp_ge_r6_226,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r7_224),
    kInstruction_cmp_mi_r7_224,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_88),
    kInstruction_cmp_le_r0_88,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_131),
    kInstruction_cmp_lt_r3_131,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_70),
    kInstruction_cmp_gt_r6_70,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_212),
    kInstruction_cmp_cc_r5_212,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_184),
    kInstruction_cmp_pl_r7_184,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_170),
    kInstruction_cmp_gt_r0_170,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_227),
    kInstruction_cmp_ne_r7_227,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_129),
    kInstruction_cmp_cs_r7_129,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_214),
    kInstruction_cmp_lt_r2_214,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_68),
    kInstruction_cmp_le_r3_68,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_174),
    kInstruction_cmp_cs_r1_174,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_224),
    kInstruction_cmp_mi_r6_224,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_107),
    kInstruction_cmp_gt_r3_107,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_62),
    kInstruction_cmp_pl_r6_62,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_173),
    kInstruction_cmp_mi_r2_173,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_208),
    kInstruction_cmp_cs_r3_208,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_214),
    kInstruction_cmp_cc_r3_214,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_20),
    kInstruction_cmp_lt_r5_20,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_9),
    kInstruction_cmp_vs_r2_9,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_55),
    kInstruction_cmp_le_r1_55,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_14),
    kInstruction_cmp_vc_r3_14,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_74),
    kInstruction_cmp_eq_r5_74,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_40),
    kInstruction_cmp_cs_r0_40,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_98),
    kInstruction_cmp_ge_r6_98,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_79),
    kInstruction_cmp_cs_r3_79,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_199),
    kInstruction_cmp_ne_r0_199,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_163),
    kInstruction_cmp_lt_r0_163,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_42),
    kInstruction_cmp_cs_r6_42,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_32),
    kInstruction_cmp_eq_r6_32,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_64),
    kInstruction_cmp_vs_r1_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_91),
    kInstruction_cmp_hi_r4_91,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_79),
    kInstruction_cmp_ls_r3_79,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_68),
    kInstruction_cmp_gt_r3_68,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_133),
    kInstruction_cmp_eq_r0_133,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_8),
    kInstruction_cmp_vs_r4_8,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_248),
    kInstruction_cmp_cs_r2_248,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_153),
    kInstruction_cmp_cs_r2_153,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_21),
    kInstruction_cmp_cc_r1_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_171),
    kInstruction_cmp_mi_r3_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_126),
    kInstruction_cmp_gt_r6_126,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_155),
    kInstruction_cmp_hi_r0_155,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_224),
    kInstruction_cmp_cs_r0_224,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_38),
    kInstruction_cmp_cc_r2_38,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_127),
    kInstruction_cmp_lt_r3_127,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_21),
    kInstruction_cmp_gt_r6_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_39),
    kInstruction_cmp_gt_r4_39,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r4_40),
    kInstruction_cmp_ge_r4_40,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_228),
    kInstruction_cmp_hi_r4_228,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_51),
    kInstruction_cmp_le_r6_51,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_3),
    kInstruction_cmp_ge_r3_3,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_24),
    kInstruction_cmp_ge_r5_24,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_52),
    kInstruction_cmp_ge_r0_52,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r6_84),
    kInstruction_cmp_vs_r6_84,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_238),
    kInstruction_cmp_gt_r7_238,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_118),
    kInstruction_cmp_pl_r2_118,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_96),
    kInstruction_cmp_cc_r0_96,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_241),
    kInstruction_cmp_gt_r1_241,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_231),
    kInstruction_cmp_lt_r5_231,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_223),
    kInstruction_cmp_vs_r0_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_85),
    kInstruction_cmp_vc_r6_85,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_171),
    kInstruction_cmp_vs_r4_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_34),
    kInstruction_cmp_hi_r7_34,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_243),
    kInstruction_cmp_hi_r4_243,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r6_16),
    kInstruction_cmp_cc_r6_16,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_179),
    kInstruction_cmp_cs_r2_179,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_128),
    kInstruction_cmp_cs_r5_128,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_43),
    kInstruction_cmp_lt_r6_43,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_116),
    kInstruction_cmp_lt_r1_116,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_176),
    kInstruction_cmp_mi_r4_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_158),
    kInstruction_cmp_hi_r3_158,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_21),
    kInstruction_cmp_cs_r6_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_114),
    kInstruction_cmp_ge_r5_114,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_109),
    kInstruction_cmp_vs_r3_109,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_249),
    kInstruction_cmp_ne_r4_249,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_96),
    kInstruction_cmp_ls_r5_96,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_135),
    kInstruction_cmp_hi_r0_135,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_63),
    kInstruction_cmp_vc_r2_63,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_169),
    kInstruction_cmp_le_r0_169,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r4_230),
    kInstruction_cmp_vc_r4_230,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_181),
    kInstruction_cmp_gt_r3_181,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_202),
    kInstruction_cmp_eq_r6_202,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_57),
    kInstruction_cmp_mi_r4_57,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_220),
    kInstruction_cmp_lt_r7_220,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_43),
    kInstruction_cmp_lt_r3_43,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_210),
    kInstruction_cmp_pl_r3_210,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_182),
    kInstruction_cmp_cc_r4_182,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_105),
    kInstruction_cmp_vc_r5_105,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_150),
    kInstruction_cmp_ls_r4_150,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_2),
    kInstruction_cmp_ls_r0_2,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_0),
    kInstruction_cmp_eq_r0_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r6_204),
    kInstruction_cmp_cc_r6_204,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_226),
    kInstruction_cmp_lt_r4_226,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_37),
    kInstruction_cmp_pl_r2_37,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_208),
    kInstruction_cmp_ge_r3_208,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_75),
    kInstruction_cmp_mi_r1_75,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_249),
    kInstruction_cmp_hi_r7_249,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_61),
    kInstruction_cmp_vc_r6_61,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r1_185),
    kInstruction_cmp_eq_r1_185,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_55),
    kInstruction_cmp_vs_r5_55,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_243),
    kInstruction_cmp_pl_r2_243,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_111),
    kInstruction_cmp_eq_r0_111,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_75),
    kInstruction_cmp_cc_r5_75,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_103),
    kInstruction_cmp_mi_r1_103,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_201),
    kInstruction_cmp_mi_r5_201,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_13),
    kInstruction_cmp_eq_r6_13,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_117),
    kInstruction_cmp_le_r1_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_245),
    kInstruction_cmp_le_r4_245,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_253),
    kInstruction_cmp_vc_r5_253,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_245),
    kInstruction_cmp_vc_r1_245,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_160),
    kInstruction_cmp_hi_r0_160,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_139),
    kInstruction_cmp_ne_r6_139,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_71),
    kInstruction_cmp_cc_r3_71,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_155),
    kInstruction_cmp_lt_r0_155,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_100),
    kInstruction_cmp_ls_r4_100,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_117),
    kInstruction_cmp_vs_r5_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_9),
    kInstruction_cmp_gt_r7_9,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_30),
    kInstruction_cmp_lt_r5_30,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_32),
    kInstruction_cmp_pl_r6_32,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_105),
    kInstruction_cmp_mi_r1_105,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_34),
    kInstruction_cmp_hi_r1_34,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_213),
    kInstruction_cmp_cs_r7_213,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_218),
    kInstruction_cmp_le_r7_218,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_131),
    kInstruction_cmp_pl_r3_131,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_117),
    kInstruction_cmp_cs_r6_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_177),
    kInstruction_cmp_cc_r1_177,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_74),
    kInstruction_cmp_cs_r1_74,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_176),
    kInstruction_cmp_ls_r7_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_208),
    kInstruction_cmp_lt_r7_208,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r2_252),
    kInstruction_cmp_ge_r2_252,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_135),
    kInstruction_cmp_gt_r7_135,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_128),
    kInstruction_cmp_cs_r4_128,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_44),
    kInstruction_cmp_le_r6_44,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_184),
    kInstruction_cmp_cs_r5_184,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_17),
    kInstruction_cmp_cc_r5_17,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_48),
    kInstruction_cmp_le_r1_48,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_152),
    kInstruction_cmp_vs_r7_152,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_236),
    kInstruction_cmp_cs_r3_236,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_68),
    kInstruction_cmp_cc_r1_68,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_179),
    kInstruction_cmp_cs_r6_179,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_35),
    kInstruction_cmp_eq_r5_35,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_220),
    kInstruction_cmp_le_r5_220,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_63),
    kInstruction_cmp_pl_r1_63,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_255),
    kInstruction_cmp_vs_r5_255,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_193),
    kInstruction_cmp_pl_r5_193,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_165),
    kInstruction_cmp_gt_r3_165,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_120),
    kInstruction_cmp_le_r0_120,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_21),
    kInstruction_cmp_cc_r0_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_203),
    kInstruction_cmp_ge_r3_203,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_25),
    kInstruction_cmp_ne_r0_25,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_6),
    kInstruction_cmp_mi_r6_6,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_194),
    kInstruction_cmp_ne_r7_194,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_20),
    kInstruction_cmp_lt_r6_20,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_94),
    kInstruction_cmp_ls_r3_94,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_222),
    kInstruction_cmp_gt_r6_222,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_247),
    kInstruction_cmp_cc_r1_247,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_127),
    kInstruction_cmp_cc_r0_127,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_252),
    kInstruction_cmp_mi_r2_252,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_150),
    kInstruction_cmp_ge_r0_150,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_18),
    kInstruction_cmp_mi_r4_18,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_182),
    kInstruction_cmp_vs_r5_182,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_125),
    kInstruction_cmp_pl_r1_125,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_159),
    kInstruction_cmp_pl_r6_159,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_218),
    kInstruction_cmp_le_r3_218,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_163),
    kInstruction_cmp_hi_r2_163,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r7_246),
    kInstruction_cmp_mi_r7_246,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_1),
    kInstruction_cmp_lt_r7_1,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_82),
    kInstruction_cmp_pl_r4_82,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_115),
    kInstruction_cmp_le_r2_115,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_74),
    kInstruction_cmp_vc_r0_74,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_11),
    kInstruction_cmp_gt_r3_11,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_225),
    kInstruction_cmp_cs_r7_225,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_245),
    kInstruction_cmp_gt_r2_245,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_13),
    kInstruction_cmp_lt_r4_13,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_83),
    kInstruction_cmp_le_r3_83,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r7_83),
    kInstruction_cmp_eq_r7_83,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_86),
    kInstruction_cmp_vc_r6_86,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_99),
    kInstruction_cmp_le_r2_99,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_139),
    kInstruction_cmp_hi_r0_139,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_122),
    kInstruction_cmp_gt_r6_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_190),
    kInstruction_cmp_cs_r2_190,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_97),
    kInstruction_cmp_pl_r0_97,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_41),
    kInstruction_cmp_ls_r7_41,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_111),
    kInstruction_cmp_pl_r2_111,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_239),
    kInstruction_cmp_ls_r5_239,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_104),
    kInstruction_cmp_le_r3_104,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_29),
    kInstruction_cmp_gt_r3_29,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_247),
    kInstruction_cmp_ge_r7_247,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_1),
    kInstruction_cmp_le_r6_1,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_161),
    kInstruction_cmp_hi_r0_161,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_143),
    kInstruction_cmp_vs_r1_143,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_14),
    kInstruction_cmp_cs_r7_14,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_80),
    kInstruction_cmp_gt_r3_80,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r6_207),
    kInstruction_cmp_ls_r6_207,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_187),
    kInstruction_cmp_vs_r1_187,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_193),
    kInstruction_cmp_ne_r6_193,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_202),
    kInstruction_cmp_le_r5_202,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_23),
    kInstruction_cmp_vs_r3_23,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_141),
    kInstruction_cmp_mi_r2_141,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_145),
    kInstruction_cmp_mi_r1_145,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_176),
    kInstruction_cmp_lt_r0_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_18),
    kInstruction_cmp_hi_r2_18,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_247),
    kInstruction_cmp_gt_r4_247,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_144),
    kInstruction_cmp_lt_r1_144,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_174),
    kInstruction_cmp_cc_r5_174,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_66),
    kInstruction_cmp_ge_r6_66,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_223),
    kInstruction_cmp_vc_r0_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_211),
    kInstruction_cmp_cc_r7_211,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_186),
    kInstruction_cmp_le_r1_186,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_73),
    kInstruction_cmp_ne_r4_73,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_64),
    kInstruction_cmp_ls_r4_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_100),
    kInstruction_cmp_cc_r3_100,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_83),
    kInstruction_cmp_ls_r7_83,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_253),
    kInstruction_cmp_ge_r7_253,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_190),
    kInstruction_cmp_lt_r1_190,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_132),
    kInstruction_cmp_hi_r0_132,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_172),
    kInstruction_cmp_cc_r1_172,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_24),
    kInstruction_cmp_cs_r4_24,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_183),
    kInstruction_cmp_vs_r0_183,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_231),
    kInstruction_cmp_eq_r3_231,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_6),
    kInstruction_cmp_cc_r4_6,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_151),
    kInstruction_cmp_le_r6_151,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r4_123),
    kInstruction_cmp_eq_r4_123,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_110),
    kInstruction_cmp_lt_r2_110,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_39),
    kInstruction_cmp_vc_r2_39,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_45),
    kInstruction_cmp_gt_r5_45,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_120),
    kInstruction_cmp_eq_r2_120,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_6),
    kInstruction_cmp_ge_r0_6,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_54),
    kInstruction_cmp_vs_r3_54,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_164),
    kInstruction_cmp_cc_r0_164,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_198),
    kInstruction_cmp_eq_r6_198,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_254),
    kInstruction_cmp_cc_r0_254,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_167),
    kInstruction_cmp_ne_r1_167,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_89),
    kInstruction_cmp_hi_r7_89,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_220),
    kInstruction_cmp_mi_r6_220,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_199),
    kInstruction_cmp_vs_r5_199,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_166),
    kInstruction_cmp_ls_r4_166,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_139),
    kInstruction_cmp_le_r2_139,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_112),
    kInstruction_cmp_vs_r5_112,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_13),
    kInstruction_cmp_cs_r3_13,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_95),
    kInstruction_cmp_gt_r3_95,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_94),
    kInstruction_cmp_pl_r2_94,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r2_227),
    kInstruction_cmp_ne_r2_227,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_251),
    kInstruction_cmp_ne_r7_251,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_97),
    kInstruction_cmp_ge_r5_97,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_253),
    kInstruction_cmp_gt_r5_253,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_95),
    kInstruction_cmp_hi_r7_95,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_253),
    kInstruction_cmp_gt_r3_253,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_162),
    kInstruction_cmp_le_r7_162,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_36),
    kInstruction_cmp_gt_r4_36,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_58),
    kInstruction_cmp_ne_r3_58,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_25),
    kInstruction_cmp_vs_r0_25,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_116),
    kInstruction_cmp_ne_r7_116,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_198),
    kInstruction_cmp_cs_r1_198,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_122),
    kInstruction_cmp_cc_r0_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_57),
    kInstruction_cmp_le_r4_57,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_150),
    kInstruction_cmp_vc_r3_150,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r1_54),
    kInstruction_cmp_eq_r1_54,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_146),
    kInstruction_cmp_ge_r1_146,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_124),
    kInstruction_cmp_vc_r1_124,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_165),
    kInstruction_cmp_ne_r6_165,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_54),
    kInstruction_cmp_vc_r6_54,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_226),
    kInstruction_cmp_hi_r3_226,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r1_167),
    kInstruction_cmp_eq_r1_167,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_162),
    kInstruction_cmp_mi_r3_162,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_8),
    kInstruction_cmp_mi_r5_8,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_67),
    kInstruction_cmp_mi_r3_67,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_113),
    kInstruction_cmp_ge_r6_113,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_51),
    kInstruction_cmp_lt_r2_51,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_131),
    kInstruction_cmp_vc_r2_131,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_196),
    kInstruction_cmp_ne_r4_196,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_189),
    kInstruction_cmp_mi_r5_189,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_62),
    kInstruction_cmp_cs_r1_62,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_142),
    kInstruction_cmp_hi_r4_142,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_91),
    kInstruction_cmp_ne_r5_91,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_38),
    kInstruction_cmp_eq_r3_38,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_155),
    kInstruction_cmp_ls_r3_155,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_0),
    kInstruction_cmp_le_r5_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_106),
    kInstruction_cmp_vc_r1_106,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_212),
    kInstruction_cmp_lt_r0_212,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_87),
    kInstruction_cmp_lt_r1_87,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_62),
    kInstruction_cmp_mi_r2_62,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_2),
    kInstruction_cmp_vc_r0_2,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_24),
    kInstruction_cmp_ls_r7_24,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_12),
    kInstruction_cmp_ls_r3_12,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_181),
    kInstruction_cmp_pl_r0_181,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_43),
    kInstruction_cmp_gt_r2_43,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_130),
    kInstruction_cmp_cc_r5_130,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_170),
    kInstruction_cmp_eq_r6_170,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_208),
    kInstruction_cmp_hi_r4_208,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_196),
    kInstruction_cmp_cc_r2_196,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_131),
    kInstruction_cmp_lt_r4_131,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_122),
    kInstruction_cmp_vs_r7_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_212),
    kInstruction_cmp_cs_r0_212,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_50),
    kInstruction_cmp_eq_r2_50,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_202),
    kInstruction_cmp_gt_r3_202,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r4_197),
    kInstruction_cmp_eq_r4_197,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_7),
    kInstruction_cmp_cc_r3_7,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_206),
    kInstruction_cmp_vs_r5_206,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_137),
    kInstruction_cmp_lt_r6_137,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_154),
    kInstruction_cmp_cs_r4_154,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_16),
    kInstruction_cmp_hi_r0_16,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_110),
    kInstruction_cmp_le_r1_110,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_67),
    kInstruction_cmp_ge_r5_67,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_58),
    kInstruction_cmp_lt_r2_58,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_45),
    kInstruction_cmp_gt_r4_45,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_227),
    kInstruction_cmp_gt_r7_227,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_143),
    kInstruction_cmp_lt_r6_143,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_168),
    kInstruction_cmp_cs_r5_168,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_74),
    kInstruction_cmp_hi_r5_74,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_165),
    kInstruction_cmp_gt_r6_165,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_191),
    kInstruction_cmp_le_r2_191,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_212),
    kInstruction_cmp_pl_r3_212,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_108),
    kInstruction_cmp_lt_r2_108,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_225),
    kInstruction_cmp_gt_r4_225,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_181),
    kInstruction_cmp_cc_r3_181,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_39),
    kInstruction_cmp_ge_r7_39,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_212),
    kInstruction_cmp_gt_r2_212,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_32),
    kInstruction_cmp_cc_r2_32,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_92),
    kInstruction_cmp_vs_r1_92,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_64),
    kInstruction_cmp_cs_r0_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_195),
    kInstruction_cmp_mi_r3_195,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_168),
    kInstruction_cmp_ne_r7_168,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_84),
    kInstruction_cmp_vc_r2_84,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_105),
    kInstruction_cmp_hi_r1_105,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r4_91),
    kInstruction_cmp_vc_r4_91,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_103),
    kInstruction_cmp_pl_r0_103,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_122),
    kInstruction_cmp_cc_r7_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_228),
    kInstruction_cmp_vs_r7_228,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_154),
    kInstruction_cmp_ls_r4_154,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_159),
    kInstruction_cmp_mi_r5_159,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_207),
    kInstruction_cmp_gt_r6_207,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_75),
    kInstruction_cmp_lt_r0_75,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_106),
    kInstruction_cmp_gt_r4_106,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_236),
    kInstruction_cmp_gt_r0_236,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_127),
    kInstruction_cmp_le_r7_127,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_138),
    kInstruction_cmp_vs_r0_138,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_145),
    kInstruction_cmp_vs_r3_145,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_70),
    kInstruction_cmp_cs_r1_70,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_69),
    kInstruction_cmp_cs_r3_69,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_28),
    kInstruction_cmp_hi_r3_28,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_122),
    kInstruction_cmp_le_r5_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_212),
    kInstruction_cmp_cc_r7_212,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_186),
    kInstruction_cmp_mi_r4_186,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_171),
    kInstruction_cmp_ne_r1_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_205),
    kInstruction_cmp_vs_r4_205,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_26),
    kInstruction_cmp_ls_r1_26,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_58),
    kInstruction_cmp_le_r5_58,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_140),
    kInstruction_cmp_gt_r2_140,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_121),
    kInstruction_cmp_pl_r5_121,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_183),
    kInstruction_cmp_vc_r3_183,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_110),
    kInstruction_cmp_vs_r5_110,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_89),
    kInstruction_cmp_ls_r2_89,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_173),
    kInstruction_cmp_vc_r3_173,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_57),
    kInstruction_cmp_le_r7_57,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_111),
    kInstruction_cmp_eq_r5_111,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_180),
    kInstruction_cmp_mi_r4_180,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_252),
    kInstruction_cmp_vs_r1_252,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_168),
    kInstruction_cmp_le_r2_168,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_240),
    kInstruction_cmp_ne_r7_240,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_177),
    kInstruction_cmp_hi_r5_177,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_156),
    kInstruction_cmp_cc_r7_156,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_140),
    kInstruction_cmp_ls_r0_140,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_206),
    kInstruction_cmp_vc_r2_206,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_198),
    kInstruction_cmp_ge_r3_198,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_154),
    kInstruction_cmp_pl_r1_154,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_118),
    kInstruction_cmp_eq_r5_118,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_173),
    kInstruction_cmp_le_r7_173,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_174),
    kInstruction_cmp_mi_r6_174,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_159),
    kInstruction_cmp_pl_r2_159,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_97),
    kInstruction_cmp_lt_r0_97,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r2_145),
    kInstruction_cmp_ge_r2_145,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_196),
    kInstruction_cmp_cc_r5_196,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_152),
    kInstruction_cmp_vs_r3_152,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_85),
    kInstruction_cmp_le_r3_85,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_155),
    kInstruction_cmp_le_r7_155,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_160),
    kInstruction_cmp_cc_r1_160,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_195),
    kInstruction_cmp_gt_r2_195,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_67),
    kInstruction_cmp_vc_r3_67,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_119),
    kInstruction_cmp_lt_r0_119,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_123),
    kInstruction_cmp_ne_r3_123,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_23),
    kInstruction_cmp_le_r5_23,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_208),
    kInstruction_cmp_lt_r6_208,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_245),
    kInstruction_cmp_cc_r5_245,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_111),
    kInstruction_cmp_vs_r4_111,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_75),
    kInstruction_cmp_pl_r4_75,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_59),
    kInstruction_cmp_le_r6_59,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_70),
    kInstruction_cmp_pl_r6_70,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_191),
    kInstruction_cmp_vc_r1_191,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_125),
    kInstruction_cmp_le_r2_125,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_249),
    kInstruction_cmp_ls_r4_249,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_41),
    kInstruction_cmp_vs_r2_41,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_199),
    kInstruction_cmp_pl_r4_199,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_180),
    kInstruction_cmp_cc_r3_180,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_225),
    kInstruction_cmp_ls_r0_225,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r2_93),
    kInstruction_cmp_ne_r2_93,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r3_16),
    kInstruction_cmp_cc_r3_16,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_223),
    kInstruction_cmp_pl_r1_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_129),
    kInstruction_cmp_ge_r0_129,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_34),
    kInstruction_cmp_lt_r5_34,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_156),
    kInstruction_cmp_vc_r5_156,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_29),
    kInstruction_cmp_hi_r0_29,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_228),
    kInstruction_cmp_eq_r5_228,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_86),
    kInstruction_cmp_ls_r5_86,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_99),
    kInstruction_cmp_cs_r5_99,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r4_217),
    kInstruction_cmp_eq_r4_217,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_15),
    kInstruction_cmp_ne_r0_15,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_17),
    kInstruction_cmp_ls_r2_17,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_70),
    kInstruction_cmp_cs_r3_70,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_60),
    kInstruction_cmp_ge_r0_60,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_107),
    kInstruction_cmp_cc_r0_107,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_192),
    kInstruction_cmp_gt_r3_192,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_175),
    kInstruction_cmp_ne_r1_175,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_88),
    kInstruction_cmp_le_r1_88,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_216),
    kInstruction_cmp_mi_r5_216,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_149),
    kInstruction_cmp_pl_r4_149,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_28),
    kInstruction_cmp_cs_r6_28,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_65),
    kInstruction_cmp_vs_r1_65,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_169),
    kInstruction_cmp_vs_r2_169,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_108),
    kInstruction_cmp_eq_r3_108,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_127),
    kInstruction_cmp_eq_r5_127,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_23),
    kInstruction_cmp_vc_r1_23,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_132),
    kInstruction_cmp_pl_r7_132,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_90),
    kInstruction_cmp_vc_r3_90,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_195),
    kInstruction_cmp_pl_r3_195,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_28),
    kInstruction_cmp_ne_r7_28,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_233),
    kInstruction_cmp_vs_r2_233,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_3),
    kInstruction_cmp_ge_r5_3,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_231),
    kInstruction_cmp_ge_r3_231,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_10),
    kInstruction_cmp_pl_r2_10,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_56),
    kInstruction_cmp_le_r1_56,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_232),
    kInstruction_cmp_eq_r5_232,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_124),
    kInstruction_cmp_mi_r5_124,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_198),
    kInstruction_cmp_vc_r2_198,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_86),
    kInstruction_cmp_lt_r5_86,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r1_199),
    kInstruction_cmp_eq_r1_199,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_21),
    kInstruction_cmp_eq_r2_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_194),
    kInstruction_cmp_mi_r4_194,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_235),
    kInstruction_cmp_ge_r1_235,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_164),
    kInstruction_cmp_gt_r6_164,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_132),
    kInstruction_cmp_ne_r0_132,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_188),
    kInstruction_cmp_mi_r2_188,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_136),
    kInstruction_cmp_ls_r7_136,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r3_248),
    kInstruction_cmp_mi_r3_248,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_248),
    kInstruction_cmp_pl_r1_248,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_4),
    kInstruction_cmp_gt_r1_4,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_171),
    kInstruction_cmp_eq_r3_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_75),
    kInstruction_cmp_ge_r5_75,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_115),
    kInstruction_cmp_ne_r6_115,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_218),
    kInstruction_cmp_mi_r1_218,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_160),
    kInstruction_cmp_pl_r6_160,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_69),
    kInstruction_cmp_ls_r3_69,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_73),
    kInstruction_cmp_hi_r3_73,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_248),
    kInstruction_cmp_cc_r2_248,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_1),
    kInstruction_cmp_le_r0_1,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_43),
    kInstruction_cmp_gt_r0_43,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_202),
    kInstruction_cmp_pl_r7_202,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_8),
    kInstruction_cmp_le_r3_8,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_235),
    kInstruction_cmp_ls_r1_235,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_223),
    kInstruction_cmp_cs_r5_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_89),
    kInstruction_cmp_le_r7_89,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_45),
    kInstruction_cmp_ls_r5_45,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_206),
    kInstruction_cmp_pl_r6_206,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_12),
    kInstruction_cmp_ne_r3_12,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_37),
    kInstruction_cmp_vc_r3_37,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_112),
    kInstruction_cmp_cs_r3_112,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_10),
    kInstruction_cmp_cs_r3_10,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_206),
    kInstruction_cmp_cs_r0_206,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_215),
    kInstruction_cmp_vs_r2_215,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_171),
    kInstruction_cmp_hi_r2_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_117),
    kInstruction_cmp_ge_r3_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r7_211),
    kInstruction_cmp_vc_r7_211,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r6_147),
    kInstruction_cmp_hi_r6_147,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_64),
    kInstruction_cmp_gt_r4_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r2_17),
    kInstruction_cmp_ge_r2_17,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_242),
    kInstruction_cmp_lt_r0_242,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_144),
    kInstruction_cmp_ls_r5_144,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_44),
    kInstruction_cmp_cc_r7_44,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_214),
    kInstruction_cmp_vs_r7_214,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_132),
    kInstruction_cmp_ge_r3_132,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_36),
    kInstruction_cmp_hi_r4_36,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_5),
    kInstruction_cmp_cs_r1_5,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_194),
    kInstruction_cmp_mi_r6_194,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_134),
    kInstruction_cmp_ge_r1_134,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_90),
    kInstruction_cmp_ls_r2_90,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_207),
    kInstruction_cmp_vc_r1_207,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_13),
    kInstruction_cmp_cc_r7_13,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r6_117),
    kInstruction_cmp_cc_r6_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_113),
    kInstruction_cmp_mi_r2_113,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_107),
    kInstruction_cmp_vc_r0_107,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_156),
    kInstruction_cmp_mi_r6_156,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_193),
    kInstruction_cmp_hi_r0_193,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_5),
    kInstruction_cmp_gt_r5_5,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_137),
    kInstruction_cmp_cc_r5_137,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_60),
    kInstruction_cmp_vs_r1_60,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_156),
    kInstruction_cmp_ge_r5_156,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_246),
    kInstruction_cmp_hi_r5_246,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_228),
    kInstruction_cmp_pl_r1_228,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_214),
    kInstruction_cmp_mi_r6_214,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_39),
    kInstruction_cmp_ls_r1_39,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r2_201),
    kInstruction_cmp_ge_r2_201,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_250),
    kInstruction_cmp_ls_r5_250,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_40),
    kInstruction_cmp_mi_r2_40,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_225),
    kInstruction_cmp_cc_r4_225,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_96),
    kInstruction_cmp_ne_r1_96,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_162),
    kInstruction_cmp_ge_r5_162,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_176),
    kInstruction_cmp_eq_r5_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_246),
    kInstruction_cmp_lt_r1_246,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_44),
    kInstruction_cmp_ls_r4_44,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_96),
    kInstruction_cmp_lt_r2_96,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_54),
    kInstruction_cmp_ge_r5_54,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_13),
    kInstruction_cmp_lt_r6_13,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_106),
    kInstruction_cmp_mi_r5_106,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_62),
    kInstruction_cmp_vs_r5_62,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_235),
    kInstruction_cmp_vs_r5_235,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_49),
    kInstruction_cmp_hi_r1_49,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_32),
    kInstruction_cmp_cs_r5_32,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_43),
    kInstruction_cmp_cc_r7_43,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_122),
    kInstruction_cmp_pl_r6_122,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r7_87),
    kInstruction_cmp_eq_r7_87,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_250),
    kInstruction_cmp_cc_r1_250,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_236),
    kInstruction_cmp_vc_r1_236,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_83),
    kInstruction_cmp_pl_r1_83,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_228),
    kInstruction_cmp_gt_r2_228,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_41),
    kInstruction_cmp_mi_r1_41,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_42),
    kInstruction_cmp_hi_r1_42,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_242),
    kInstruction_cmp_hi_r0_242,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_9),
    kInstruction_cmp_ne_r7_9,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_0),
    kInstruction_cmp_lt_r3_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_183),
    kInstruction_cmp_pl_r0_183,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_117),
    kInstruction_cmp_hi_r2_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_77),
    kInstruction_cmp_hi_r0_77,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_159),
    kInstruction_cmp_ls_r3_159,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_5),
    kInstruction_cmp_cc_r4_5,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r4_244),
    kInstruction_cmp_vc_r4_244,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_121),
    kInstruction_cmp_hi_r2_121,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_90),
    kInstruction_cmp_le_r3_90,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_10),
    kInstruction_cmp_vc_r6_10,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_150),
    kInstruction_cmp_cs_r5_150,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r7_117),
    kInstruction_cmp_vc_r7_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_211),
    kInstruction_cmp_cs_r7_211,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_18),
    kInstruction_cmp_cs_r0_18,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r2_60),
    kInstruction_cmp_ne_r2_60,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_223),
    kInstruction_cmp_ge_r0_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_176),
    kInstruction_cmp_lt_r1_176,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_15),
    kInstruction_cmp_eq_r6_15,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_74),
    kInstruction_cmp_vs_r7_74,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_68),
    kInstruction_cmp_ne_r5_68,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_49),
    kInstruction_cmp_ne_r7_49,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_139),
    kInstruction_cmp_le_r0_139,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_218),
    kInstruction_cmp_ge_r3_218,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r2_25),
    kInstruction_cmp_ge_r2_25,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_117),
    kInstruction_cmp_mi_r5_117,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_57),
    kInstruction_cmp_pl_r7_57,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_7),
    kInstruction_cmp_gt_r7_7,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_55),
    kInstruction_cmp_ne_r4_55,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_56),
    kInstruction_cmp_ne_r7_56,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r5_55),
    kInstruction_cmp_cc_r5_55,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_84),
    kInstruction_cmp_cc_r7_84,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_229),
    kInstruction_cmp_cs_r5_229,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_205),
    kInstruction_cmp_ne_r1_205,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_133),
    kInstruction_cmp_ge_r1_133,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_25),
    kInstruction_cmp_vc_r0_25,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_114),
    kInstruction_cmp_ge_r0_114,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_135),
    kInstruction_cmp_le_r5_135,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_145),
    kInstruction_cmp_pl_r3_145,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_197),
    kInstruction_cmp_le_r5_197,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_14),
    kInstruction_cmp_vc_r0_14,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_113),
    kInstruction_cmp_vc_r3_113,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_224),
    kInstruction_cmp_le_r3_224,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_99),
    kInstruction_cmp_le_r1_99,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_222),
    kInstruction_cmp_le_r6_222,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_15),
    kInstruction_cmp_vc_r6_15,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_59),
    kInstruction_cmp_ge_r5_59,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_187),
    kInstruction_cmp_mi_r2_187,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_107),
    kInstruction_cmp_ls_r0_107,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r6_111),
    kInstruction_cmp_le_r6_111,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_58),
    kInstruction_cmp_hi_r7_58,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_143),
    kInstruction_cmp_le_r1_143,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_181),
    kInstruction_cmp_cs_r7_181,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_235),
    kInstruction_cmp_hi_r4_235,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_69),
    kInstruction_cmp_vs_r3_69,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_100),
    kInstruction_cmp_ls_r1_100,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_93),
    kInstruction_cmp_ne_r7_93,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_10),
    kInstruction_cmp_pl_r5_10,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_158),
    kInstruction_cmp_eq_r0_158,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_8),
    kInstruction_cmp_pl_r5_8,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_172),
    kInstruction_cmp_vc_r5_172,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_0),
    kInstruction_cmp_ne_r6_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r0_106),
    kInstruction_cmp_mi_r0_106,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_229),
    kInstruction_cmp_vs_r7_229,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r6_75),
    kInstruction_cmp_ne_r6_75,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_247),
    kInstruction_cmp_cc_r7_247,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_171),
    kInstruction_cmp_ne_r0_171,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_76),
    kInstruction_cmp_lt_r6_76,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r6_20),
    kInstruction_cmp_ls_r6_20,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_79),
    kInstruction_cmp_ne_r3_79,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_214),
    kInstruction_cmp_lt_r4_214,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_108),
    kInstruction_cmp_gt_r1_108,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_149),
    kInstruction_cmp_ls_r0_149,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_218),
    kInstruction_cmp_vc_r5_218,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_65),
    kInstruction_cmp_hi_r3_65,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r4_9),
    kInstruction_cmp_ge_r4_9,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_252),
    kInstruction_cmp_ls_r2_252,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_107),
    kInstruction_cmp_vs_r1_107,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_32),
    kInstruction_cmp_le_r7_32,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_22),
    kInstruction_cmp_cs_r7_22,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_145),
    kInstruction_cmp_le_r1_145,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r2_144),
    kInstruction_cmp_ne_r2_144,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_79),
    kInstruction_cmp_mi_r4_79,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_240),
    kInstruction_cmp_ne_r5_240,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_251),
    kInstruction_cmp_lt_r7_251,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_118),
    kInstruction_cmp_le_r0_118,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r0_199),
    kInstruction_cmp_eq_r0_199,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_105),
    kInstruction_cmp_hi_r3_105,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_215),
    kInstruction_cmp_cs_r3_215,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_19),
    kInstruction_cmp_ge_r7_19,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_94),
    kInstruction_cmp_le_r4_94,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_100),
    kInstruction_cmp_hi_r4_100,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_116),
    kInstruction_cmp_cc_r7_116,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_168),
    kInstruction_cmp_ls_r4_168,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_5),
    kInstruction_cmp_lt_r5_5,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r4_121),
    kInstruction_cmp_vc_r4_121,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_235),
    kInstruction_cmp_ls_r2_235,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_65),
    kInstruction_cmp_gt_r2_65,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_153),
    kInstruction_cmp_le_r0_153,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r2_92),
    kInstruction_cmp_ge_r2_92,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_183),
    kInstruction_cmp_cs_r7_183,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_90),
    kInstruction_cmp_vs_r7_90,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_83),
    kInstruction_cmp_ge_r7_83,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_170),
    kInstruction_cmp_vc_r6_170,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_13),
    kInstruction_cmp_vs_r7_13,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_26),
    kInstruction_cmp_cc_r2_26,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_118),
    kInstruction_cmp_ls_r3_118,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r4_78),
    kInstruction_cmp_vc_r4_78,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_222),
    kInstruction_cmp_vc_r1_222,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_16),
    kInstruction_cmp_ls_r7_16,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_41),
    kInstruction_cmp_vs_r4_41,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_21),
    kInstruction_cmp_lt_r3_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_73),
    kInstruction_cmp_gt_r5_73,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_21),
    kInstruction_cmp_vs_r2_21,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_212),
    kInstruction_cmp_gt_r6_212,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_217),
    kInstruction_cmp_ge_r0_217,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_163),
    kInstruction_cmp_ge_r3_163,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_180),
    kInstruction_cmp_hi_r4_180,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_163),
    kInstruction_cmp_cs_r3_163,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_3),
    kInstruction_cmp_hi_r3_3,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_121),
    kInstruction_cmp_gt_r3_121,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_82),
    kInstruction_cmp_cs_r0_82,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r1_204),
    kInstruction_cmp_cc_r1_204,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_16),
    kInstruction_cmp_cc_r2_16,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_152),
    kInstruction_cmp_le_r4_152,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r6_168),
    kInstruction_cmp_ls_r6_168,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r4_85),
    kInstruction_cmp_cs_r4_85,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_175),
    kInstruction_cmp_lt_r7_175,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_165),
    kInstruction_cmp_cs_r7_165,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_6),
    kInstruction_cmp_ge_r1_6,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_59),
    kInstruction_cmp_cs_r3_59,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r1_223),
    kInstruction_cmp_ne_r1_223,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_222),
    kInstruction_cmp_vs_r1_222,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_102),
    kInstruction_cmp_cs_r0_102,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_62),
    kInstruction_cmp_ls_r0_62,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r6_97),
    kInstruction_cmp_vs_r6_97,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_60),
    kInstruction_cmp_gt_r6_60,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r7_144),
    kInstruction_cmp_mi_r7_144,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_0),
    kInstruction_cmp_vs_r4_0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_62),
    kInstruction_cmp_hi_r5_62,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_49),
    kInstruction_cmp_le_r1_49,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_178),
    kInstruction_cmp_le_r4_178,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_149),
    kInstruction_cmp_lt_r3_149,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_64),
    kInstruction_cmp_vs_r7_64,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_202),
    kInstruction_cmp_ne_r3_202,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r2_164),
    kInstruction_cmp_ne_r2_164,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_193),
    kInstruction_cmp_gt_r3_193,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_164),
    kInstruction_cmp_le_r7_164,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_151),
    kInstruction_cmp_eq_r6_151,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_38),
    kInstruction_cmp_hi_r3_38,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_191),
    kInstruction_cmp_gt_r7_191,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_42),
    kInstruction_cmp_ge_r6_42,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_247),
    kInstruction_cmp_vc_r6_247,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_236),
    kInstruction_cmp_hi_r5_236,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_234),
    kInstruction_cmp_hi_r5_234,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_126),
    kInstruction_cmp_le_r4_126,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_241),
    kInstruction_cmp_gt_r7_241,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_116),
    kInstruction_cmp_hi_r7_116,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_119),
    kInstruction_cmp_cs_r7_119,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r3_148),
    kInstruction_cmp_ge_r3_148,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_88),
    kInstruction_cmp_gt_r7_88,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_58),
    kInstruction_cmp_vc_r6_58,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_157),
    kInstruction_cmp_mi_r6_157,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r0_129),
    kInstruction_cmp_cs_r0_129,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_161),
    kInstruction_cmp_vc_r1_161,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r0_34),
    kInstruction_cmp_mi_r0_34,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RDLOW_OPERAND_IMM8_IN_IT_BLOCK_CMP_T32_H_
